@@ -1,6 +1,6 @@
 /* about.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2011-2014 Ralf Hoffmann.
+ * Copyright (C) 2011-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -38,6 +38,7 @@ About::About( AGUIX *aguix, Worker &worker ) : m_aguix( aguix ), m_worker( worke
 {
 }
 
+#ifdef HAVE_AVFS
 static std::string getAVFSVersion()
 {
     if ( ! Datei::fileExists( "/#avfsstat/version" ) ) return "";
@@ -64,6 +65,7 @@ static std::string getAVFSVersion()
 
     return res;
 }
+#endif
 
 void About::about()
 {
@@ -74,7 +76,7 @@ void About::about()
 
     twin = m_aguix->getTransientWindow();
   
-    AWindow *win = new AWindow( m_aguix, 10, 10, 10, 10, 0, catalog.getLocale( 208 ), AWindow::AWINDOW_DIALOG );
+    AWindow *win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocale( 208 ), AWindow::AWINDOW_DIALOG );
     win->create();
     if ( twin != NULL ) {
         win->setTransientForAWindow( twin );
@@ -90,7 +92,7 @@ void About::about()
     ac1_texts->setMaxSpace( 5 );
     ac1_texts->setBorderWidth( 5 );
 
-    std::string str1 = AGUIXUtils::formatStringToString( "Worker %d.%d.%d%s|Copyright (C) 1998 - 2014 Ralf Hoffmann||Active options:",
+    std::string str1 = AGUIXUtils::formatStringToString( "Worker %d.%d.%d%s|Copyright (C) 1998 - 2015 Ralf Hoffmann||Active options:",
                                                          WORKER_MAJOR, WORKER_MINOR, WORKER_PATCH, WORKER_COMMENT );
     win->addMultiLineText( str1, *ac1_texts, 0, 0, NULL, NULL );
 
@@ -204,7 +206,9 @@ void About::about()
     row = option_lv->addRow();
     option_lv->setText( row, 0, "  UDisks available:" );
     if ( m_worker.getVolumeManager().getUDisksAvailable() == true ) {
-        option_lv->setText( row, 1, "yes" );
+        option_lv->setText( row, 1, "yes (version 1)" );
+    } else if ( m_worker.getVolumeManager().getUDisks2Available() == true ) {
+        option_lv->setText( row, 1, "yes (version 2)" );
     } else {
         option_lv->setText( row, 1, "no" );
     }
@@ -240,6 +244,16 @@ void About::about()
     }
     option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
 
+    /* LUA */
+    row = option_lv->addRow();
+    option_lv->setText( row, 0, "LUA support:" );
+#ifdef HAVE_LUA
+    option_lv->setText( row, 1, "yes" );
+#else
+    option_lv->setText( row, 1, "no" );
+#endif
+    option_lv->setPreColors( row, FieldListView::PRECOLOR_NOTSELORACT );
+
 #ifdef DEVELOPER
     row = option_lv->addRow();
     option_lv->setText( row, 0, "Developer version:" );
@@ -274,9 +288,9 @@ void About::about()
     ac1_buttons->setMaxSpace( -1 );
     ac1_buttons->setBorderWidth( 0 );
 
-    licenseb = (Button*)ac1_buttons->add( new Button( m_aguix, 0, 0, catalog.getLocale( 508 ), 1, 0, 0 ),
+    licenseb = (Button*)ac1_buttons->add( new Button( m_aguix, 0, 0, catalog.getLocale( 508 ), 0 ),
                                           0, 0, AContainer::CO_FIX );
-    okb = (Button*)ac1_buttons->add( new Button( m_aguix, 0, 0, catalog.getLocale( 11 ), 1, 0, 0 ),
+    okb = (Button*)ac1_buttons->add( new Button( m_aguix, 0, 0, catalog.getLocale( 11 ), 0 ),
                                      1, 0, AContainer::CO_FIX );
     okb->takeFocus();
 
