@@ -1,6 +1,6 @@
 /* acontainer.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2004-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2004-2008,2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -189,6 +189,12 @@ AContainer::AContainer( AWindow *twin, int txelems, int tyelems )
   MinSpace = 5;
   MaxSpace = -1;
   ergWidths = ergHeights = NULL;
+
+  old_rearrange_width = old_rearrange_height = 0;
+
+  m_move_infos.resize( xelems * yelems );
+  m_resize_infos.resize( xelems * yelems );
+  m_rearrange_infos.resize( xelems * yelems );
 }
 
 AContainer::AContainer( AWindow *twin,
@@ -692,16 +698,28 @@ int AContainer::rearrange( int vhmode )
 	      ux = elements[ind].widelem()->getX();
 	      uw = elements[ind].widelem()->getWidth();
 	    }
-	    elements[ind].widelem()->move( ux, uy );
-	    if ( elements[ind].noResize() == false ) elements[ind].widelem()->resize( uw, uh );
+	    //elements[ind].widelem()->move( ux, uy );
+            m_move_infos[ind].active = true;
+            m_move_infos[ind].x = ux;
+            m_move_infos[ind].y = uy;
+	    if ( elements[ind].noResize() == false ) {
+                //elements[ind].widelem()->resize( uw, uh );
+                m_resize_infos[ind].active = true;
+                m_resize_infos[ind].x = uw;
+                m_resize_infos[ind].y = uh;
+            }
 	  } else if ( elements[ind].cont() != NULL ) {
 	    if ( vhmode == ACONT_ONLYH ) {
 	      uy = elements[ind].cont()->getY();
 	    } else if ( vhmode == ACONT_ONLYV ) {
 	      ux = elements[ind].cont()->getX();
 	    }
-	    elements[ind].cont()->move( ux, uy );
-	    elements[ind].cont()->rearrange( vhmode );
+	    //elements[ind].cont()->move( ux, uy );
+            m_move_infos[ind].active = true;
+            m_move_infos[ind].x = ux;
+            m_move_infos[ind].y = uy;
+	    //elements[ind].cont()->rearrange( vhmode );
+            m_rearrange_infos[ind].active = true;
 	  }
 	}
 	cx += tw;
@@ -709,6 +727,55 @@ int AContainer::rearrange( int vhmode )
     }
     cy += th;
   }
+
+  int start, stop, step;
+
+  if ( width >= old_rearrange_width &&
+       height >= old_rearrange_height ) {
+      start = xelems * yelems - 1;
+      stop = -1;
+      step = -1;
+  } else {
+      start = 0;
+      stop = xelems * yelems;
+      step = 1;
+  }
+
+  for ( ind = start; ind != stop; ind += step ) {
+      if ( m_move_infos[ind].active ) {
+
+          if ( elements[ind].widelem() != NULL ) {
+              elements[ind].widelem()->move( m_move_infos[ind].x,
+                                             m_move_infos[ind].y );
+          } else if ( elements[ind].cont() != NULL ) {
+              elements[ind].cont()->move( m_move_infos[ind].x,
+                                          m_move_infos[ind].y );
+          }
+
+          m_move_infos[ind].active = false;
+      }
+  }
+
+  for ( ind = start; ind != stop; ind += step ) {
+      if ( m_resize_infos[ind].active ) {
+          elements[ind].widelem()->resize( m_resize_infos[ind].x,
+                                           m_resize_infos[ind].y );
+
+          m_resize_infos[ind].active = false;
+      }
+  }
+
+  for ( ind = start; ind != stop; ind += step ) {
+      if ( m_rearrange_infos[ind].active ) {
+          elements[ind].cont()->rearrange( vhmode );
+
+          m_rearrange_infos[ind].active = false;
+      }
+  }
+
+  old_rearrange_width = width;
+  old_rearrange_height = height;
+
   return 0;
 }
 
