@@ -1,6 +1,6 @@
 /* awindow.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2009,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,7 +31,6 @@ AWindow::AWindow( AGUIX *aguix,
 		  int y,
 		  int width,
 		  int height,
-		  int bg,
 		  std::string title,
                   wm_window_type_t type ) : Widget( aguix )
 {
@@ -41,7 +40,13 @@ AWindow::AWindow( AGUIX *aguix,
   _y = y;
   _w = ( width > 0 ) ? width : 1;
   _h = ( height > 0 ) ? height : 1;
-  _bg = bg;
+
+  _bg = _aguix->getFaces().getColor( "default-bg" );
+
+  if ( _bg < 0 ) {
+      _bg = 0;
+  }
+
   _title = title;
   onScreen=false;
   border = 5;
@@ -612,7 +617,7 @@ int AWindow::addTextFromString( const char *text,
   text_elems = (Text**)_allocsafe( sizeof( Text* ) * lines );
 
   for ( i = 0; i < lines; i++ ) {
-    text_elems[i] = (Text*)add( new Text( _aguix, tx, ty, liness[i], 1 ) );
+    text_elems[i] = (Text*)add( new Text( _aguix, tx, ty, liness[i] ) );
     ty += text_elems[i]->getHeight() + vspace;
   }
 
@@ -640,14 +645,19 @@ int AWindow::addMultiLineText( const std::string text,
                                AContainer &ac,
                                int xpos, int ypos,
                                AContainer **return_container,
-                               std::list<Text*> *return_text_list )
+                               std::list<Text*> *return_text_list,
+                               bool split_on_newline )
 {
   int i;
   int lines;
   char **liness;
   Text *textelement;
 
-  lines = createLines( text.c_str(), &liness );
+  if ( split_on_newline ) {
+      lines = createLines( text.c_str(), &liness, '\n' );
+  } else {
+      lines = createLines( text.c_str(), &liness );
+  }
 
   AContainer *textac = ac.add( new AContainer( this, 1, lines ), xpos, ypos );
   textac->setMinSpace( 5 );
@@ -655,7 +665,7 @@ int AWindow::addMultiLineText( const std::string text,
   textac->setBorderWidth( 0 );
 
   for ( i = 0; i < lines; i++ ) {
-    textelement = (Text*)textac->add( new Text( _aguix, 0, 0, liness[i], 1 ),
+    textelement = (Text*)textac->add( new Text( _aguix, 0, 0, liness[i] ),
                                       0, i, AContainer::CO_INCWNR );
     if ( return_text_list != NULL ) {
       return_text_list->push_back( textelement );
