@@ -1,6 +1,6 @@
 /* awindow.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -44,12 +44,11 @@ public:
                  AWINDOW_DIALOG } wm_window_type_t;
 
   AWindow( AGUIX *parent,
-	   int x,
-	   int y,
-	   int width,
-	   int height,
-	   int bg,
-	   std::string title,
+           int x,
+           int y,
+           int width,
+           int height,
+           std::string title,
            wm_window_type_t type = AWINDOW_NORMAL );
   ~AWindow();
   AWindow( const AWindow &other );
@@ -110,7 +109,8 @@ public:
                         AContainer &ac,
                         int xpos, int ypos,
                         AContainer **return_container,
-                        std::list<Text*> *return_text_list );
+                        std::list<Text*> *return_text_list,
+                        bool split_on_newline = false );
   void centerScreen();
   bool contains( Widget *elem ) const;
   Widget *getFocusOwner() const;
