@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2014 Ralf Hoffmann.
+ * Copyright (C) 2002-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -78,7 +78,6 @@ public:
 
   virtual void redraw();
   void redraw( int element );
-  void redrawContent();
   typedef enum { CC_NORMAL = 0, CC_SELECT = 1, CC_ACTIVE = 2, CC_SELACT = 3 } colorclass_t;
   void setFG( int row, colorclass_t cc, int col );
   int getFG( int row, colorclass_t cc ) const;
@@ -134,7 +133,7 @@ public:
   void showRow( int row, bool redraw = true);
   
   void setData( int row, int ndata );
-  int getData( int row ) const;
+  int getData( int row, int fallback_value ) const;
   void setDataExt( int row, FieldLVRowData *ndata );
   FieldLVRowData *getDataExt( int row ) const;
   
@@ -203,6 +202,37 @@ public:
 
   void setDefaultColorMode( precolor_t mode );
 
+  struct on_demand_data {
+      on_demand_data() : done( false ),
+          text_set( false ),
+          segments_set( false )
+      {}
+      
+      bool done;  // indicates that the caller is done with ondemand data
+
+      std::string text; // the text for the given row x column
+      bool text_set;
+
+      std::vector< size_t > segments; // highlight segments
+      bool segments_set;
+  };
+  
+  void setOnDemandCallback( std::function< void( FieldListView*,
+                                                 int row,
+                                                 int field,
+                                                 struct on_demand_data &data ) > cb );
+
+  void clearOnDemandDataAvailableFlag();
+  void clearOnDemandDataAvailableFlag( int row );
+
+  typedef enum {
+      HEADER_SORT_HINT_NONE,
+      HEADER_SORT_HINT_UP,
+      HEADER_SORT_HINT_DOWN
+  } header_sort_hint_t;
+
+  void setSortHint( int field, header_sort_hint_t hint );
+  void unsetSortHint();
 protected:
   int fields;
   int *fieldwidth;
@@ -244,6 +274,16 @@ protected:
     void setHighlightSegments( int field, const std::vector< size_t > &segments );
     const std::vector< size_t > *getHighlightSegments( int field ) const;
     void clearHighlightSegments();
+
+    bool getOnDemandDataAvailable() const
+    {
+        return m_ondemand_data_available;
+    }
+
+    void setOnDemandDataAvailable( bool nv )
+    {
+        m_ondemand_data_available = nv;
+    }
   protected:
     int cur_fields;
     std::string **texts;
@@ -254,6 +294,8 @@ protected:
     int data;
     FieldLVRowData *dataExt;
     bool mark;
+
+    bool m_ondemand_data_available;
   };
   Content **elementarray;
   int arraysize;
@@ -264,6 +306,7 @@ protected:
 
   int xoffset, yoffset, maxdisplayv;
 
+  void redrawContent();
   void redrawLine( int element );
   int activerow;
 
@@ -390,6 +433,8 @@ protected:
                                unsigned int keystate,
                                unsigned int matching_mod );
 
+  void initStaticDefaultColors();
+
   std::set<int> m_updated_rows;
   bool m_complete_update;
   struct timeval m_last_update_time;
@@ -399,6 +444,23 @@ protected:
   bool m_consider_header_for_dynamic_width;
 
   precolor_t m_default_color_mode;
+
+  static ColorDef s_default_element_colors;
+
+  std::function< void( FieldListView*,
+                       int row,
+                       int field,
+                       struct on_demand_data &data ) > m_ondemand_callback;
+
+  void updateOnDemandData();
+
+  struct header_sort_hint {
+      header_sort_hint() : field( -1 ),
+                           hint( HEADER_SORT_HINT_NONE )
+      {}
+      int field;
+      header_sort_hint_t hint;
+  } sort_hint;
 };
 
 #endif
