@@ -1,6 +1,6 @@
 /* popupmenu.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2008,2010 Ralf Hoffmann.
+ * Copyright (C) 2007-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,7 +31,7 @@ PopUpMenu::PopUpMenu( AGUIX *parent,
                       int group_id ) : PopUpWindow( parent,
                                                     0, 0,
                                                     10, 10,
-                                                    0, "",
+                                                    "",
                                                     group_id ),
                                        m_highlighted_entry( -1 ),
                                        m_counter( 0 ),
@@ -56,10 +56,12 @@ PopUpMenu::PopUpMenu( AGUIX *parent,
         InternPopUpEntry e;
 
         e.name = it1->name;
+        e.help = it1->help;
         e.type = it1->type;
         e.id = it1->id;
         e.fg = it1->fg;
         e.bg = it1->bg;
+        e.highlight_on_show = it1->highlight_on_show;
 
         if ( it1->type == SUBMENU && it1->submenu != NULL ) {
             e.submenu = new PopUpMenu( parent, *(it1->submenu), getGroupID() );
@@ -73,6 +75,10 @@ PopUpMenu::PopUpMenu( AGUIX *parent,
 
 PopUpMenu::~PopUpMenu()
 {
+    if ( m_help_cb ) {
+        m_help_cb( "" );
+    }
+
     for ( std::vector<InternPopUpEntry>::iterator it1 = m_entries.begin();
           it1 != m_entries.end();
           it1++ ) {
@@ -117,6 +123,16 @@ void PopUpMenu::show( int x, int y, popup_show_t show_type )
         if ( m_parent_menu == NULL ) {
             setKeyboardFocus( true );
         }
+        
+        if ( getKeyboardFocus() ) {
+            for ( size_t entry = 0;
+                  entry < m_entries.size();
+                  entry++ ) {
+                if ( m_entries[entry].highlight_on_show ) {
+                    setHighlightEntry( entry );
+                }
+            }
+        }
 
         PopUpWindow::show();
         //TODO handle positions
@@ -149,6 +165,10 @@ void PopUpMenu::show( int x, int y, popup_show_t show_type )
 void PopUpMenu::hide()
 {
     bool send_msg = false;
+
+    if ( m_help_cb ) {
+        m_help_cb( "" );
+    }
     
     if ( m_parent_menu == NULL && isVisible() == true ) {
         send_msg = true;
@@ -393,35 +413,31 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
             } else {
 
                 if ( msg->key == XK_Down ) {
+                    int highlighted_entry;
+
                     if ( m_highlighted_entry < 0 ) {
-                        m_highlighted_entry = 0;
+                        highlighted_entry = 0;
                     } else {
-                        m_highlighted_entry++;
-                        if ( m_highlighted_entry >= (int)m_entries.size() )
-                            m_highlighted_entry = 0;
+                        highlighted_entry = m_highlighted_entry + 1;
+                        if ( highlighted_entry >= (int)m_entries.size() ) {
+                            highlighted_entry = 0;
+                        }
                     }
                 
-                    m_highlighted_entry = forwardToVisibleEntry( m_highlighted_entry, 1 );
-                
-                    m_open_after_timeout = true;
-                    m_counter = 0;
-                    enableTimer();
-                    redraw();
+                    setHighlightEntry( forwardToVisibleEntry( highlighted_entry, 1 ) );
                 } else if ( msg->key == XK_Up ) {
+                    int highlighted_entry;
+
                     if ( m_highlighted_entry < 0 ) {
-                        m_highlighted_entry = (int)m_entries.size() - 1;
+                        highlighted_entry = (int)m_entries.size() - 1;
                     } else {
-                        m_highlighted_entry--;
-                        if ( m_highlighted_entry < 0 )
-                            m_highlighted_entry = (int)m_entries.size() - 1;
+                        highlighted_entry = m_highlighted_entry - 1;
+                        if ( highlighted_entry < 0 ) {
+                            highlighted_entry = (int)m_entries.size() - 1;
+                        }
                     }
 
-                    m_highlighted_entry = forwardToVisibleEntry( m_highlighted_entry, -1 );
-
-                    m_open_after_timeout = true;
-                    m_counter = 0;
-                    enableTimer();
-                    redraw();
+                    setHighlightEntry( forwardToVisibleEntry( highlighted_entry, -1 ) );
                 } else if ( msg->key == XK_Return ) {
                     activateEntry( m_highlighted_entry );
                 } else if ( msg->key == XK_Right ) {
@@ -434,7 +450,8 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
                                 showEntry( m_highlighted_entry );
                                 setKeyboardFocus( false );
                                 it1->submenu->setKeyboardFocus( true );
-                                it1->submenu->setHighlightEntry( 0 );
+
+                                it1->submenu->highlightOnShowEntry( 0 );
                             }
                             break;
                         }
@@ -487,14 +504,9 @@ bool PopUpMenu::handleMessage( XEvent *e,Message *msg )
                   entry = getEntryForYPos( my );
                   if ( entry >= 0 && entry < (int)m_entries.size() ) {
                       if ( m_highlighted_entry != entry && isVisibleEntry( entry ) == true ) {
-                          m_open_after_timeout = true;
-                          m_highlighted_entry = entry;
-                          m_counter = 0;
+                          setHighlightEntry( entry );
                           
                           changeFocusTo( this );
-                          
-                          enableTimer();
-                          redraw();
                       }
                       
                       // for immediate popup:
@@ -560,7 +572,8 @@ PopUpMenu::InternPopUpEntry::InternPopUpEntry() : name( "" ),
                                                   height( 0 ),
                                                   fg( -1 ),
                                                   bg( -1 ),
-                                                  editable_content( "" )
+                                                  editable_content( "" ),
+                                                  highlight_on_show( false )
 {
 }
 
@@ -573,7 +586,8 @@ PopUpMenu::PopUpEntry::PopUpEntry() : name( "" ),
                                       id( -1 ),
                                       submenu( NULL ),
                                       fg( -1 ),
-                                      bg( -1 )
+                                      bg( -1 ),
+                                      highlight_on_show( false )
 {
 }
 
@@ -627,6 +641,10 @@ void PopUpMenu::setHighlightEntry( int entry )
             m_counter = 0;
             
             enableTimer();
+
+            if ( m_help_cb ) {
+                m_help_cb( m_entries[m_highlighted_entry].help );
+            }
         }
         redraw();
     }
@@ -698,16 +716,16 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
         if ( m_entries[entry].fg >= 0 ) {
             normal_fg = m_entries[entry].fg;
         } else {
-            normal_fg = 1;
+            normal_fg = _aguix->getFaces().getColor( "popup-fg" );
         }
         if ( m_entries[entry].bg >= 0 ) {
             normal_bg = m_entries[entry].bg;
         } else {
-            normal_bg = 0;
+            normal_bg = getBG();
         }
 
         if ( m_edit_entry == entry ) {
-            _aguix->setFG( 2 );
+            _aguix->setFG( _aguix->getFaces().getColor( "popup-edit-field-bg" ) );
             _aguix->FillRectangle( win,
                                    getBorderWidth() + 1,
                                    top_y + 1,
@@ -746,7 +764,7 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
                                             getEntryHeight( entry ), 0 );
                     }
                 
-                    if ( normal_bg != 0 ) {
+                    if ( normal_bg != getBG() ) {
                         _aguix->setFG( normal_bg );
                         _aguix->FillRectangle( win,
                                                getBorderWidth() + 1,
@@ -756,7 +774,7 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
                     }
 
                     if ( isVisibleEntry( entry ) == true ) {
-                        int hfg = 2;
+                        int hfg = _aguix->getFaces().getColor( "popup-highlight-fg" );
 
                         if ( normal_bg == hfg ) {
                             hfg = normal_fg;
@@ -769,7 +787,7 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
                         _aguix->DrawText( dc, m_entries[entry].name.c_str(),
                                           getBorderWidth() + 1 + 1,
                                           top_y + 1 + 1,
-                                          2 );
+                                          _aguix->getFaces().getColor( "popup-highlight-fg" ) );
                         _aguix->DrawText( dc, m_entries[entry].name.c_str(),
                                           getBorderWidth() + 1,
                                           top_y + 1,
@@ -783,7 +801,7 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
                         int tr_w = submenu_char_w;
                         int tr_y = top_y + 1;
                         int tr_h = m_entries[entry].height - 2;
-                        _aguix->setFG( 1 );
+                        _aguix->setFG( _aguix->getFaces().getColor( "popup-submenu-arrow" ) );
                         _aguix->DrawTriangleFilled( win,
                                                     tr_x + 2, tr_y + 2,
                                                     tr_x + tr_w - 3, tr_y + tr_h / 2,
@@ -791,12 +809,12 @@ void PopUpMenu::redrawEntry( int entry, int top_y )
                     }
                     break;
                 case HLINE:
-                    _aguix->setFG( 2 );
+                    _aguix->setFG( _aguix->getFaceCol_3d_bright() );
                     _aguix->DrawLine( win, getBorderWidth(), top_y + 2,
                                       getBorderWidth(), top_y + 1 );
                     _aguix->DrawLine( win, getBorderWidth(), top_y + 1,
                                       getWidth() - getBorderWidth() - 2, top_y + 1 );
-                    _aguix->setFG( 1 );
+                    _aguix->setFG( _aguix->getFaceCol_3d_dark() );
                     _aguix->DrawLine( win, getWidth() - getBorderWidth() - 1, top_y + 1,
                                       getWidth() - getBorderWidth() - 1, top_y + 2 );
                     _aguix->DrawLine( win, getWidth() - getBorderWidth() - 1, top_y + 2,
@@ -891,13 +909,7 @@ int PopUpMenu::forwardToVisibleEntry( int pos, int direction )
 void PopUpMenu::updateInfixFilter()
 {
     //move highlight to next visible
-    m_highlighted_entry = forwardToVisibleEntry( m_highlighted_entry, 1 );
-
-    m_open_after_timeout = true;
-    m_counter = 0;
-    enableTimer();
-    //redraw menu
-    redraw();
+    setHighlightEntry( forwardToVisibleEntry( m_highlighted_entry, 1 ) );
 }
 
 bool PopUpMenu::isVisibleEntry( int pos ) const
@@ -1024,3 +1036,37 @@ void PopUpMenu::checkAndGrabKeyboard()
         }
     }
 }
+
+int PopUpMenu::getHighlightEntry() const
+{
+    return m_highlighted_entry;
+}
+
+bool PopUpMenu::getKeyboardFocus() const
+{
+    return m_keyboard_focus;
+}
+
+void PopUpMenu::highlightOnShowEntry( int default_entry )
+{
+    size_t entry;
+
+    for ( entry = 0;
+          entry < m_entries.size();
+          entry++ ) {
+        if ( m_entries[entry].highlight_on_show ) {
+            setHighlightEntry( entry );
+            break;
+        }
+    }
+
+    if ( entry >= m_entries.size() &&
+         default_entry >= 0 ) {
+        setHighlightEntry( default_entry );
+    }
+}
+
+void PopUpMenu::setHelpCB( std::function< void( const std::string &help ) > help_cb )
+{
+    m_help_cb = help_cb;
+}
