@@ -1,6 +1,6 @@
 /* util.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2016 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -438,4 +438,50 @@ namespace AGUIXUtils
             str = nv;
         }
     }
+
+    std::string timeToString( time_t t )
+    {
+        char buf[128];
+        struct tm converted_tm = { 0 };
+
+        localtime_r( &t, &converted_tm );
+    
+        if ( strftime( buf, sizeof( buf ),
+                       "%Y-%m-%d %H:%M:%S", &converted_tm ) > 0 ) {
+            return std::string( buf );
+        }
+
+        return "";
+    }
+
+    bool parseStringToTime( const std::string &time_string,
+                            time_t *return_time )
+    {
+        struct tm parsed_tm = { 0 };
+        time_t converted_time;
+
+        parsed_tm.tm_isdst = -1;
+
+        if ( strptime( time_string.c_str(),
+                       "%Y-%m-%d %H:%M:%S",
+                       &parsed_tm ) == NULL ) {
+            if ( strptime( time_string.c_str(),
+                           "%Y-%m-%d",
+                           &parsed_tm ) == NULL ) {
+                return false;
+            }
+        }
+
+        converted_time = mktime( &parsed_tm );
+
+        if ( converted_time == (time_t)-1 ) {
+            return false;
+        }
+
+        if ( return_time ) {
+            *return_time = converted_time;
+        }
+
+        return true;
+    }
 }
