@@ -1,6 +1,6 @@
 /* basic_actions.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -810,7 +810,7 @@ int UserAction::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(4))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(4));
-  win =new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win =new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -818,7 +818,7 @@ int UserAction::configure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  rcyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 0, 0, AContainer::CO_INCW );
+  rcyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 0, 0, AContainer::CO_INCW );
   rcyb->addOption(catalog.getLocale(255));
   rcyb->addOption(catalog.getLocale(256));
   rcyb->addOption(catalog.getLocale(257));
@@ -842,15 +842,11 @@ int UserAction::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, AContainer::CO_FIX );
   Button *cb = (Button*)ac1_1->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, AContainer::CO_FIX );
 
   win->setDoTabCycling( true );
@@ -1011,7 +1007,7 @@ int ChangeHiddenFlag::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(7))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(7));
-  win=new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win=new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -1019,7 +1015,7 @@ int ChangeHiddenFlag::configure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  rcyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 0, 0, AContainer::CO_INCW );
+  rcyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 0, 0, AContainer::CO_INCW );
   rcyb->addOption(catalog.getLocale(360));
   rcyb->addOption(catalog.getLocale(361));
   rcyb->addOption(catalog.getLocale(362));
@@ -1045,15 +1041,11 @@ int ChangeHiddenFlag::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, AContainer::CO_FIX );
   Button *cb = (Button*)ac1_1->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, AContainer::CO_FIX );
   
   win->setDoTabCycling( true );
