@@ -1,6 +1,6 @@
 /* chmodop.c
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -191,7 +191,7 @@ ChModOp::doconfigure(int mode)
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(38))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(38));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
   
@@ -199,20 +199,20 @@ ChModOp::doconfigure(int mode)
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 38 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 38 ) ), 0, 0, cincwnr );
 
   ofcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( onfiles == true ) ? 1 : 0,
-						    catalog.getLocale( 295 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						    catalog.getLocale( 295 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   odcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( ondirs == true ) ? 1 : 0,
-						    catalog.getLocale( 296 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
+						    catalog.getLocale( 296 ), LABEL_RIGHT, 0 ), 0, 2, cincwnr );
 
   rcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( recursive == true ) ? 1 : 0,
-						   catalog.getLocale( 297 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
+						   catalog.getLocale( 297 ), LABEL_RIGHT, 0 ), 0, 3, cincwnr );
 
   if(mode==0) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( requestflags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ), 0, 4, cincwnr );
   }
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
@@ -223,15 +223,11 @@ ChModOp::doconfigure(int mode)
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_1->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   okb->takeFocus();
