@@ -1,6 +1,6 @@
 /* clipboardop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2013 Ralf Hoffmann.
+ * Copyright (C) 2012-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -126,7 +126,7 @@ ClipboardOp::doconfigure(int mode)
   
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 61 ) ) + 1 );
     sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 61 ) );
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+    win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
 
@@ -138,15 +138,13 @@ ClipboardOp::doconfigure(int mode)
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( 5 );
     ac1_3->setBorderWidth( 0 );
-    ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 979 ), 1 ), 0, 0, cfix );
+    ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 979 ) ), 0, 0, cfix );
     sgcf = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, m_string.c_str(), 0 ),
                                       1, 0, cincw );
     flagb = (Button*)ac1_3->add( new Button( aguix,
                                              0,
                                              0,
                                              "F",
-                                             1,
-                                             0,
                                              0 ), 2, 0, cfix );
   
     AContainer *ac1_5 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
@@ -157,15 +155,11 @@ ClipboardOp::doconfigure(int mode)
                                            0,
                                            0,
                                            catalog.getLocale( 11 ),
-                                           1,
-                                           0,
                                            0 ), 0, 0, cfix );
     cancelb = (Button*)ac1_5->add( new Button( aguix,
                                                0,
                                                0,
                                                catalog.getLocale( 8 ),
-                                               1,
-                                               0,
                                                0 ), 1, 0, cfix );
     win->contMaximize( true );
 
