@@ -429,7 +429,9 @@ struct mytoken tokenlist[]={
   { LEAVE_UNMODIFIED_WCP, "leave_unmodified" },
   { PREFERUDISKSVERSION_WCP, "prefer_udisks_version" },
   { CHANGECOLUMNSOP_WCP, "changecolumnsop" },
-  { PATTERNISCOMMASEPARATED_WCP, "pattern_is_comma_separated" }
+  { PATTERNISCOMMASEPARATED_WCP, "pattern_is_comma_separated" },
+  { USE_STRING_COMPARE_MODE_WCP, "usestringcomparemode" },
+  { STRCASECMP_WCP, "strcasecmp" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
