@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,6 +33,8 @@
 #include "copyorder.hh"
 #include "virtualdirmode.hh"
 
+using namespace CopyParams;
+
 const char *CopyOp::name="CopyOp";
 
 CopyOp::CopyOp() : FunctionProto()
@@ -45,6 +47,8 @@ CopyOp::CopyOp() : FunctionProto()
   request_flags=false;
   overwrite=COPYOP_OVERWRITE_NORMAL;
   preserve_attr=true;
+  adjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_NEVER;
+  ensure_file_permissions = LEAVE_PERMISSIONS_UNMODIFIED;
   hasConfigure = true;
     m_category = FunctionProto::CAT_FILEOPS;
 }
@@ -65,6 +69,8 @@ CopyOp::duplicate() const
   ta->request_flags=request_flags;
   ta->overwrite=overwrite;
   ta->preserve_attr=preserve_attr;
+  ta->adjust_relative_symlinks = adjust_relative_symlinks;
+  ta->ensure_file_permissions = ensure_file_permissions;
   return ta;
 }
 
@@ -126,6 +132,32 @@ CopyOp::save(Datei *fh)
       break;
   }
   fh->configPutPairBool( "preserveattr", preserve_attr );
+
+  switch ( adjust_relative_symlinks ) {
+      case COPYOP_ADJUST_SYMLINK_OUTSIDE:
+          fh->configPutPair( "adjustrelativesymlinks", "outside" );
+          break;
+      case COPYOP_ADJUST_SYMLINK_ALWAYS:
+          fh->configPutPair( "adjustrelativesymlinks", "always" );
+          break;
+      default:
+          break;
+  }
+
+  switch ( ensure_file_permissions() ) {
+      case ensure_mode_t::ENSURE_USER_RW_PERMISSION:
+          fh->configPutPair( "ensure_file_permissions", "user_rw" );
+          break;
+      case ENSURE_USER_RW_GROUP_R_PERMISSION:
+          fh->configPutPair( "ensure_file_permissions", "user_rw_group_r" );
+          break;
+      case ENSURE_USER_RW_ALL_R_PERMISSION:
+          fh->configPutPair( "ensure_file_permissions", "user_rw_all_r" );
+          break;
+      default:
+          break;
+  }
+
   return true;
 }
 
@@ -168,6 +200,8 @@ CopyOp::normalmodecopy( ActionMessage *am )
     trequest_dest=request_dest;
     toverwrite=overwrite;
     tpreserve_attr=preserve_attr;
+    tadjust_relative_symlinks = adjust_relative_symlinks;
+    tensure_file_permissions = ensure_file_permissions;
   }
   
   if(cont==true) {
@@ -203,6 +237,9 @@ CopyOp::normalmodecopy( ActionMessage *am )
     */
 
     do_request = false;
+
+    bool last_path_used = false;
+
     if ( trequest_dest == true ) {
         do_request = true;
     } else if ( tsame_dir == true ) {
@@ -220,6 +257,14 @@ CopyOp::normalmodecopy( ActionMessage *am )
                 do_request = true;
             }
 
+            if ( destination_directory.empty() ) {
+                destination_directory = endlister->getLastPath();
+
+                if ( ! destination_directory.empty() ) {
+                    last_path_used = true;
+                }
+            }
+
             if ( auto vdm = dynamic_cast< VirtualDirMode * >( dest_lm ) ) {
                 if ( ! destination_directory.empty() && ! vdm->currentDirIsReal() ) {
                     std::string textstr = AGUIXUtils::formatStringToString( catalog.getLocale( 1002 ),
@@ -243,27 +288,53 @@ CopyOp::normalmodecopy( ActionMessage *am )
         }
     }
 
+    if ( last_path_used ) {
+        int use_previous_if_same = 0;
+        std::string previously_used_path;
+
+        try {
+            use_previous_if_same = Worker::getKVPStore().getIntValue( "copy_use_previous_if_same" );
+            previously_used_path = Worker::getKVPStore().getStringValue( "copy_previous_destination" );
+
+            if ( use_previous_if_same != 0 &&
+                 previously_used_path == destination_directory ) {
+                do_request = false;
+            }
+        } catch (...) {
+        }
+    }
+
     if ( do_request == true ) {
         std::string default_dir;
         char *tstr = NULL;
 
-        destination_directory.clear();
-      
-        if ( dest_lm != NULL ) {
-            default_dir = dest_lm->getCurrentDirectory();
+        if ( ! destination_directory.empty() ) {
+            default_dir = destination_directory;
+        } else {
+            if ( dest_lm != NULL ) {
+                default_dir = dest_lm->getCurrentDirectory();
 
-            if ( default_dir.empty() ) {
+                if ( default_dir.empty() ) {
+                    default_dir = start_lm->getCurrentDirectory();
+                }
+            } else {
                 default_dir = start_lm->getCurrentDirectory();
             }
-        } else {
-            default_dir = start_lm->getCurrentDirectory();
         }
       
-        if ( requestdest( default_dir.c_str(), &tstr ) != 0 ) {
+        bool ask_result = false;
+
+        if ( requestdest( default_dir.c_str(), &tstr, last_path_used, ask_result ) != 0 ) {
             destination_directory.clear();
         } else {
             destination_directory = tstr;
             _freesafe( tstr );
+
+            if ( last_path_used ) {
+                Worker::getKVPStore().setIntValue( "copy_use_previous_if_same", ask_result ? 1 : 0 );
+                Worker::getKVPStore().setStringValue( "copy_previous_destination",
+                                                      destination_directory );
+            }
         }
     }
     /* if dest==null nothing to do
@@ -281,6 +352,21 @@ CopyOp::normalmodecopy( ActionMessage *am )
         co->move=tmove;
         co->follow_symlinks=tfollow_symlinks;
         co->preserve_attr=tpreserve_attr;
+
+        switch ( tadjust_relative_symlinks ) {
+            case COPYOP_ADJUST_SYMLINK_OUTSIDE:
+                co->adjust_relative_symlinks = co->COPY_ADJUST_SYMLINK_OUTSIDE;
+                break;
+            case COPYOP_ADJUST_SYMLINK_ALWAYS:
+                co->adjust_relative_symlinks = co->COPY_ADJUST_SYMLINK_ALWAYS;
+                break;
+            default:                
+                co->adjust_relative_symlinks = co->COPY_ADJUST_SYMLINK_NEVER;
+                break;
+        }
+
+        co->ensure_file_permissions = tensure_file_permissions;
+
         co->do_rename=trename;
         switch(toverwrite) {
             case COPYOP_OVERWRITE_ALWAYS:
@@ -330,33 +416,93 @@ CopyOp::doconfigure(int mode)
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(8))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(8));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 9 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 11 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 8 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocaleCom( 8 ) ), 0, 0, cincwnr );
 
   fscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( follow_symlinks == true ) ? 1 : 0,
-						    catalog.getLocale( 298 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						    catalog.getLocale( 298 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   mcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( move == true ) ? 1 : 0,
-						   catalog.getLocale( 299 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
+						   catalog.getLocale( 299 ), LABEL_RIGHT, 0 ), 0, 2, cincwnr );
 
   rcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( do_rename == true ) ? 1 : 0,
-						   catalog.getLocale( 300 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
+						   catalog.getLocale( 300 ), LABEL_RIGHT, 0 ), 0, 3, cincwnr );
 
   sdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( same_dir == true ) ? 1 : 0,
-						    catalog.getLocale( 301 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
+						    catalog.getLocale( 301 ), LABEL_RIGHT, 0 ), 0, 4, cincwnr );
 
   rdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( request_dest == true ) ? 1 : 0,
-						    catalog.getLocale( 302 ), LABEL_RIGHT, 1, 0 ), 0, 5, cincwnr );
+						    catalog.getLocale( 302 ), LABEL_RIGHT, 0 ), 0, 5, cincwnr );
 
   pacb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( preserve_attr == true ) ? 1 : 0,
-						    catalog.getLocale( 150 ), LABEL_RIGHT, 1, 0 ), 0, 6, cincwnr );
+						    catalog.getLocale( 150 ), LABEL_RIGHT, 0 ), 0, 6, cincwnr );
+
+  AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 7 );
+  ac1_1->setMinSpace( 5 );
+  ac1_1->setMaxSpace( -1 );
+  ac1_1->setBorderWidth( 0 );
+
+  ac1_1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1088 ) ),
+                    0, 0, cfix );
+  CycleButton *ars_cyb = ac1_1->addWidget( new CycleButton( aguix, 0, 0, 100, 0 ),
+                                           1, 0, cincwnr );
+  ars_cyb->addOption( catalog.getLocale( 306 ) );
+  ars_cyb->addOption( catalog.getLocale( 1089 ) );
+  ars_cyb->addOption( catalog.getLocale( 305 ) );
+  ars_cyb->resize( ars_cyb->getMaxSize(),
+                   ars_cyb->getHeight() );
+  ac1_1->readLimits();
+
+  switch ( adjust_relative_symlinks ) {
+    case COPYOP_ADJUST_SYMLINK_OUTSIDE:
+      ars_cyb->setOption( 1 );
+      break;
+    case COPYOP_ADJUST_SYMLINK_ALWAYS:
+      ars_cyb->setOption( 2 );
+      break;
+    default:
+      ars_cyb->setOption( 0 );
+      break;
+  }
+
+  AContainer *ac1_ens_perm = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
+  ac1_ens_perm->setMinSpace( 5 );
+  ac1_ens_perm->setMaxSpace( -1 );
+  ac1_ens_perm->setBorderWidth( 0 );
+
+  ac1_ens_perm->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1097 ) ),
+                           0, 0, cfix );
+  CycleButton *ep_cyb = ac1_ens_perm->addWidget( new CycleButton( aguix, 0, 0, 100, 0 ),
+                                                 1, 0, cincwnr );
+  ep_cyb->addOption( catalog.getLocale( 1098 ) );
+  ep_cyb->addOption( catalog.getLocale( 1099 ) );
+  ep_cyb->addOption( catalog.getLocale( 1100 ) );
+  ep_cyb->addOption( catalog.getLocale( 1101 ) );
+  ep_cyb->resize( ep_cyb->getMaxSize(),
+                  ep_cyb->getHeight() );
+  ac1_ens_perm->readLimits();
+
+  switch ( ensure_file_permissions() ) {
+    case ENSURE_USER_RW_PERMISSION:
+      ep_cyb->setOption( 1 );
+      break;
+    case ENSURE_USER_RW_GROUP_R_PERMISSION:
+      ep_cyb->setOption( 2 );
+      break;
+    case ENSURE_USER_RW_ALL_R_PERMISSION:
+      ep_cyb->setOption( 3 );
+      break;
+    default:
+      ep_cyb->setOption( 0 );
+      break;
+  }
 
 /*  ttext=(Text*)win->add(new Text(aguix,x,y,catalog.getLocale(303),1));
   x+=ttext->getWidth()+5;
@@ -384,10 +530,10 @@ CopyOp::doconfigure(int mode)
 
   if(mode==0) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( request_flags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 7, cincwnr );
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ), 0, 9, cincwnr );
   }
 
-  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 8 );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 10 );
   ac1_2->setMinSpace( 5 );
   ac1_2->setMaxSpace( -1 );
   ac1_2->setBorderWidth( 0 );
@@ -395,15 +541,11 @@ CopyOp::doconfigure(int mode)
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   okb->takeFocus();
@@ -441,12 +583,14 @@ CopyOp::doconfigure(int mode)
                 rdcb->setState((rdcb->getState() == true ) ? false : true);
                 break;
               case XK_6:
-/*                i=ocyb->getSelectedOption()+1;
-                if(i>=3) i=0;
-                ocyb->setOption(i);
-                break;
-              case XK_7:*/
+                pacb->setState( ( pacb->getState() == true ) ? false : true );
                 break;
+              case XK_7:
+                  ars_cyb->setOption( ( ars_cyb->getSelectedOption() + 1 ) % 3 );
+                  break;
+              case XK_8:
+                  ep_cyb->setOption( ( ep_cyb->getSelectedOption() + 1 ) % 4 );
+                  break;
               case XK_Return:
                 if ( cb->getHasFocus() == false ) {
                   endmode = 0;
@@ -473,6 +617,34 @@ CopyOp::doconfigure(int mode)
       tsame_dir = sdcb->getState();
       trequest_dest = rdcb->getState();
       tpreserve_attr = pacb->getState();
+
+      switch ( ars_cyb->getSelectedOption() ) {
+          case 1:
+              tadjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_OUTSIDE;
+              break;
+          case 2:
+              tadjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_ALWAYS;
+              break;
+          default:
+              tadjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_NEVER;
+              break;
+      }
+
+      switch ( ep_cyb->getSelectedOption() ) {
+          case 1:
+              tensure_file_permissions = ENSURE_USER_RW_PERMISSION;
+              break;
+          case 2:
+              tensure_file_permissions = ENSURE_USER_RW_GROUP_R_PERMISSION;
+              break;
+          case 3:
+              tensure_file_permissions = ENSURE_USER_RW_ALL_R_PERMISSION;
+              break;
+          default:
+              tensure_file_permissions = LEAVE_PERMISSIONS_UNMODIFIED;
+              break;
+      }
+
       toverwrite=COPYOP_OVERWRITE_NORMAL;
 /*      switch(ocyb->getSelectedOption()) {
         case 1:
@@ -494,6 +666,34 @@ CopyOp::doconfigure(int mode)
       request_dest = rdcb->getState();
       request_flags = rfcb->getState();
       preserve_attr = pacb->getState();
+
+      switch ( ars_cyb->getSelectedOption() ) {
+          case 1:
+              adjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_OUTSIDE;
+              break;
+          case 2:
+              adjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_ALWAYS;
+              break;
+          default:
+              adjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_NEVER;
+              break;
+      }
+
+      switch ( ep_cyb->getSelectedOption() ) {
+          case 1:
+              ensure_file_permissions = ENSURE_USER_RW_PERMISSION;
+              break;
+          case 2:
+              ensure_file_permissions = ENSURE_USER_RW_GROUP_R_PERMISSION;
+              break;
+          case 3:
+              ensure_file_permissions = ENSURE_USER_RW_ALL_R_PERMISSION;
+              break;
+          default:
+              ensure_file_permissions = LEAVE_PERMISSIONS_UNMODIFIED;
+              break;
+      }
+
       overwrite=COPYOP_OVERWRITE_NORMAL;
 /*      switch(ocyb->getSelectedOption()) {
         case 1:
@@ -522,7 +722,8 @@ CopyOp::configure()
 }
 
 int
-CopyOp::requestdest( const char *defaultstr, char **dest )
+CopyOp::requestdest( const char *defaultstr, char **dest,
+                     bool show_do_not_ask, bool &do_not_ask_return )
 {
   Requester *req=new Requester( Worker::getAGUIX());
   char *buttonstr;
@@ -534,12 +735,29 @@ CopyOp::requestdest( const char *defaultstr, char **dest )
                               strlen(catalog.getLocale(8))+1);
   sprintf(buttonstr,"%s|%s",catalog.getLocale(11),
                             catalog.getLocale(8));
-  erg = req->string_request( catalog.getLocale( 123 ),
-                             textstr,
-                             ( defaultstr != NULL ) ? defaultstr : "",
-                             buttonstr,
-                             dest,
-                             Requester::REQUEST_SELECTALL );
+
+  if ( show_do_not_ask ) {
+      bool v = false;
+
+      erg = req->string_request_choose( catalog.getLocale( 123 ),
+                                        textstr,
+                                        ( defaultstr != NULL ) ? defaultstr : "",
+                                        catalog.getLocale( 1062 ),
+                                        v,
+                                        buttonstr,
+                                        dest,
+                                        Requester::REQUEST_SELECTALL );
+
+      do_not_ask_return = v;
+  } else {
+      erg = req->string_request( catalog.getLocale( 123 ),
+                                 textstr,
+                                 ( defaultstr != NULL ) ? defaultstr : "",
+                                 buttonstr,
+                                 dest,
+                                 Requester::REQUEST_SELECTALL );
+  }
+
   _freesafe(buttonstr);
   delete req;
   return erg;
@@ -584,3 +802,13 @@ void CopyOp::setPreserveAttr(bool nv)
 {
   preserve_attr=nv;
 }
+
+void CopyOp::setAdjustRelativeSymlinks( adjust_relative_symlinks_t nv )
+{
+    adjust_relative_symlinks = nv;
+}
+
+void CopyOp::setEnsureFilePermissions( const CopyParams::EnsureFilePermissions &nv )
+{
+    ensure_file_permissions = nv;
+}
