@@ -82,7 +82,7 @@ CopyOpWin::CopyOpWin( AGUIX*taguix, bool _move )
   m_finished = false;
   m_detached = false;
 
-  int v = Worker::getKVPStore().getIntValue( "copy-keep-window" );
+  int v = Worker::getPersKVPStore().getIntValue( "copy-keep-window" );
 
   // 0 is default for non-existing entry, 2 means enabled
   if ( v == 0 ||
@@ -114,72 +114,72 @@ CopyOpWin::open()
   window = new AWindow( aguix,
 			10, 10,
 			w, h,
-			0, ( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
+			( move == true ) ? catalog.getLocale( 299 ) : catalog.getLocaleCom( 8 ),
                         AWindow::AWINDOW_NORMAL );
   window->create();
   tx=5;
   ty=5;
-  sourcetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  sourcetext=(Text*)window->add(new Text(aguix,tx,ty,""));
   ismessage[0] = true;
   ty+=sourcetext->getHeight()+5;
-  desttext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  desttext=(Text*)window->add(new Text(aguix,tx,ty,""));
   ismessage[1] = true;
   ty+=desttext->getHeight()+5;
-  fsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"",2,3,0));
+  fsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"","button-special1-fg", "button-special1-bg",0));
   sbw=fsb->getWidth();
   bb1=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,fsb->getHeight()+2,1));
   fsb->toFront();
   ty+=bb1->getHeight()+5;
   tx=10;
-  filetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  filetext=(Text*)window->add(new Text(aguix,tx,ty,""));
   ty+=filetext->getHeight()+5;
 
-  ttext = (Text*)window->add( new Text( aguix, tx, ty, catalog.getLocale( 90 ), 1 ) );
+  ttext = (Text*)window->add( new Text( aguix, tx, ty, catalog.getLocale( 90 ) ) );
   tx += ttext->getWidth() + 5;
-  fileavgtext = (Text*)window->add( new Text( aguix, tx, ty, "", 1 ) );
+  fileavgtext = (Text*)window->add( new Text( aguix, tx, ty, "" ) );
   ty += fileavgtext->getHeight() + 5;
 
   tx=5;
   bb2=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb2->getHeight()+5;
 
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(118),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(118)));
   tx+=ttext->getWidth()+5;
-  files2gotext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  files2gotext=(Text*)window->add(new Text(aguix,tx,ty,""));
   tx=5;
   ty+=ttext->getHeight()+5;
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(119),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(119)));
   tx+=ttext->getWidth()+5;
-  dirs2gotext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  dirs2gotext=(Text*)window->add(new Text(aguix,tx,ty,""));
   tx=5;
   ty+=ttext->getHeight()+5;
-  gsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"",2,3,0));
+  gsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"","button-special1-fg", "button-special1-bg",0));
   bb3=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,gsb->getHeight()+2,1));
   gsb->toFront();
   ty+=bb3->getHeight()+5;
   tx=10;
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(120),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(120)));
   tx+=ttext->getWidth()+5;
-  globtext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  globtext=(Text*)window->add(new Text(aguix,tx,ty,""));
   tx=5;
   ty+=globtext->getHeight()+5;
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(121),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(121)));
   tx+=ttext->getWidth()+5;
-  timetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  timetext=(Text*)window->add(new Text(aguix,tx,ty,""));
   ty+=timetext->getHeight()+5;
   tx=5;
   bb4=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb4->getHeight()+5;
 
-  m_detach_b = (Button*)window->add( new Button( aguix, tx, ty, catalog.getLocale( 1039 ), 1, 0, 0 ) );
+  m_detach_b = (Button*)window->add( new Button( aguix, tx, ty, catalog.getLocale( 1039 ), 0 ) );
 
   m_keep_window_cb = (ChooseButton*)window->add( new ChooseButton( aguix, tx, ty,
                                                                    m_keep_window,
                                                                    catalog.getLocale( 1047 ),
-                                                                   LABEL_RIGHT, 1, 0 ) );
+                                                                   LABEL_RIGHT, 0 ) );
   m_keep_window_cb->hide();
 
-  cb = (Button*)window->add( new Button( aguix, tx, ty, catalog.getLocale( 8 ), 1, 0, 0 ) );
+  cb = (Button*)window->add( new Button( aguix, tx, ty, catalog.getLocale( 8 ), 0 ) );
   cb->move( w - 5 - cb->getWidth(), cb->getY() );
 
   ty+=cb->getHeight()+5;
@@ -663,8 +663,8 @@ int CopyOpWin::handleMessage( AGMessage *msg )
             if ( msg->choose.button == m_keep_window_cb ) {
                 m_keep_window = m_keep_window_cb->getState();
 
-                Worker::getKVPStore().setIntValue( "copy-keep-window",
-                                                   ( m_keep_window ? 2 : 1 ) );
+                Worker::getPersKVPStore().setIntValue( "copy-keep-window",
+                                                       ( m_keep_window ? 2 : 1 ) );
             }
             break;
         case AG_SIZECHANGED:
