@@ -1,6 +1,6 @@
 /* copyorder.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2014 Ralf Hoffmann.
+ * Copyright (C) 2014-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,6 +31,8 @@ copyorder::copyorder()
       do_rename( false ),
       preserve_attr( true ),
       overwrite( COPY_OVERWRITE_NORMAL ),
+      adjust_relative_symlinks( COPY_ADJUST_SYMLINK_NEVER ),
+      ensure_file_permissions( CopyParams::LEAVE_PERMISSIONS_UNMODIFIED ),
       cowin( NULL ),
       error( 0 ),
       ignoreLosedAttr( false )
