@@ -1291,3 +1291,23 @@ size_t Datei::read( char *buffer, size_t len )
 CopyfileProgressCallback::~CopyfileProgressCallback()
 {
 }
+
+bool Datei::lock()
+{
+    if ( fd < 0 ) return false;
+
+#ifdef HAVE_LOCKF
+    if ( lockf( fd, F_LOCK, 0 ) == 0 ) {
+        return true;
+    }
+#endif
+
+    return false;
+}
+
+void Datei::unlock()
+{
+#ifdef HAVE_LOCKF
+    lockf( fd, F_ULOCK, 0 );
+#endif
+}
