@@ -100,6 +100,9 @@ public:
   void configCloseSection();
 
   size_t read( char *buffer, size_t len );
+
+    bool lock();
+    void unlock();
 private:
   int fd;
   long error;
