@@ -1,6 +1,6 @@
 /* dirbookmarkaddui.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2008,2013 Ralf Hoffmann.
+ * Copyright (C) 2007-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -47,7 +47,7 @@ DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
     m_win = std::unique_ptr<AWindow>( new AWindow( &m_aguix,
                                                    0, 0,
                                                    400, 400,
-                                                   0, catalog.getLocaleCom( 51 ),
+                                                   catalog.getLocaleCom( 51 ),
                                                    AWindow::AWINDOW_DIALOG ) );
     m_win->create();
 
@@ -60,15 +60,13 @@ DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
                               strlen( dirname.c_str() ) + 1 );
     sprintf( tstr, catalog.getLocale( 756 ), dirname.c_str() );
 
-    co1_1->add( new Text( &m_aguix, 0, 0, tstr, 1 ),
+    co1_1->add( new Text( &m_aguix, 0, 0, tstr ),
                 0, 0, AContainer::CO_INCW );
     _freesafe( tstr );
     m_okb_op1 = (Button*)co1_1->add( new Button( &m_aguix,
                                                  0,
                                                  0,
                                                  catalog.getLocale( 11 ),
-                                                 1,
-                                                 0,
                                                  0 ), 0, 1, AContainer::CO_INCW );
 
     if ( basename.length() > 0 ) {
@@ -78,7 +76,7 @@ DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
                                   strlen( dirname.c_str() ) + 1 );
         sprintf( tstr, catalog.getLocale( 756 ), dirname.c_str() );
         
-        co1_2->add( new Text( &m_aguix, 0, 0, tstr, 1 ),
+        co1_2->add( new Text( &m_aguix, 0, 0, tstr ),
                     0, 0, AContainer::CO_INCW );
         _freesafe( tstr );
         
@@ -87,15 +85,13 @@ DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
         sprintf( tstr, catalog.getLocale( 757 ),
                  basename.c_str() );
         
-        co1_2->add( new Text( &m_aguix, 0, 0, tstr, 1 ),
+        co1_2->add( new Text( &m_aguix, 0, 0, tstr ),
                     0, 1, AContainer::CO_INCW );
         _freesafe( tstr );
         m_okb_op2 = (Button*)co1_2->add( new Button( &m_aguix,
                                                      0,
                                                      0,
                                                      catalog.getLocale( 11 ),
-                                                     1,
-                                                     0,
                                                      0 ), 0, 2, AContainer::CO_INCW );
     }
 
@@ -110,15 +106,13 @@ DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
                                       strlen( s1.c_str() ) + 1 );
             sprintf( tstr, catalog.getLocale( 756 ), s1.c_str() );
             
-            co1_3->add( new Text( &m_aguix, 0, 0, tstr, 1 ),
+            co1_3->add( new Text( &m_aguix, 0, 0, tstr ),
                         0, 0, AContainer::CO_INCW );
             _freesafe( tstr );
             m_okb_op3 = (Button*)co1_3->add( new Button( &m_aguix,
                                                          0,
                                                          0,
                                                          catalog.getLocale( 11 ),
-                                                         1,
-                                                         0,
                                                          0 ), 0, 1, AContainer::CO_INCW );
         }
     }
@@ -127,8 +121,6 @@ DirBookmarkAddUI::DirBookmarkAddUI( AGUIX &aguix, BookmarkDBProxy &data,
                                                0,
                                                0,
                                                catalog.getLocale( 8 ),
-                                               1,
-                                               0,
                                                0 ), 0, 3, AContainer::CO_INCW );
 
     m_win->contMaximize( true, true );
