@@ -21,7 +21,6 @@
 
 #include "dirbookmarkop.hh"
 #include "listermode.h"
-#include "normalmode.h"
 #include "ownop.h"
 #include "bookmarkdb.hh"
 #include "bookmarkdbentry.hh"
@@ -34,6 +33,7 @@
 #include "worker.h"
 #include "worker_locale.h"
 #include "fileentry.hh"
+#include "argclass.hh"
 
 const char *DirBookmarkOp::name = "DirBookmarkOp";
 
@@ -68,7 +68,6 @@ int DirBookmarkOp::run( WPUContext *wpu, ActionMessage *msg )
 {
     Lister *l1;
     ListerMode *lm1;
-    NormalMode *nm1;
     
     l1 = msg->getWorker()->getActiveLister();
     if ( l1 == NULL )
@@ -81,23 +80,20 @@ int DirBookmarkOp::run( WPUContext *wpu, ActionMessage *msg )
     DirBookmarkUI ui( *Worker::getAGUIX(), bookmarks );
 
     lm1 = l1->getActiveMode();
-    if ( lm1 != NULL && lm1->isType( "NormalMode" ) == true ) {
-        nm1 = (NormalMode*)lm1;
-            
-        std::list<NM_specialsourceExt*> sellist;
-        nm1->getSelFiles( &sellist, NormalMode::NM_GETFILES_ONLYACTIVE );
+    if ( lm1 != NULL ) {
+        std::list< NM_specialsourceExt > sellist;
+        lm1->getSelFiles( sellist, ListerMode::LM_GETFILES_ONLYACTIVE );
             
         std::string dirname, basename;
 
-        if ( nm1->getCurrentDir() != NULL )
-            dirname = nm1->getCurrentDir();
+        dirname = lm1->getCurrentDirectory();
 
         if ( sellist.empty() == false ) {
-            if ( (*sellist.begin())->entry() != NULL ) {
-                basename = (*sellist.begin())->entry()->name;
+            if ( (*sellist.begin()).entry() != NULL ) {
+                basename = (*sellist.begin()).entry()->name;
+                dirname = NWC::Path::dirname( sellist.begin()->entry()->fullname );
             }
         }
-        nm1->freeSelFiles( &sellist );
             
         ui.setCurrentDirname( dirname );
         ui.setCurrentBasename( basename );
@@ -107,6 +103,10 @@ int DirBookmarkOp::run( WPUContext *wpu, ActionMessage *msg )
         try {
             BookmarkDBEntry sel_entry = ui.getSelectedEntry();
 
+            // enable path jump in progress flag so the next entry used
+            // will be stored in path jump DB too
+            msg->getWorker()->setPathJumpInProgress( ui.getFilterString() );
+
             std::string dir = sel_entry.getName();
             std::string highlight_entry;
                 
@@ -117,15 +117,16 @@ int DirBookmarkOp::run( WPUContext *wpu, ActionMessage *msg )
                 dir = fse.getDirname();
             }
 
-            l1->switch2Mode( 0 );
-            lm1 = l1->getActiveMode();
-            if ( lm1 != NULL && lm1->isType( "NormalMode" ) == true ) {
-                nm1 = (NormalMode*)lm1;
-                    
-                nm1->enterPath( dir );
-                if ( highlight_entry.empty() == false ) {
-                    nm1->activateEntry( highlight_entry );
-                }
+            std::list< RefCount< ArgClass > > args;
+
+            args.push_back( new StringArg( dir ) );
+            lm1->runCommand( "enter_dir", args );
+
+            args.clear();
+
+            if ( ! highlight_entry.empty() ) {
+                args.push_back( new StringArg( highlight_entry ) );
+                lm1->runCommand( "activate_entry", args );
             }
         } catch ( int ) {
         }
