@@ -46,7 +46,7 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
     m_win = std::unique_ptr<AWindow>( new AWindow( &m_aguix,
                                                    0, 0,
                                                    400, 400,
-                                                   0, catalog.getLocaleCom( 51 ) ) );
+                                                   catalog.getLocaleCom( 51 ) ) );
     m_win->create();
 
     m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 5 ), true );
@@ -55,15 +55,15 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
     AContainer *co1_2 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
     co1_2->setMaxSpace( 5 );
     co1_2->setBorderWidth( 0 );
-    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ), 1 ),
+    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ) ),
                 0, 0, AContainer::CO_FIX );
-    m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "", 1 ),
+    m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "" ),
                                                   1, 0, AContainer::CO_INCW ) );
     
     AContainer *co1_5 = m_co1->add( new AContainer( m_win.get(), 3, 1 ), 0, 1 );
     co1_5->setMaxSpace( 5 );
     co1_5->setBorderWidth( 0 );
-    co1_5->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 822 ), 1 ),
+    co1_5->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 822 ) ),
                 0, 0, AContainer::CO_FIX );
 
     AContainer *co1_5_1 = co1_5->add( new AContainer( m_win.get(), 3, 1 ), 1, 0 );
@@ -71,11 +71,11 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
     co1_5_1->setMinSpace( 0 );
     co1_5_1->setBorderWidth( 0 );
     m_prev_cat_b = (Button*)co1_5_1->add( new Button( &m_aguix, 0, 0,
-                                                      "<", 1, 0, 0 ), 0, 0, AContainer::CO_FIX );
+                                                      "<", 0 ), 0, 0, AContainer::CO_FIX );
     m_cat_sb = dynamic_cast<SolidButton*>( co1_5_1->add( new SolidButton( &m_aguix, 0, 0,
-                                                                          "", 1, 0, true ), 1, 0, AContainer::CO_INCW ) );
+                                                                          "", true ), 1, 0, AContainer::CO_INCW ) );
     m_next_cat_b = (Button*)co1_5_1->add( new Button( &m_aguix, 0, 0,
-                                                      ">", 1, 0, 0 ), 2, 0, AContainer::CO_FIX );
+                                                      ">", 0 ), 2, 0, AContainer::CO_FIX );
     
     m_lv = static_cast<FieldListView*>( m_co1->add( new FieldListView( &m_aguix, 
                                                                      0, 0, 
@@ -104,24 +104,18 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
                                               0,
                                               0,
                                               catalog.getLocale( 759 ),
-                                              1,
-                                              0,
                                               0 ), 0, 0, AContainer::CO_FIX );
 
     m_editb = (Button*)co1_4->add( new Button( &m_aguix,
                                                0,
                                                0,
                                                catalog.getLocale( 805 ),
-                                               1,
-                                               0,
                                                0 ), 1, 0, AContainer::CO_FIX );
 
     m_delb = (Button*)co1_4->add( new Button( &m_aguix,
                                               0,
                                               0,
                                               catalog.getLocale( 760 ),
-                                              1,
-                                              0,
                                               0 ), 2, 0, AContainer::CO_FIX );
 
     AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 4 );
@@ -132,15 +126,11 @@ DirBookmarkUI::DirBookmarkUI( AGUIX &aguix, BookmarkDBProxy &data  ) : m_aguix(
                                              0,
                                              0,
                                              catalog.getLocale( 761 ),
-                                             1,
-                                             0,
                                              0 ), 0, 0, AContainer::CO_FIX );
     m_cancelb = (Button*)co1_3->add( new Button( &m_aguix,
                                                  0,
                                                  0,
                                                  catalog.getLocale( 633 ),
-                                                 1,
-                                                 0,
                                                  0 ), 1, 0, AContainer::CO_FIX );
 
     m_win->contMaximize( true );
