@@ -1,6 +1,6 @@
 /* dirfiltersets.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2007-2008,2013 Ralf Hoffmann.
+ * Copyright (C) 2007-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -52,117 +52,6 @@ DirFilterSettings::DirFilterSettings( const DirFilterSettings &other ) :
 {
 }
 
-bool DirFilterSettings::check( FileEntry &e )
-{
-    bool use = true;
-
-    if ( _show_hidden == false &&
-         e.isHidden == true &&
-         strcmp( e.name, ".." ) != 0 ) {
-        
-        use = false;
-    }
-
-    if ( use == true ) {
-        if ( _string_filter.get() != NULL &&
-             strcmp( e.name, ".." ) != 0 ) {
-            if ( _string_filter->match( e.name ) == false )
-                use = false;
-        }
-    }
-
-    if ( use == true ) {
-        bool isIn;
-        
-        std::list<NM_Filter>::const_iterator it;
-        
-        if ( e.isDir() == true ) {
-            // a dir is always visible
-            use = true;
-        } else {
-            if ( _ins > 0 ) isIn = false;
-            else isIn = true;
-            
-            for ( it = _filters.begin();
-                  it != _filters.end();
-                  it++ ) {
-                if ( it->getCheck() > 0 ) {
-                    if ( fnmatch( it->getPattern(), e.name, 0 ) == 0 ) {
-                        if ( it->getCheck() == 1 ) isIn = true;
-                        else isIn = false;
-                        break;
-                    }
-                }
-            }
-            use = isIn;
-        }
-    }
-
-    if ( use == true && m_bookmark_filter != SHOW_ALL ) {
-        if ( m_bookmark_filter == SHOW_ONLY_BOOKMARKS ) {
-            if ( e.getBookmarkMatch() == FileEntry::NOT_IN_BOOKMARKS ) {
-                use = false;
-            }
-        } else if ( m_bookmark_filter == SHOW_ONLY_LABEL ) {
-            if ( e.hasMatchingLabels() == true ) {
-                try {
-                    const std::list<std::string> &labels = e.getMatchingLabels();
-                    
-                    if ( std::find( labels.begin(),
-                                    labels.end(),
-                                    m_bookmark_label ) == labels.end() ) {
-                        use = false;
-                    }
-                } catch ( int ) {
-                    use = false;
-                }
-            } else {
-                use = false;
-            }
-        }
-    }
-
-    if ( use == true ) {
-        bool clear_override = true;
-
-        if ( m_highlight_bookmark_prefix == true || e.getBookmarkMatch() == FileEntry::BOOKMARK ) {
-            if ( e.hasMatchingLabels() == true ) {
-                std::map<std::string, WConfig::ColorDef::label_colors_t>::const_iterator label_it;
-                
-                try {
-                    const std::list<std::string> &matching_labels = e.getMatchingLabels();
-                    const std::map<std::string, WConfig::ColorDef::label_colors_t> &label_colors = wconfig->getColorDefs().getLabelColors();
-                    
-                    if ( matching_labels.empty() == false ) {
-                        if ( m_bookmark_filter != SHOW_ONLY_LABEL ) {
-                            label_it = label_colors.find( matching_labels.front() );
-                        } else {
-                            label_it = label_colors.find( m_bookmark_label );
-                        }
-                        if ( label_it != label_colors.end() ) {
-                            WConfig::ColorDef::label_colors_t col = label_it->second;
-                            e.setOverrideColor( FileEntryCustomColor::NORMAL,
-                                                col.normal_fg,
-                                                col.normal_bg );
-                            e.setOverrideColor( FileEntryCustomColor::ACTIVE,
-                                                col.active_fg,
-                                                col.active_bg );
-                            clear_override = false;
-                        }
-                    }
-                } catch ( int ) {
-                }
-            }
-        }
-        if ( clear_override == true ) {
-            e.clearOverrideColor();
-        }
-    }
-
-    e.use = use;
-    return use;
-}
-
 bool DirFilterSettings::check( const std::string &dirname,
                                NWCEntrySelectionState &es )
 {
@@ -195,6 +84,16 @@ bool DirFilterSettings::check( const std::string &dirname,
         }
     }
 
+    if ( use == true ) {
+        if ( m_generic_filter.get() != NULL &&
+             e->getBasename() != ".." ) {
+
+            if ( m_generic_filter->check( es ) == false ) {
+                use = false;
+            }
+        }
+    }
+
     if ( use == true ) {
         bool isIn;
         
@@ -390,6 +289,13 @@ void DirFilterSettings::setStringFilter( std::unique_ptr<StringMatcher> filter )
     _serial_nr++;
 }
 
+void DirFilterSettings::setGenericFilter( std::unique_ptr< GenericDirectoryFilter > filter )
+{
+    m_generic_filter = std::move( filter );
+
+    _serial_nr++;
+}
+
 void DirFilterSettings::bookmarksChanged()
 {
     _serial_nr++;
