@@ -161,7 +161,9 @@ int EnterDirOp::run( WPUContext *wpu, ActionMessage *msg )
 
                     lm1->getSelFiles( extfilelist, ListerMode::LM_GETFILES_ONLYACTIVE );
                     for ( auto &ss1 : extfilelist ) {
-                        entry_fullname = ss1.entry()->fullname;
+                        if ( ss1.entry() ) {
+                            entry_fullname = ss1.entry()->fullname;
+                        }
                     }
 
                     if ( ! entry_fullname.empty() ) {
@@ -211,7 +213,7 @@ int EnterDirOp::configure()
     tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) +
                               strlen( catalog.getLocaleCom( 18 ) ) + 1 );
     sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 18 ) );
-    win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+    win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
     win->create();
     _freesafe( tstr );
 
@@ -224,8 +226,8 @@ int EnterDirOp::configure()
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 0 );
 
-    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 317 ), 1 ), 0, 0, cfix );
-    rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+    ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 317 ) ), 0, 0, cfix );
+    rcyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
     rcyb->addOption( catalog.getLocale( 318 ) );
     rcyb->addOption( catalog.getLocale( 319 ) );
     rcyb->addOption( catalog.getLocale( 320 ) );
@@ -252,7 +254,7 @@ int EnterDirOp::configure()
     ac1_2->setMaxSpace( 0 );
     ac1_2->setBorderWidth( 0 );
 
-    ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 322 ), 1 ), 0, 0, cfix );
+    ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 322 ) ), 0, 0, cfix );
     ac1_2->setMinWidth( 5, 1, 0 );
     ac1_2->setMaxWidth( 5, 1, 0 );
     sg = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, dir, 0 ), 2, 0, cincw );
@@ -260,8 +262,6 @@ int EnterDirOp::configure()
                                                    0,
                                                    0,
                                                    "F",
-                                                   1,
-                                                   0,
                                                    0 ), 3, 0, cfix );
     sgb->resize( sgb->getWidth(), sg->getHeight() );
     ac1_2->readLimits();
@@ -274,15 +274,11 @@ int EnterDirOp::configure()
                                                   0,
                                                   0,
                                                   catalog.getLocale( 11 ),
-                                                  1,
-                                                  0,
                                                   0 ), 0, 0, cfix );
     Button *cb = (Button*)ac1_3->add( new Button( aguix,
                                                   0,
                                                   0,
                                                   catalog.getLocale( 8 ),
-                                                  1,
-                                                  0,
                                                   0 ), 1, 0, cfix );
 
     win->setDoTabCycling( true );
