@@ -1,6 +1,6 @@
 /* execlass.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2002-2008 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2002-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: execlass.cc,v 1.17 2005/07/13 19:56:15 ralf Exp $ */
 
 #include "execlass.h"
 #include <stdarg.h>
@@ -142,7 +141,7 @@ void ExeClass::addCommand( const char *format, ... )
               and if wconfig THREADSAFE or type !=TERMINAL */
 void ExeClass::execute()
 {
-  char *exestr = NULL;
+  std::string exestr;
   int error = 0;
   
   if ( fp == NULL ) return;
@@ -155,11 +154,11 @@ void ExeClass::execute()
       if ( fprintf( fp, "echo %s\n", catalog.getLocale( 201 ) ) < 0 ) error++;
       if ( fprintf( fp, "read x\n" ) < 0 ) error++;
     }
-    exestr = (char*)_allocsafe( strlen( wconfig->getTerminalStr() ) +
-                                strlen( tmpfile ) + 1 );
-    sprintf( exestr, wconfig->getTerminalStr(), tmpfile );
+    exestr = AGUIXUtils::formatStringToString( wconfig->getTerminalStr(),
+                                               tmpfile );
   } else {
-    exestr = dupstring( tmpfile );
+      exestr = "/bin/sh ";
+      exestr += tmpfile;
   }
   if ( type == EXECUTE_SHOW_OUTPUT ) {
     if ( fprintf( fp, OUTPUT_BIN, tmpoutput ) < 0 ) error++;
@@ -169,11 +168,10 @@ void ExeClass::execute()
   fp = NULL;
 
   if ( error == 0 ) {
-      (void)system( exestr );
+      (void)system( exestr.c_str() );
   } else {
     //TODO show requests?
   }
-  _freesafe(exestr);
 
   if ( worker != NULL ) worker->unsetWaitCursor();
 }
@@ -229,7 +227,8 @@ int ExeClass::getOutputAndRV( char **return_output, int *return_value, int *retu
   }
   fp = NULL;
 
-  exestr = tmpfile;
+  exestr = "/bin/sh ";
+  exestr += tmpfile;
   exestr += " >";
   exestr += tmpoutput;
   exestr += " 2>";
