@@ -1,6 +1,6 @@
 /* fileentry_typecheck.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2010-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -83,29 +83,22 @@ FileEntryTypeCheck::typecandidate_t FileEntryTypeCheck::runTests( FileEntry &fe,
             
             if ( erg.type == NULL && type->getUseMagic() == true ) {
                 erg.tests_done++;
-                if ( type->getMagicCompressed() == true ) {
-                    if ( temp_results.magic_avail_compressed == false ) {
-                        if ( worker_islocal( fe.fullname ) == true ) {
-                            temp_results.magic_result_compressed = MagicDB::getInstance().getInfo( fe.fullname, true );
-                        } else {
-                            temp_results.magic_result_compressed = MagicDB::getInstance().getInfo( fbuffer, reads, true );
-                        }
-                        temp_results.magic_avail_compressed = true;
-                    }
-                } else {
-                    if ( temp_results.magic_avail == false ) {
-                        if ( worker_islocal( fe.fullname ) == true ) {
-                            temp_results.magic_result = MagicDB::getInstance().getInfo( fe.fullname );
-                        } else {
-                            temp_results.magic_result = MagicDB::getInstance().getInfo( fbuffer, reads );
-                        }
-                        temp_results.magic_avail = true;
+
+                int array_pos = 0;
+
+                if ( type->getMagicCompressed() == true ) array_pos += 1;
+                if ( type->getMagicMime() == true ) array_pos += 2;
+
+                if ( temp_results.magic_avail[array_pos] == false ) {
+                    if ( worker_islocal( fe.fullname ) == true ) {
+                        temp_results.magic_result[array_pos] = MagicDB::getInstance().getInfo( fe.fullname, type->getMagicCompressed(), type->getMagicMime() );
+                    } else {
+                        temp_results.magic_result[array_pos] = MagicDB::getInstance().getInfo( fbuffer, reads, type->getMagicCompressed(), type->getMagicMime() );
                     }
+                    temp_results.magic_avail[array_pos] = true;
                 }
                 
-                if ( type->magicMatch( ( type->getMagicCompressed() == true ) ?
-                                       temp_results.magic_result_compressed :
-                                       temp_results.magic_result ) == true ) {
+                if ( type->magicMatch( temp_results.magic_result[array_pos] ) == true ) {
                     erg.prio = 3;
                     erg.type = type;
                 }
