@@ -1,6 +1,6 @@
 /* fileviewerbg.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010-2014 Ralf Hoffmann.
+ * Copyright (C) 2010-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -46,8 +46,11 @@ FileViewerBG::FileViewerBG() : win( NULL ),
                                wcb( NULL ),
                                slncb( NULL ),
                                jumplineb( NULL ),
-                               readmoreb( NULL )
-
+                               readmoreb( NULL ),
+                               m_next_match_b( NULL ),
+                               m_prev_match_b( NULL ),
+                               m_restart_search_b( NULL ),
+                               m_find_pos_text( NULL )
 {
 }
 
@@ -88,7 +91,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
         win->setTransientForAWindow( aguix->getTransientWindow() );
         }*/
 
-    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
+    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
 
@@ -100,6 +103,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     Text *fnt = (Text*)ac1_1->add( new Text( aguix, 0, 0, "" ), 1, 0, AContainer::ACONT_MINH + AContainer::ACONT_MAXH );
     readmoreb = (Button*)ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 763 ), 0 ),
                                      2, 0, cfix );
+    readmoreb->setBubbleHelpText( catalog.getLocale( 1146 ) );
 
     fnt->setTextShrinker( RefCount<TextShrinker>( new FileNameShrinker() ) );
 
@@ -118,7 +122,7 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
     ac1->readLimits();
     ac1_1->readLimits();
 
-    AContainer *ac1_3 = ac1->add( new AContainer( win, 5, 1 ), 0, 2 );
+    AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 3 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -131,25 +135,62 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
                                                        m_wrap_mode, catalog.getLocale( 637 ),
                                                        LABEL_RIGHT, 0 ),
                                      0, 0, cincwnr );
+    wcb->setBubbleHelpText( catalog.getLocale( 1147 ) );
     slncb = (ChooseButton*)ac1_3->add( new ChooseButton( aguix, 0, 0,
                                                          m_showlinenumbers_mode, catalog.getLocale( 715 ),
                                                          LABEL_RIGHT, 0 ),
                                        1, 0, cincwnr );
+    slncb->setBubbleHelpText( catalog.getLocale( 1148 ) );
     jumplineb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 716 ), 2 ),
                                      2, 0, cfix );
-
-    AContainer *ac1_3_1 = ac1_3->add( new AContainer( win, 2, 1 ), 3, 0 );
-    ac1_3_1->setMinSpace( 5 );
-    ac1_3_1->setMaxSpace( 5 );
-    ac1_3_1->setBorderWidth( 0 );
-  
-    ac1_3_1->add( new Text( aguix, 0, 0, catalog.getLocale( 790 ) ), 0, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
-    search_sg = (StringGadget*)ac1_3_1->add( new StringGadget( aguix, 0, 0, 60, "", 1 ),
-                                             1, 0, cincw );
+    jumplineb->setBubbleHelpText( catalog.getLocale( 1142 ) );
 
     okb = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 633 ), 2 ),
-                               4, 0, cfix );
+                               3, 0, cfix );
+    okb->setBubbleHelpText( catalog.getLocale( 1143 ) );
 
+    AContainer *ac1_4 = ac1->add( new AContainer( win, 5, 1 ), 0, 2 );
+    ac1_4->setMinSpace( 5 );
+    ac1_4->setMaxSpace( 10 );
+    ac1_4->setBorderWidth( 0 );
+  
+    AContainer *ac1_4_1 = ac1_4->add( new AContainer( win, 2, 1 ), 0, 0 );
+    ac1_4_1->setMinSpace( 5 );
+    ac1_4_1->setMaxSpace( 5 );
+    ac1_4_1->setBorderWidth( 0 );
+  
+    ac1_4_1->add( new Text( aguix, 0, 0, catalog.getLocale( 790 ) ), 0, 0, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+    search_sg = (StringGadget*)ac1_4_1->add( new StringGadget( aguix, 0, 0, 60, "", 1 ),
+                                             1, 0, cincw );
+    search_sg->setBubbleHelpText( catalog.getLocale( 1149 ) );
+
+    m_next_match_b = ac1_4->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1136 ), 2 ),
+                                       1, 0, cfix );
+    m_next_match_b->setBubbleHelpText( catalog.getLocale( 1144 ) );
+    m_prev_match_b = ac1_4->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1137 ), 2 ),
+                                       2, 0, cfix );
+    m_prev_match_b->setBubbleHelpText( catalog.getLocale( 1145 ) );
+    m_restart_search_b = ac1_4->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 1138 ), 2 ),
+                                           3, 0, cfix );
+
+    AContainer *ac1_4_2 = ac1_4->add( new AContainer( win, 2, 1 ), 4, 0 );
+    ac1_4_2->setMinSpace( 5 );
+    ac1_4_2->setMaxSpace( 5 );
+    ac1_4_2->setBorderWidth( 0 );
+  
+    ac1_4_2->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1139 ) ), 0, 0, AContainer::CO_FIX );
+    m_find_pos_text = ac1_4_2->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 1140 ) ),
+                                          1, 0, AContainer::CO_INCW );
+    {
+        std::string info = AGUIXUtils::formatStringToString( catalog.getLocale( 1141 ), 1000000000 );
+        int tw = aguix->getTextWidth( info.c_str() );
+
+        if ( tw > m_find_pos_text->getWidth() ) {
+            m_find_pos_text->resize( tw, m_find_pos_text->getHeight() );
+            ac1_4_2->readLimits();
+        }
+    }
+    
     win->setDoTabCycling( true );
     win->contMaximize( true );
   
@@ -179,6 +220,8 @@ void FileViewerBG::view( const std::list<std::string> &filelist,
         readmoreb->hide();
     }
 
+    m_find_pos_text->setText( "" );
+    
     win->useStippleBackground();
     win->centerScreen();
     win->show();
@@ -198,7 +241,7 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                 endmode = 0;
             }
             break;
-	case AG_CHOOSECLICKED:
+        case AG_CHOOSECLICKED:
             if ( msg.choose.button == wcb ) {
                 tv->setLineWrap( msg.choose.state );
             } else if ( msg.choose.button == slncb ) {
@@ -225,6 +268,12 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                 if ( ts->incompleteFile() == false ) {
                     readmoreb->hide();
                 }
+            } else if ( msg.button.button == m_next_match_b ) {
+                nextMatch();
+            } else if ( msg.button.button == m_prev_match_b ) {
+                nextMatch( true );
+            } else if ( msg.button.button == m_restart_search_b ) {
+                restartSearchFromTop();
             }
             break;
             /*        case AG_KEYPRESSED:
@@ -232,23 +281,24 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                       break;*/
 	case AG_KEYPRESSED:
             if ( /*ignore_key_release == false && */win->isParent( msg.key.window, false ) == true ) {
-                wcb->setState( tv->getLineWrap() );
-                slncb->setState( tv->getShowLineNumbers() );
                 switch ( msg.key.key ) {
                     case XK_q:
                     case XK_F3:
                     case XK_F10:
                         endmode = 0;
                         break;
-                    case XK_Escape:
-                        if ( search_sg->isActive() == false ) {
-                            //TODO that is time critical, it may already be inactive
-                            endmode = 0;
-                        }
-                        break;
                     case XK_l:
                         if ( ( msg.key.keystate & ( ControlMask | Mod1Mask ) ) != 0 ) {
                             jumpToLine();
+                        } else if ( KEYSTATEMASK( msg.key.keystate ) == 0 &&
+                                    ! tv->getHasFocus() ) {
+                            tv->setShowLineNumbers( ( tv->getShowLineNumbers() == true ) ? false : true );
+                        }
+                        break;
+                    case XK_w:
+                        if ( KEYSTATEMASK( msg.key.keystate ) == 0 &&
+                             ! tv->getHasFocus() ) {
+                            tv->setLineWrap( ( tv->getLineWrap() == true ) ? false : true );
                         }
                         break;
                     case XK_r:
@@ -289,10 +339,17 @@ void FileViewerBG::handleAGUIXMessage( AGMessage &msg )
                             nextMatch();
                         }
                         break;
+                    case XK_p:
+                        if ( KEYSTATEMASK( msg.key.keystate ) == 0 ) {
+                            nextMatch( true );
+                        }
+                        break;
                     case XK_Return:
                         nextMatch();
                         break;
                 }
+                wcb->setState( tv->getLineWrap() );
+                slncb->setState( tv->getShowLineNumbers() );
             }
             break;
         case AG_STRINGGADGET_OK:
@@ -458,11 +515,29 @@ void FileViewerBG::jumpToLine()
         _freesafe( return_str );
 }
 
-void FileViewerBG::nextMatch()
+void FileViewerBG::nextMatch( bool backwards )
 {
-    ts_search->search( search_sg->getText() );
+    if ( backwards ) {
+        ts_search->searchBackwards( search_sg->getText() );
+    } else {
+        ts_search->search( search_sg->getText() );
+    }
     ts_search->highlightCurMatch( *tv );
     tv->makeSelectionVisible();
+
+    if ( strlen( search_sg->getText() ) < 1 ) {
+        m_find_pos_text->setText( "" );
+    } else {
+        int match_line = ts_search->getCurMatchLine();
+
+        if ( match_line < 0 ) {
+            m_find_pos_text->setText( catalog.getLocale( 1140 ) );
+        } else {
+            std::string info = AGUIXUtils::formatStringToString( catalog.getLocale( 1141 ), match_line + 1 );
+        
+            m_find_pos_text->setText( info.c_str() );
+        }
+    }
 }
 
 void FileViewerBG::setLineWrap( bool nv )
@@ -484,3 +559,9 @@ bool FileViewerBG::getShowLineNumbers() const
 {
     return m_showlinenumbers_mode;
 }
+
+void FileViewerBG::restartSearchFromTop()
+{
+    ts_search->setSearchStartLine( 0 );
+    nextMatch();
+}
