@@ -279,8 +279,8 @@ void InformationMode::showinfos()
     if(fe->filetype!=NULL) {
       tstr=(char*)_allocsafe(strlen("%s: %s")+
                              strlen(catalog.getLocale(178))+
-                             strlen(fe->filetype->getName())+1);
-      sprintf(tstr,"%s: %s",catalog.getLocale(178),fe->filetype->getName());
+                             strlen(fe->filetype->getName().c_str())+1);
+      sprintf(tstr,"%s: %s",catalog.getLocale(178),fe->filetype->getName().c_str());
     } else {
       if(fe->isDir()==true) {
 //        tstr=(char*)_allocsafe(strlen("%s: %s")+
@@ -289,13 +289,13 @@ void InformationMode::showinfos()
 //        sprintf(tstr,"%s: %s",catalog.getLocale(178),catalog.getLocale(109));
         tstr=(char*)_allocsafe(strlen("%s: %s")+
                                strlen(catalog.getLocale(178))+
-                               strlen(wconfig->getdirtype()->getName())+1);
-        sprintf(tstr,"%s: %s",catalog.getLocale(178),wconfig->getdirtype()->getName());
+                               strlen(wconfig->getdirtype()->getName().c_str())+1);
+        sprintf(tstr,"%s: %s",catalog.getLocale(178),wconfig->getdirtype()->getName().c_str());
       } else {
         tstr=(char*)_allocsafe(strlen("%s: %s")+
                                strlen(catalog.getLocale(178))+
-                               strlen(wconfig->getnotyettype()->getName())+1);
-        sprintf(tstr,"%s: %s",catalog.getLocale(178),wconfig->getnotyettype()->getName());
+                               strlen(wconfig->getnotyettype()->getName().c_str())+1);
+        sprintf(tstr,"%s: %s",catalog.getLocale(178),wconfig->getnotyettype()->getName().c_str());
       }
     }
     lv->setText( 3, 0, tstr);
