@@ -1,6 +1,6 @@
 /* intviewop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2006,2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2005-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -101,9 +101,13 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
     if ( msg->mode == msg->AM_MODE_ONLYACTIVE )
       _tmode = SHOW_ACTIVE_FILE;
     else if ( msg->mode == msg->AM_MODE_DNDACTION ) {
-      filelist.push_back( msg->dndmsg->getFE()->fullname );
+        if ( msg->dndmsg->getFE() ) {
+            filelist.push_back( msg->dndmsg->getFE()->fullname );
+        }
     } else if ( msg->mode == msg->AM_MODE_SPECIAL ) {
-      filelist.push_back( msg->getFE()->fullname );
+        if ( msg->getFE() ) {
+            filelist.push_back( msg->getFE()->fullname );
+        }
     }
 
     if ( filelist.size() < 1 ) {
@@ -111,7 +115,9 @@ InternalViewOp::run( WPUContext *wpu, ActionMessage *msg )
           std::list< NM_specialsourceExt > extfilelist;
           lm1->getSelFiles( extfilelist, ListerMode::LM_GETFILES_ONLYACTIVE );
           for ( auto &ss1 : extfilelist ) {
-              filelist.push_back( ss1.entry()->fullname );
+              if ( ss1.entry() ) {
+                  filelist.push_back( ss1.entry()->fullname );
+              }
           }
 	/*} else if ( _tmode == SHOW_SELECTED_FILES ) {
 	  if ( nm1 != NULL ) {
@@ -213,7 +219,7 @@ InternalViewOp::doconfigure(int mode)
   
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( catalog.getLocaleCom( 49 ) ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), catalog.getLocaleCom( 49 ) );
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe( tstr );
 
@@ -225,8 +231,8 @@ InternalViewOp::doconfigure(int mode)
   ac1_2->setMinSpace( 5 );
   ac1_2->setMaxSpace( 5 );
   ac1_2->setBorderWidth( 0 );
-  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 632 ), 1 ), 0, 0, cfix );
-  cycbm = (CycleButton*)ac1_2->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 632 ) ), 0, 0, cfix );
+  cycbm = (CycleButton*)ac1_2->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
 
   cycbm->addOption( catalog.getLocale( 634 ) );
   cycbm->addOption( catalog.getLocale( 635 ) );
@@ -245,20 +251,18 @@ InternalViewOp::doconfigure(int mode)
   ac1_3->setMinSpace( 5 );
   ac1_3->setMaxSpace( 5 );
   ac1_3->setBorderWidth( 0 );
-  ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 636 ), 1 ), 0, 0, cfix );
+  ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 636 ) ), 0, 0, cfix );
   sgcf = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, _custom_files.c_str(), 0 ),
 				    1, 0, cincw );
   flagb = (Button*)ac1_3->add( new Button( aguix,
 					   0,
 					   0,
 					   "F",
-					   1,
-					   0,
 					   0 ), 2, 0, cfix );
   
   if ( mode == 0 ) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( _request_flags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ),
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ),
 				    0, 2, cincwnr );
   }
 
@@ -270,15 +274,11 @@ InternalViewOp::doconfigure(int mode)
 					 0,
 					 0,
 					 catalog.getLocale( 11 ),
-					 1,
-					 0,
 					 0 ), 0, 0, cfix );
   cancelb = (Button*)ac1_5->add( new Button( aguix,
 					     0,
 					     0,
 					     catalog.getLocale( 8 ),
-					     1,
-                                                     0,
 					     0 ), 1, 0, cfix );
   win->contMaximize( true );
 
