@@ -78,6 +78,9 @@ public:
     bool pathsChanged( const std::set< std::string > changed_paths );
 
     void finalizeBGOps();
+
+    void setLastPath( const std::string &path );
+    std::string getLastPath() const;
 private:
   Worker *parent;
   AGUIX *aguix;
@@ -92,6 +95,8 @@ private:
 
   AContainer *m_cont;
   AContainer *m_mode_cont;
+
+    std::string m_last_path;
 };
 
 #endif
