@@ -1,6 +1,6 @@
 /* listermode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2011-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -46,6 +46,10 @@ void ListerMode::messageHandler(AGMessage *)
 {
 }
 
+void ListerMode::messageHandlerInactive(AGMessage *)
+{
+}
+
 void ListerMode::on()
 {
   parentlister->setActiveMode(this);
@@ -84,6 +88,10 @@ void ListerMode::cyclicfunc(cyclicfunc_mode_t mode)
 {
 }
 
+void ListerMode::cyclicfuncInactive( cyclicfunc_mode_t mode )
+{
+}
+
 const char *ListerMode::getLocaleName()
 {
   return "";
@@ -239,3 +247,7 @@ std::list< std::string > ListerMode::getListOfCommandsWithoutArgs()
 
     return res;
 }
+
+void ListerMode::finalizeBGOps()
+{
+}
