@@ -1,6 +1,6 @@
 /* nwc_dir.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006,2011 Ralf Hoffmann.
+ * Copyright (C) 2006,2011-2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,7 +31,8 @@ namespace NWC
   Dir::Dir( const std::string &fullname,
             bool follow_symlinks ) : FSEntry( fullname ),
                                      _dirtype( VIRTUAL ),
-                                     _follow_symlinks( follow_symlinks )
+                                     _follow_symlinks( follow_symlinks ),
+                                     m_bytes_in_dir( -1 )
   {
     if ( getFullname()[0] == '/' )
       _dirtype = FS_DIR;
@@ -40,16 +41,18 @@ namespace NWC
   Dir::Dir( const FSEntry &other,
             bool follow_symlinks ) : FSEntry( other ),
                                      _dirtype( VIRTUAL ),
-                                     _follow_symlinks( follow_symlinks )
+                                     _follow_symlinks( follow_symlinks ),
+                                     m_bytes_in_dir( -1 )
   {
     if ( getFullname()[0] == '/' )
       _dirtype = FS_DIR;
   }
 
   Dir::Dir( const Dir &other ) : FSEntry( other ),
-                                 _follow_symlinks( other._follow_symlinks )
+                                 _follow_symlinks( other._follow_symlinks ),
+                                 m_bytes_in_dir( other.m_bytes_in_dir )
   {
-    for ( std::list<FSEntry*>::const_iterator it1 = other._subentries.begin();
+    for ( std::vector<FSEntry*>::const_iterator it1 = other._subentries.begin();
           it1 != other._subentries.end(); it1++ ) {
       addEntry( **it1 );
     }
@@ -66,35 +69,45 @@ namespace NWC
     DIR *dir;
     worker_struct_dirent *dirent;
     std::string str1, str2;
+    int res = 0;
 
-    if ( entryExists() == true ) {
-      clearLists();
-
-      if ( isVirtual() == false ) {
-        dir = worker_opendir( getFullname().c_str() );
-        if ( dir != NULL ) {
-          while ( ( dirent = worker_readdir( dir ) ) != NULL) {
-            str1 = dirent->d_name;
-            if ( str1 != ".." && str1 != "." ) {
-              str2 = Path::join( getFullname(), str1 );
-              handleDirEntry( str2 );
+    if ( isVirtual() ) {
+        for ( auto &t_entry : _subentries ) {
+            if ( t_entry ) {
+                t_entry->updateStats();
             }
-          }
-          worker_closedir( dir );
         }
-        _dirtype = FS_DIR_READ;
-      }
+    } else {
+        if ( entryExists() == true ) {
+            clearLists();
+
+            dir = worker_opendir( getFullname().c_str() );
+            if ( dir != NULL ) {
+                while ( ( dirent = worker_readdir( dir ) ) != NULL) {
+                    str1 = dirent->d_name;
+                    if ( str1 != ".." && str1 != "." ) {
+                        str2 = Path::join( getFullname(), str1 );
+                        handleDirEntry( str2 );
+                    }
+                }
+                worker_closedir( dir );
+            } else {
+                res = 1;
+            }
+
+            _dirtype = FS_DIR_READ;
+        }
     }
   
     if ( recursive == true ) {
-      for ( std::list<FSEntry*>::iterator it1 = _subentries.begin(); it1 != _subentries.end(); it1++ ) {
+      for ( std::vector<FSEntry*>::iterator it1 = _subentries.begin(); it1 != _subentries.end(); it1++ ) {
         if ( Dir *direntry = dynamic_cast<Dir*>( *it1 ) ) {
           direntry->readDir( recursive );
         }
       }
     }
 
-    return 0;
+    return res;
   }
 
   void Dir::handleDirEntry( const std::string &filename )
@@ -173,7 +186,7 @@ namespace NWC
 
     dircb.prepareDirWalk( *this, cobj, additional_entries, skip_entries );
 
-    for ( std::list<FSEntry*>::iterator it1 = _subentries.begin();
+    for ( std::vector<FSEntry*>::iterator it1 = _subentries.begin();
           it1 != _subentries.end() && cobj.getMode() != WalkControlObj::ABORT;
           it1++ ) {
 
@@ -209,7 +222,7 @@ namespace NWC
     return cobj;
   }
 
-  int Dir::add( std::auto_ptr<FSEntry> file )
+  int Dir::add( std::unique_ptr<FSEntry> file )
   {
     FSEntry *fileP = file.release();
 
@@ -230,10 +243,13 @@ namespace NWC
 
   int Dir::clearLists()
   {
-    for ( std::list<FSEntry*>::iterator it1 = _subentries.begin(); it1 != _subentries.end(); it1 = _subentries.begin() ) {
+    for ( std::vector<FSEntry*>::iterator it1 = _subentries.begin();
+          it1 != _subentries.end();
+          ++it1 ) {
       delete (*it1);
-      _subentries.pop_front();
     }
+
+    _subentries.clear();
   
     if ( getFullname()[0] == '/' )
       _dirtype = FS_DIR;
@@ -307,7 +323,7 @@ namespace NWC
   int Dir::removeFromList( const std::string &name )
   {
     int found = 0;
-    for ( std::list<FSEntry*>::iterator it1 = _subentries.begin();
+    for ( std::vector<FSEntry*>::iterator it1 = _subentries.begin();
           it1 != _subentries.end();
           it1++ ) {
       if ( (*it1)->getFullname() == name ) {
@@ -322,6 +338,30 @@ namespace NWC
     return found;
   }
 
+    int Dir::removeFromList( const std::string &name, int pos )
+    {
+        int found = 0;
+
+        if ( pos >= 0 && pos < (int)_subentries.size() ) {
+            if ( _subentries[pos]->getFullname() == name ) {
+                auto it = _subentries.begin();
+
+                std::advance( it, pos );
+
+                _subentries.erase( it );
+
+                makeVirtual();
+                found = 1;
+            }
+        }
+
+        if ( ! found ) {
+            return removeFromList( name );
+        }
+
+        return found;
+    }
+
   void Dir::setFollowSymlinks( bool nv )
   {
     _follow_symlinks = nv;
@@ -336,11 +376,39 @@ namespace NWC
   {
       std::list< std::string > l;
 
-      for ( std::list<FSEntry*>::const_iterator it1 = _subentries.begin();
+      for ( std::vector<FSEntry*>::const_iterator it1 = _subentries.begin();
             it1 != _subentries.end();
             it1++ ) {
           l.push_back( (*it1)->getFullname() );
       }
       return l;
   }
+
+    FSEntry *Dir::getEntryAtPos( int pos )
+    {
+        if ( pos < 0 || pos >= (int)_subentries.size() ) return NULL;
+
+        return _subentries[pos];
+    }
+
+    loff_t Dir::getBytesInDir() const
+    {
+        return m_bytes_in_dir;
+    }
+
+    void Dir::setBytesInDir( loff_t bytes )
+    {
+        m_bytes_in_dir = bytes;
+    }
+
+    int Dir::changeBasenameOfEntry( const std::string &newbasename,
+                                    int pos,
+                                    bool keep_dirtype )
+    {
+        if ( pos < 0 || pos >= (int)_subentries.size() ) return 1;
+
+        if ( ! keep_dirtype ) makeVirtual();
+
+        return _subentries[pos]->changeBasename( newbasename );
+    }
 }
