@@ -1,6 +1,6 @@
 /* ownop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -193,7 +193,7 @@ OwnOp::configure()
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(28))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(28));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -202,22 +202,22 @@ OwnOp::configure()
   ac1->setMaxSpace( 5 );
 
   scb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( separate_each_entry == true ) ? 1 : 0,
-						   catalog.getLocale( 329 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+						   catalog.getLocale( 329 ), LABEL_RIGHT, 0 ), 0, 0, cincwnr );
 
   rcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( recursive == true ) ? 1 : 0,
-						   catalog.getLocale( 330 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						   catalog.getLocale( 330 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   tdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( take_dirs == true ) ? 1 : 0,
-                                                    catalog.getLocale( 513 ), LABEL_RIGHT, 1, 0 ), 0, 2, cincwnr );
+                                                    catalog.getLocale( 513 ), LABEL_RIGHT, 0 ), 0, 2, cincwnr );
 
   dcdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( dontcd == true ) ? 1 : 0,
-						     catalog.getLocale( 617 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
+						     catalog.getLocale( 617 ), LABEL_RIGHT, 0 ), 0, 3, cincwnr );
 
   ChooseButton* virtualcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( m_use_virtual_temp_copies == true ) ? 1 : 0,
-                                                                       catalog.getLocale( 964 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
+                                                                       catalog.getLocale( 964 ), LABEL_RIGHT, 0 ), 0, 4, cincwnr );
 
   ChooseButton* relflagscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( m_flags_are_relative_to_base_dir == true ) ? 1 : 0,
-                                                                        catalog.getLocale( 1001 ), LABEL_RIGHT, 1, 0 ), 0, 5, cincwnr );
+                                                                        catalog.getLocale( 1001 ), LABEL_RIGHT, 0 ), 0, 5, cincwnr );
 
   ibcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
                                                     0,
@@ -225,7 +225,6 @@ OwnOp::configure()
                                                     ( inbackground == true ) ? 1 : 0,
                                                     catalog.getLocale( 435 ),
                                                     LABEL_RIGHT,
-                                                    1,
                                                     0 ), 0, 6, cincwnr );
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 7 );
@@ -233,8 +232,8 @@ OwnOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 331 ), 1 ), 0, 0, cfix );
-  cyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 331 ) ), 0, 0, cfix );
+  cyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   cyb->addOption(catalog.getLocale(332));
   cyb->addOption(catalog.getLocale(333));
   cyb->addOption(catalog.getLocale(334));
@@ -265,25 +264,26 @@ OwnOp::configure()
   ac1_2->setMaxSpace( 0 );
   ac1_2->setBorderWidth( 0 );
 
-  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 336 ), 1 ), 0, 0, cfix );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 336 ) ), 0, 0, cfix );
   ac1_2->setMinWidth( 5, 1, 0 );
   ac1_2->setMaxWidth( 5, 1, 0 );
 
-  comreqb = (Button*)ac1_2->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 1, 0, 0 ), 2, 0, cfix );
+  comreqb = (Button*)ac1_2->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 0 ), 2, 0, cfix );
 
   sg[0] = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, com_str, 0 ), 3, 0, cincw );
   
-  fb = (Button*)ac1_2->add( new Button( aguix, 0, 0, "O", 1, 0, 0 ), 4, 0, cfix );
+  fb = (Button*)ac1_2->add( new Button( aguix, 0, 0, "O", 0 ), 4, 0, cfix );
+  fb->setBubbleHelpText( catalog.getLocale( 1132 ) );
   
   AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 9 );
   ac1_3->setMinSpace( 0 );
   ac1_3->setMaxSpace( 0 );
   ac1_3->setBorderWidth( 0 );
 
-  Text *view_text = (Text*)ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ), 1 ), 0, 0, cfix );
+  Text *view_text = (Text*)ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ) ), 0, 0, cfix );
   ac1_3->setMinWidth( 5, 1, 0 );
   ac1_3->setMaxWidth( 5, 1, 0 );
-  comreqb2 = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 1, 0, 0 ), 2, 0, cfix );
+  comreqb2 = (Button*)ac1_3->add( new Button( aguix, 0, 0, catalog.getLocale( 458 ), 0 ), 2, 0, cfix );
   sg[1] = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, view_str, 0 ), 3, 0, cincw );
   
   if ( cyb->getSelectedOption() == 3 ) {
@@ -304,15 +304,11 @@ OwnOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_4->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
@@ -502,14 +498,14 @@ OwnOp::getFlag()
                    AContainer::ACONT_MAXH +
                    AContainer::ACONT_MAXW;
   
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 338 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 338 ) ), 0, 0, cincwnr );
 
   lv = (FieldListView*)ac1->add( new FieldListView( aguix,
                                                     0,
@@ -541,15 +537,11 @@ OwnOp::getFlag()
 					 0,
 					 0,
 					 catalog.getLocale( 11 ),
-					 1,
-					 0,
 					 0 ), 0, 0, cfix );
   cb = (Button*)ac1_2->add( new Button( aguix,
 					0,
 					0,
 					catalog.getLocale( 8 ),
-					1,
-					0,
 					0 ), 1, 0, cfix );
   win->contMaximize( true );
   win->setDoTabCycling( true );
@@ -576,7 +568,7 @@ OwnOp::getFlag()
     // ok
     trow = lv->getActiveRow();
     if ( lv->isValidRow( trow ) == true ) {
-      nr = lv->getData( trow );
+      nr = lv->getData( trow, 0 );
       returnstr = dupstring( ownop_flags[nr].flag );
     }
   }
