@@ -29,6 +29,7 @@
 #include <aguix/util.h>
 #include <aguix/choosebutton.h>
 #include <aguix/cyclebutton.h>
+#include <aguix/acontainerbb.h>
 #include "worker_locale.h"
 #include "nwc_path.hh"
 #include <algorithm>
@@ -152,19 +153,22 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                                    AWindow::AWINDOW_DIALOG ) );
     m_win->create();
 
-    m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 7 ), true );
+    m_co1 = m_win->setContainer( new AContainer( m_win.get(), 1, 6 ), true );
     m_co1->setMaxSpace( 5 );
-    
-    AContainer *co1_2 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
+
+    AContainer *co1_2 = m_co1->add( new AContainerBB( m_win.get(), 1, 2 ), 0, 0 );
     co1_2->setMaxSpace( 5 );
-    co1_2->setBorderWidth( 0 );
-    co1_2->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ) ),
-                0, 0, AContainer::CO_FIX );
-    m_infixtext = static_cast<Text*>( co1_2->add( new Text( &m_aguix, 0, 0, "" ),
-                                                  1, 0, AContainer::CO_INCW ) );
+
+    AContainer *co1_2_1 = co1_2->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
+    co1_2_1->setMaxSpace( 5 );
+    co1_2_1->setBorderWidth( 0 );
+    co1_2_1->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 758 ) ),
+                  0, 0, AContainer::CO_FIX );
+    m_infixtext = co1_2_1->addWidget( new Text( &m_aguix, 0, 0, "" ),
+                                      1, 0, AContainer::CO_INCW );
 
 
-    m_hold_co = m_co1->add( new AContainer( m_win.get(), 4, 1 ), 0, 1 );
+    m_hold_co = co1_2->add( new AContainer( m_win.get(), 4, 1 ), 0, 1 );
     m_hold_co->setMaxSpace( 5 );
     m_hold_co->setBorderWidth( 0 );
     m_hold_co->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 1029 ) ),
@@ -176,13 +180,15 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
     m_hold_filter_text = m_hold_co->addWidget( new Text( &m_aguix, 0, 0, "" ),
                                            3, 0, AContainer::CO_INCW );
 
-    AContainer *co1_4 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 2 );
+    AContainer *co1_4 = m_co1->add( new AContainerBB( m_win.get(), 1, 2 ), 0, 1 );
     co1_4->setMaxSpace( 5 );
-    co1_4->setBorderWidth( 0 );
-    co1_4->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 980 ) ),
-                0, 0, AContainer::CO_FIX );
-    m_filter_mode_cyb = (CycleButton*)co1_4->add( new CycleButton( &m_aguix, 0, 0, 50, 0 ),
-                                                  1, 0, AContainer::CO_INCWNR );
+    AContainer *co1_4_1 = co1_4->add( new AContainer( m_win.get(), 2, 1 ), 0, 0 );
+    co1_4_1->setMaxSpace( 5 );
+    co1_4_1->setBorderWidth( 0 );
+    co1_4_1->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 980 ) ),
+                  0, 0, AContainer::CO_FIX );
+    m_filter_mode_cyb = co1_4_1->addWidget( new CycleButton( &m_aguix, 0, 0, 50, 0 ),
+                                            1, 0, AContainer::CO_INCWNR );
 
     m_filter_mode_cyb->addOption( catalog.getLocale( 981 ) );
     m_filter_mode_cyb->addOption( catalog.getLocale( 982 ) );
@@ -190,9 +196,9 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     m_filter_mode_cyb->resize( m_filter_mode_cyb->getMaxSize(),
                                m_filter_mode_cyb->getHeight() );
-    co1_4->readLimits();
+    co1_4_1->readLimits();
 
-    AContainer *co1_op = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 3 );
+    AContainer *co1_op = co1_4->add( new AContainer( m_win.get(), 2, 1 ), 0, 1 );
     co1_op->setMaxSpace( 5 );
     co1_op->setBorderWidth( 0 );
 
@@ -208,7 +214,36 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
                                                                      LABEL_RIGHT, 0 ),
                                                    1, 0, AContainer::CO_INCWNR );
 
-    m_breadcrumb_co = m_co1->add( new AContainer( m_win.get(), max_path_components + 1, 1 ), 0, 4 );
+    AContainer *co_age = m_co1->add( new AContainerBB( m_win.get(), 7, 1 ), 0, 2 );
+    co_age->setMaxSpace( 5 );
+
+    co_age->add( new Text( &m_aguix, 0, 0, catalog.getLocale( 1154 ) ),
+                 0, 0, AContainer::CO_FIX );
+    m_age_text = co_age->addWidget( new Text( &m_aguix, 0, 0, "----" ),
+                                    1, 0, AContainer::CO_FIX );
+
+    {
+        int textw = 0;
+        for ( int k = 1105; k <= 1110; k++ ) {
+            int tw = m_aguix.getTextWidth( catalog.getLocale( k ) );
+            if ( tw > textw ) {
+                textw = tw;
+            }
+        }
+        co_age->setMinWidth( textw, 1, 0 );
+        co_age->setMaxWidth( textw, 1, 0 );
+    }
+    
+    m_plus1h_b = co_age->addWidget( new Button( &m_aguix, 0, 0, catalog.getLocale( 1155 ), 0 ),
+                                    2, 0, AContainer::CO_FIX );
+    m_plus1d_b = co_age->addWidget( new Button( &m_aguix, 0, 0, catalog.getLocale( 1156 ), 0 ),
+                                    3, 0, AContainer::CO_FIX );
+    m_plus1w_b = co_age->addWidget( new Button( &m_aguix, 0, 0, catalog.getLocale( 1157 ), 0 ),
+                                    4, 0, AContainer::CO_FIX );
+    m_age_reset_b = co_age->addWidget( new Button( &m_aguix, 0, 0, catalog.getLocale( 1158 ), 0 ),
+                                       5, 0, AContainer::CO_FIX );
+
+    m_breadcrumb_co = m_co1->add( new AContainer( m_win.get(), max_path_components + 1, 1 ), 0, 3 );
     m_breadcrumb_co->setMaxSpace( 5 );
 
     for ( int i = 0; i < max_path_components; i++ ) {
@@ -222,7 +257,7 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
         b->hide();
     }
 
-    AContainer *co1_5 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 5 );
+    AContainer *co1_5 = m_co1->add( new AContainer( m_win.get(), 2, 1 ), 0, 4 );
     co1_5->setMaxSpace( 5 );
     co1_5->setBorderWidth( 0 );
 
@@ -271,7 +306,7 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     co1_5->readLimits();
 
-    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 5, 1 ), 0, 6 );
+    AContainer *co1_3 = m_co1->add( new AContainer( m_win.get(), 5, 1 ), 0, 5 );
     co1_3->setMinSpace( 5 );
     co1_3->setMaxSpace( -1 );
     co1_3->setBorderWidth( 0 );
@@ -303,6 +338,8 @@ PathJumpUI::PathJumpUI( AGUIX &aguix, DeepPathStore &path_store, Worker &worker
 
     m_win->contMaximize( true );
     m_win->setDoTabCycling( true );
+
+    m_entry_filter_age = 0;
 }
 
 PathJumpUI::~PathJumpUI()
@@ -313,10 +350,12 @@ int PathJumpUI::mainLoop()
 {
     m_lv_dirty = true;
 
-    showData();
+    apply_filter( m_filter );
 
     highlight_best_hit( m_dirname );
 
+    showData();
+
     maximizeWin();
 
     int tw = Worker::getPersKVPStore().getIntValue( "pathjumpwin-width",
@@ -353,6 +392,30 @@ int PathJumpUI::mainLoop()
                       endmode = 2;
                   } else if ( msg->button.button == m_cancelb ) {
                       endmode = -1;
+                  } else if ( msg->button.button == m_plus1h_b ) {
+                      m_entry_filter_age += 1 * 60 * 60;
+
+                      apply_filter( m_filter );
+                      showData();
+                      updateAgeText();
+                  } else if ( msg->button.button == m_plus1d_b ) {
+                      m_entry_filter_age += 1 * 24 * 60 * 60;
+
+                      apply_filter( m_filter );
+                      showData();
+                      updateAgeText();
+                  } else if ( msg->button.button == m_plus1w_b ) {
+                      m_entry_filter_age += 7 * 24 * 60 * 60;
+
+                      apply_filter( m_filter );
+                      showData();
+                      updateAgeText();
+                  } else if ( msg->button.button == m_age_reset_b ) {
+                      m_entry_filter_age = 0;
+
+                      apply_filter( m_filter );
+                      showData();
+                      updateAgeText();
                   } else if ( msg->button.button == m_hold_status_b ) {
                       if ( m_hold_status.active ) {
                           resetHeldEntriesAndUpdateUI();
@@ -424,7 +487,9 @@ int PathJumpUI::mainLoop()
                           }
                       }
                   } else if ( msg->key.key == XK_Up ) {
+                      m_lv->takeFocus();
                   } else if ( msg->key.key == XK_Down ) {
+                      m_lv->takeFocus();
                   } else if ( msg->key.key == XK_Next ) {
                   } else if ( msg->key.key == XK_Prior ) {
                   } else if ( msg->key.key == XK_Home ) {
@@ -485,6 +550,27 @@ int PathJumpUI::mainLoop()
                           }
                           apply_filter( m_filter );
                           showData();
+                      } else if ( msg->key.key == XK_h &&
+                                  KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
+                          m_entry_filter_age += 1 * 60 * 60;
+
+                          apply_filter( m_filter );
+                          showData();
+                          updateAgeText();
+                      } else if ( msg->key.key == XK_d &&
+                                  KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
+                          m_entry_filter_age += 1 * 24 * 60 * 60;
+
+                          apply_filter( m_filter );
+                          showData();
+                          updateAgeText();
+                      } else if ( msg->key.key == XK_w &&
+                                  KEYSTATEMASK( msg->key.keystate ) == ControlMask ) {
+                          m_entry_filter_age += 7 * 24 * 60 * 60;
+
+                          apply_filter( m_filter );
+                          showData();
+                          updateAgeText();
                       } else {
                           std::string cur_infix = m_filter;
                           cur_infix += msg->key.keybuf;
@@ -517,6 +603,10 @@ int PathJumpUI::mainLoop()
                         m_show_hidden_entries = msg->choose.state;
                         apply_filter( m_filter );
                         showData();
+                    } else if ( msg->choose.button == m_ignore_date_cb ) {
+                        m_ignore_date_for_sorting = m_ignore_date_cb->getState();
+                        apply_filter( m_filter );
+                        showData();
                     }
                     break;
                 case AG_CYCLEBUTTONCLICKED:
@@ -748,14 +838,14 @@ void PathJumpUI::maximizeWin()
     m_co1->rearrange();
 
     if ( my_w < m_lv->getWidth() ) {
-        m_co1->setMinWidth( my_w, 0, 5 );
+        m_co1->setMinWidth( my_w, 0, 4 );
     } else {
-        m_co1->setMinWidth( m_lv->getWidth(), 0, 5 );
+        m_co1->setMinWidth( m_lv->getWidth(), 0, 4 );
     }
     if ( my_h < m_lv->getHeight() ) {
-        m_co1->setMinHeight( my_h, 0, 5 );
+        m_co1->setMinHeight( my_h, 0, 4 );
     } else {
-        m_co1->setMinHeight( m_lv->getHeight(), 0, 5 );
+        m_co1->setMinHeight( m_lv->getHeight(), 0, 4 );
     }
     m_win->contMaximize( true );
 }
@@ -764,6 +854,8 @@ void PathJumpUI::highlight_best_hit( const std::string &filter )
 {
     find_entry( filter, "" );
 
+    post_filtering();
+
     showData();
 }
 
@@ -870,9 +962,26 @@ int PathJumpUI::apply_filter( const std::string &filter )
                     it1->m_type = BOOKMARK_HIDE;
             }
         }
+
+        if ( m_entry_filter_age > 0 && m_current_time > m_entry_filter_age ) {
+            if ( it1->m_last_access + m_entry_filter_age < m_current_time ) {
+                if ( it1->m_type == BOOKMARK_SHOW ) {
+                    it1->m_type = BOOKMARK_HIDE;
+                } else {
+                    it1->m_type = PATH_HIDE;
+                }
+            }
+        }
     }
 
-    find_entry( m_current_entry, filter );
+    // avoid calling find_entry when the filter hasn't been changed.
+    // that way the current entry and depth does not change
+    if ( filter != m_previous_apply_filter ) {
+        find_entry( m_current_entry, filter );
+        m_previous_apply_filter = filter;
+    }
+
+    post_filtering();
 
     m_lv_dirty = true;
 
@@ -933,8 +1042,6 @@ int PathJumpUI::find_entry( const std::string &name, const std::string &filter )
         m_lv_dirty = true;
     }
 
-    post_filtering();
-
     return 0;
 }
 
@@ -1659,3 +1766,41 @@ void PathJumpUI::checkExistance()
 
     m_win->unsetCursor();
 }
+
+void PathJumpUI::updateAgeText()
+{
+    if ( m_entry_filter_age == 0 ) {
+        // nothing
+        m_age_text->setText( "---" );
+    } else if ( m_entry_filter_age <= 1 * 60 * 60 ) {
+        // 1 hour
+        std::string t1 = AGUIXUtils::formatStringToString( catalog.getLocale( 1105 ),
+                                                           1 );
+        m_age_text->setText( t1.c_str() );
+    } else if ( m_entry_filter_age <= 23 * 60 * 60 ) {
+        // x hours
+        std::string t1 = AGUIXUtils::formatStringToString( catalog.getLocale( 1106 ),
+                                                           (int)( ( m_entry_filter_age + 60 * 60 - 1 ) / ( 60 * 60 ) ) );
+        m_age_text->setText( t1.c_str() );
+    } else if ( m_entry_filter_age <= 1 * 24 * 60 * 60 ) {
+        // 1 day
+        std::string t1 = AGUIXUtils::formatStringToString( catalog.getLocale( 1107 ),
+                                                           1 );
+        m_age_text->setText( t1.c_str() );
+    } else if ( m_entry_filter_age <= 6 * 24 * 60 * 60 ) {
+        // x days
+        std::string t1 = AGUIXUtils::formatStringToString( catalog.getLocale( 1108 ),
+                                                           (int)( ( m_entry_filter_age + 24 * 60 * 60 - 1 ) / ( 24 * 60 * 60 ) ) );
+        m_age_text->setText( t1.c_str() );
+    } else if ( m_entry_filter_age <= 7 * 24 * 60 * 60 ) {
+        // one week
+        std::string t1 = AGUIXUtils::formatStringToString( catalog.getLocale( 1109 ),
+                                                           1 );
+        m_age_text->setText( t1.c_str() );
+    } else {
+        // x weeks
+        std::string t1 = AGUIXUtils::formatStringToString( catalog.getLocale( 1110 ),
+                                                           (int)( ( m_entry_filter_age + 7 * 24 * 60 * 60 - 1 ) / ( 7 * 24 * 60 * 60 ) ) );
+        m_age_text->setText( t1.c_str() );
+    }
+}
