@@ -25,6 +25,7 @@
 #include <sstream>
 #include "nwc_fsentry.hh"
 #include "aguix/util.h"
+#include "datei.h"
 
 PersDeepPathStore::PersDeepPathStore( const std::string &filename ) : m_filename( filename ),
                                                                       m_lastmod( 0 ),
@@ -93,6 +94,9 @@ void PersDeepPathStore::read()
     std::string fn = m_filename;
     fn += "-v2";
 
+    std::string lock_file = fn;
+    lock_file += ".lck";
+
     NWC::FSEntry tfe( fn );
 
     if ( ! tfe.entryExists() ) {
@@ -111,6 +115,12 @@ void PersDeepPathStore::read()
              fe.stat_size() == m_lastsize ) return;
     }
 
+    Datei d;
+
+    d.open( lock_file.c_str(),
+            "w" );
+    d.lock();
+    
     std::ifstream ifile( fn.c_str() );
     std::string line;
 
@@ -153,13 +163,24 @@ void PersDeepPathStore::read()
             }
         }
     }
+
+    d.unlock();
 }
 
 void PersDeepPathStore::write()
 {
     std::string fn_v2 = m_filename;
     fn_v2 += "-v2";
-    
+
+    std::string lock_file = fn_v2;
+    lock_file += ".lck";
+
+    Datei d;
+
+    d.open( lock_file.c_str(),
+            "w" );
+    d.lock();
+
     std::ofstream ofile( fn_v2.c_str() );
     std::list< std::pair< std::string, time_t > > l = m_store.getPaths();
 
@@ -169,7 +190,11 @@ void PersDeepPathStore::write()
         ofile << it1->second << ":";
         ofile << it1->first << std::endl;
     }
-    //TODO set lastsize and lastmod to avoid next read?
+
+    d.unlock();
+
+    m_lastmod = time( NULL );
+    m_lastsize = ofile.tellp();
 }
 
 void PersDeepPathStore::bg_thread()
@@ -178,6 +203,8 @@ void PersDeepPathStore::bg_thread()
 
     while ( ! m_bg_threading.stop_thread ) {
         if ( m_bg_threading.push_list.empty() &&
+             m_bg_threading.relocate_list.empty() &&
+             m_bg_threading.remove_list.empty() &&
              m_bg_threading.current_result_id == m_bg_threading.wanted_result_id &&
              m_bg_threading.stop_thread == false ) {
             m_bg_threading.order_cv.wait();
@@ -195,6 +222,31 @@ void PersDeepPathStore::bg_thread()
             m_bg_threading.order_cv.lock();
         }
 
+        if ( ! m_bg_threading.relocate_list.empty() ) {
+            auto relocate_list_copy = m_bg_threading.relocate_list;
+
+            m_bg_threading.relocate_list.clear();
+
+            m_bg_threading.order_cv.unlock();
+
+            processRelocateOrders( relocate_list_copy );
+
+            m_bg_threading.order_cv.lock();
+        }
+
+        if ( ! m_bg_threading.remove_list.empty() ) {
+            auto remove_list_copy = m_bg_threading.remove_list;
+
+            m_bg_threading.remove_list.clear();
+
+            m_bg_threading.order_cv.unlock();
+
+            removeEntries( remove_list_copy );
+
+            m_bg_threading.order_cv.lock();
+        }
+
+
         if ( m_bg_threading.current_result_id != m_bg_threading.wanted_result_id ) {
             m_bg_threading.result_cv.lock();
 
@@ -224,3 +276,64 @@ void PersDeepPathStore::addPaths( const std::list< std::pair< std::string, time_
         write();
     }
 }
+
+void PersDeepPathStore::relocateEntries( const std::string &dest,
+                                         const std::string &source,
+                                         time_t ts,
+                                         bool move )
+{
+    m_bg_threading.order_cv.lock();
+
+    m_bg_threading.relocate_list.push_back( std::make_tuple( dest, source, ts, move ) );
+
+    m_bg_threading.order_cv.signal();
+
+    m_bg_threading.order_cv.unlock();
+}
+
+void PersDeepPathStore::processRelocateOrders( const std::list< std::tuple< std::string, std::string, time_t, bool > > &relocate_list )
+{
+    read();
+
+    DeepPathNode::node_change_t changed = DeepPathNode::NODE_UNCHANGED;
+
+    for ( auto &e : relocate_list ) {
+        m_store.relocateEntries( std::get<0>( e ),
+                                 std::get<1>( e ),
+                                 std::get<2>( e ),
+                                 std::get<3>( e ),
+                                 &changed);
+    }
+
+    if ( changed != DeepPathNode::NODE_UNCHANGED ) {
+        write();
+    }
+}
+
+void PersDeepPathStore::removeEntry( const std::string &path )
+{
+    m_bg_threading.order_cv.lock();
+
+    m_bg_threading.remove_list.push_back( path );
+
+    m_bg_threading.order_cv.signal();
+
+    m_bg_threading.order_cv.unlock();
+}
+
+void PersDeepPathStore::removeEntries( const std::list< std::string > &paths )
+{
+    read();
+
+    bool changed = false;
+
+    for ( auto &e : paths ) {
+        if ( m_store.removeEntry( e ) ) {
+            changed = true;
+        }
+    }
+
+    if ( changed ) {
+        write();
+    }
+}
