@@ -1,6 +1,6 @@
 /* processexitaction.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2010 Ralf Hoffmann.
+ * Copyright (C) 2010-2011 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,7 @@
 #include "processexitaction.hh"
 #include "fileviewer.hh"
 #include "worker.h"
+#include "wpucontext.h"
 
 class PEA_FileView_Destroyer : public FileViewerDestroyCallback
 {
@@ -40,12 +41,26 @@ private:
 
 ProcessExitAction::ProcessExitAction( bool show_file,
                                       const std::string &tmp_name,
-                                      Worker *worker ) : m_show_file( show_file ),
-                                                         m_tmp_name( tmp_name ),
-                                                         m_worker( worker )
+                                      Worker *worker,
+                                      WPUContext *wpu ) : m_show_file( show_file ),
+                                                          m_tmp_name( tmp_name ),
+                                                          m_worker( worker ),
+                                                          m_wpu( wpu )
 {
 }
 
+ProcessExitAction::~ProcessExitAction()
+{
+    /* in case callback is not called */
+    if ( m_wpu != NULL ) {
+        if ( m_wpu->unref() < 1 ) {
+            delete m_wpu;
+        }
+
+        m_wpu = NULL;
+    }
+}
+
 void ProcessExitAction::callback( int status )
 {
     if ( m_worker != NULL && status != 0 ) {
@@ -63,4 +78,12 @@ void ProcessExitAction::callback( int status )
 
         fv.view( l, cb );
     }
+
+    if ( m_wpu != NULL ) {
+        if ( m_wpu->unref() < 1 ) {
+            delete m_wpu;
+        }
+
+        m_wpu = NULL;
+    }
 }
