@@ -609,7 +609,7 @@ int ScriptOp::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getName())+1);
   sprintf(tstr,catalog.getLocale(293),getName());
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -617,7 +617,7 @@ int ScriptOp::configure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 461 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 461 ) ), 0, 0, cincwnr );
 
   lv = (FieldListView*)ac1->add( new FieldListView( aguix, 0, 0, 100, 50, 0 ), 0, 1, cincwnr );
   lv->setVBarState( 0 );
@@ -668,7 +668,7 @@ int ScriptOp::configure()
   else lv->setActiveRow( 0 );
   ac1->readLimits();
 
-  push_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  push_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( push_win, 0, 2, cmin );
   push_win->create();
   push_win->setBorderWidth( 0 );
@@ -676,11 +676,11 @@ int ScriptOp::configure()
   AContainer *push_win_ac1 = push_win->setContainer( new AContainer( push_win, 1, 5 ), true );
   push_win_ac1->setMinSpace( 5 );
   push_win_ac1->setMaxSpace( 5 );
-  push_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 468 ), 1 ), 0, 0, cincwnr );
+  push_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 468 ) ), 0, 0, cincwnr );
 
   chb = (ChooseButton*)push_win_ac1->add( new ChooseButton( aguix, 0, 0,
 							    ( push_useoutput == true ) ? 1 : 0,
-							    catalog.getLocale( 469 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+							    catalog.getLocale( 469 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   AContainer *push_win_ac1_1 = push_win_ac1->add( new AContainer( push_win, 2, 1 ), 0, 2 );
   push_win_ac1_1->setMinSpace( 5 );
@@ -688,7 +688,7 @@ int ScriptOp::configure()
   push_win_ac1_1->setBorderWidth( 0 );
 
   sprintf( buf, "%d", stack_nr );
-  push_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 470 ), 1 ), 0, 0, cfix );
+  push_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 470 ) ), 0, 0, cfix );
   StringGadget *psnsg = (StringGadget*)push_win_ac1_1->add( new StringGadget( aguix,
 									      0,
 									      0,
@@ -701,7 +701,7 @@ int ScriptOp::configure()
   push_win_ac1_2->setMaxSpace( 5 );
   push_win_ac1_2->setBorderWidth( 0 );
 
-  push_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 471 ), 1 ), 0, 0, cfix );
+  push_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 471 ) ), 0, 0, cfix );
   StringGadget *pssg = (StringGadget*)push_win_ac1_2->add( new StringGadget( aguix,
 									     0,
 									     0,
@@ -712,8 +712,6 @@ int ScriptOp::configure()
 							  0,
 							  0,
 							  "F",
-							  1,
-							  0,
 							  0 ), 2, 0, cfix );
   
   ChooseButton *pdcb = (ChooseButton*)push_win_ac1->add( new ChooseButton( aguix,
@@ -722,10 +720,9 @@ int ScriptOp::configure()
 									   dodebug,
 									   catalog.getLocale( 474 ),
 									   LABEL_RIGHT,
-									   1,
 									   0 ), 0, 4, cincwnr );
   
-  pop_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  pop_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( pop_win, 0, 2, cmin );
   pop_win->create();
   pop_win->setBorderWidth( 0 );
@@ -734,7 +731,7 @@ int ScriptOp::configure()
   pop_win_ac1->setMinSpace( 5 );
   pop_win_ac1->setMaxSpace( 5 );
 
-  pop_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 472 ), 1 ), 0, 0, cincwnr  );
+  pop_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 472 ) ), 0, 0, cincwnr  );
 
   AContainer *pop_win_ac1_1 = pop_win_ac1->add( new AContainer( pop_win, 2, 1 ), 0, 1 );
   pop_win_ac1_1->setMinSpace( 5 );
@@ -742,7 +739,7 @@ int ScriptOp::configure()
   pop_win_ac1_1->setBorderWidth( 0 );
 
   sprintf( buf, "%d", stack_nr );
-  pop_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 470 ), 1 ), 0, 0, cfix );
+  pop_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 470 ) ), 0, 0, cfix );
   popsg = (StringGadget*)pop_win_ac1_1->add( new StringGadget( aguix,
 							       0,
 							       0,
@@ -750,7 +747,7 @@ int ScriptOp::configure()
 							       buf,
 							       0 ), 1, 0, cincw );
   
-  label_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  label_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( label_win, 0, 2, cmin );
   label_win->create();
   label_win->setBorderWidth( 0 );
@@ -759,7 +756,7 @@ int ScriptOp::configure()
   label_win_ac1->setMinSpace( 5 );
   label_win_ac1->setMaxSpace( 5 );
 
-  label_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ), 1 ), 0, 0, cfix );
+  label_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ) ), 0, 0, cfix );
   StringGadget *labelsg = (StringGadget*)label_win_ac1->add( new StringGadget( aguix,
 									       0,
 									       0,
@@ -768,7 +765,7 @@ int ScriptOp::configure()
 									       0 ), 1, 0, cincw );
 
   
-  nop_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  nop_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( nop_win, 0, 2, cmin );
   nop_win->create();
   nop_win->setBorderWidth( 0 );
@@ -777,9 +774,9 @@ int ScriptOp::configure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  nop_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 476 ), 1 ), 0, 0, cincwnr );
+  nop_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 476 ) ), 0, 0, cincwnr );
   
-  end_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  end_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( end_win, 0, 2, cmin );
   end_win->create();
   end_win->setBorderWidth( 0 );
@@ -788,9 +785,9 @@ int ScriptOp::configure()
   end_win_ac1->setMinSpace( 5 );
   end_win_ac1->setMaxSpace( 5 );
 
-  end_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 477 ), 1 ), 0, 0, cincwnr );
+  end_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 477 ) ), 0, 0, cincwnr );
   
-  if_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  if_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( if_win, 0, 2, cmin );
   if_win->create();
   if_win->setBorderWidth( 0 );
@@ -804,15 +801,15 @@ int ScriptOp::configure()
   if_win_ac1_1->setMaxSpace( 5 );
   if_win_ac1_1->setBorderWidth( 0 );
 
-  if_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 478 ), 1 ), 0, 0, cfix );
-  Button *ifhelpb = (Button*)if_win_ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 1, 0, cincw );
+  if_win_ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 478 ) ), 0, 0, cfix );
+  Button *ifhelpb = (Button*)if_win_ac1_1->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 0 ), 1, 0, cincw );
 
   AContainer *if_win_ac1_2 = if_win_ac1->add( new AContainer( if_win, 3, 1 ), 0, 1 );
   if_win_ac1_2->setMinSpace( 5 );
   if_win_ac1_2->setMaxSpace( 5 );
   if_win_ac1_2->setBorderWidth( 0 );
 
-  if_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 479 ), 1 ), 0, 0, cfix );
+  if_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 479 ) ), 0, 0, cfix );
   StringGadget *iftsg = (StringGadget*)if_win_ac1_2->add( new StringGadget( aguix,
 									    0,
 									    0,
@@ -823,8 +820,6 @@ int ScriptOp::configure()
 							 0,
 							 0,
 							 "F",
-							 1,
-							 0,
 							 0 ), 2, 0, cfix );
 
   AContainer *if_win_ac1_3 = if_win_ac1->add( new AContainer( if_win, 2, 1 ), 0, 2 );
@@ -832,7 +827,7 @@ int ScriptOp::configure()
   if_win_ac1_3->setMaxSpace( 5 );
   if_win_ac1_3->setBorderWidth( 0 );
 
-  if_win_ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ), 1 ), 0, 0, cfix );
+  if_win_ac1_3->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ) ), 0, 0, cfix );
   StringGadget *iflsg = (StringGadget*)if_win_ac1_3->add( new StringGadget( aguix,
 									    0,
 									    0,
@@ -846,11 +841,10 @@ int ScriptOp::configure()
 									 dodebug,
 									 catalog.getLocale( 474 ),
 									 LABEL_RIGHT,
-									 1,
 									 0 ), 0, 3, cincwnr );
 
   
-  set_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  set_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( set_win, 0, 2, cmin );
   set_win->create();
   set_win->setBorderWidth( 0 );
@@ -862,7 +856,7 @@ int ScriptOp::configure()
   set_win_ac1->setMaxSpace( 5 );
 
   for ( i = 0; i < lines; i++ ) {
-    set_win_ac1->add( new Text( aguix, 0, 0, liness[i], 1 ), 0, i, cincwnr );
+    set_win_ac1->add( new Text( aguix, 0, 0, liness[i] ), 0, i, cincwnr );
   }
 
   for ( i = 0; i < lines; i++ ) _freesafe( liness[i] );
@@ -874,7 +868,6 @@ int ScriptOp::configure()
 									    wpu_recursive,
 									    catalog.getLocale( 330 ),
 									    LABEL_RIGHT,
-									    1,
 									    0 ), 0, lines, cincwnr );
 
   ChooseButton *settdcb = (ChooseButton*)set_win_ac1->add( new ChooseButton( aguix,
@@ -883,10 +876,9 @@ int ScriptOp::configure()
 									     wpu_take_dirs,
 									     catalog.getLocale( 513 ),
 									     LABEL_RIGHT,
-									     1,
 									     0 ), 0, lines + 1, cincwnr );
   
-  win_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  win_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( win_win, 0, 2, cmin );
   win_win->create();
   win_win->setBorderWidth( 0 );
@@ -895,7 +887,7 @@ int ScriptOp::configure()
   win_win_ac1->setMinSpace( 5 );
   win_win_ac1->setMaxSpace( 5 );
 
-  Button *winhelpb = (Button*)win_win_ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 0, 0, cincwnr );
+  Button *winhelpb = (Button*)win_win_ac1->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 0 ), 0, 0, cincwnr );
 
   AContainer *win_win_ac1_1 = win_win_ac1->add( new AContainer( win_win, 2, 1 ), 0, 1 );
   win_win_ac1_1->setMinSpace( 5 );
@@ -904,8 +896,8 @@ int ScriptOp::configure()
 
   ChooseButton *cwcb = (ChooseButton*)win_win_ac1_1->add( new ChooseButton( aguix, 0, 0,
 									    ( wintype == SCRIPT_WINDOW_LEAVE ) ? 0 : 1,
-									    catalog.getLocale( 490 ), LABEL_RIGHT, 1, 0 ), 0, 0, cfixnr );
-  CycleButton *cwcycb = (CycleButton*)win_win_ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+									    catalog.getLocale( 490 ), LABEL_RIGHT, 0 ), 0, 0, cfixnr );
+  CycleButton *cwcycb = (CycleButton*)win_win_ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   cwcycb->addOption( catalog.getLocale( 491 ) );
   cwcycb->addOption( catalog.getLocale( 492 ) );
   cwcycb->resize( cwcycb->getMaxSize(), cwcycb->getHeight() );
@@ -919,7 +911,7 @@ int ScriptOp::configure()
 
   ChooseButton *cpcb = (ChooseButton*)win_win_ac1_2->add( new ChooseButton( aguix, 0, 0,
 									    ( change_progress == true ) ? 1 : 0,
-									    catalog.getLocale( 493 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+									    catalog.getLocale( 493 ), LABEL_RIGHT, 0 ), 0, 0, cincwnr );
   AContainer *win_win_ac1_2_1 = win_win_ac1_2->add( new AContainer( win_win, 2, 2 ), 0, 1 );
   win_win_ac1_2_1->setMinSpace( 5 );
   win_win_ac1_2_1->setMaxSpace( 5 );
@@ -931,7 +923,7 @@ int ScriptOp::configure()
   win_win_ac1_2_1_1->setMinSpace( 5 );
   win_win_ac1_2_1_1->setMaxSpace( 5 );
 
-  win_win_ac1_2_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 494 ), 1 ), 0, 0, cfix );
+  win_win_ac1_2_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 494 ) ), 0, 0, cfix );
   StringGadget *prosg = (StringGadget*)win_win_ac1_2_1_1->add( new StringGadget( aguix,
 										 0,
 										 0,
@@ -942,13 +934,11 @@ int ScriptOp::configure()
 							      0,
 							      0,
 							      "F",
-							      1,
-							      0,
 							      0 ), 2, 0, cfix );
 
   ChooseButton *prouocb = (ChooseButton*)win_win_ac1_2_1->add( new ChooseButton( aguix, 0, 0,
 										 ( progress_useoutput == true ) ? 1 : 0,
-										 catalog.getLocale( 495 ), LABEL_RIGHT, 1, 0 ), 1, 1, cincwnr );
+										 catalog.getLocale( 495 ), LABEL_RIGHT, 0 ), 1, 1, cincwnr );
 
   AContainerBB *win_win_ac1_3 = static_cast<AContainerBB*>( win_win_ac1->add( new AContainerBB( win_win, 1, 2 ), 0, 3 ) );
   win_win_ac1_3->setMinSpace( 5 );
@@ -956,7 +946,7 @@ int ScriptOp::configure()
 
   ChooseButton *cwtcb = (ChooseButton*)win_win_ac1_3->add( new ChooseButton( aguix, 0, 0,
 									     ( change_text == true ) ? 1 : 0,
-									     catalog.getLocale( 496 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+									     catalog.getLocale( 496 ), LABEL_RIGHT, 0 ), 0, 0, cincwnr );
 
   AContainer *win_win_ac1_3_1 = win_win_ac1_3->add( new AContainer( win_win, 2, 2 ), 0, 1 );
   win_win_ac1_3_1->setMinSpace( 5 );
@@ -969,7 +959,7 @@ int ScriptOp::configure()
   win_win_ac1_3_1_1->setMinSpace( 5 );
   win_win_ac1_3_1_1->setMaxSpace( 5 );
 
-  win_win_ac1_3_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 497 ), 1 ), 0, 0, cfix );
+  win_win_ac1_3_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 497 ) ), 0, 0, cfix );
   StringGadget *wintextsg = (StringGadget*)win_win_ac1_3_1_1->add( new StringGadget( aguix,
 										     0,
 										     0,
@@ -980,16 +970,14 @@ int ScriptOp::configure()
 								  0,
 								  0,
 								  "F",
-								  1,
-								  0,
 								  0 ), 2, 0, cfix );
 
   ChooseButton *wintextuocb = (ChooseButton*)win_win_ac1_3_1->add( new ChooseButton( aguix, 0, 0,
 										     ( wintext_useoutput == true ) ? 1 : 0,
-										     catalog.getLocale( 498 ), LABEL_RIGHT, 1, 0 ), 1, 1, cincwnr );
+										     catalog.getLocale( 498 ), LABEL_RIGHT, 0 ), 1, 1, cincwnr );
 
   
-  goto_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  goto_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( goto_win, 0, 2, cmin );
   goto_win->create();
   goto_win->setBorderWidth( 0 );
@@ -998,7 +986,7 @@ int ScriptOp::configure()
   goto_win_ac1->setMinSpace( 5 );
   goto_win_ac1->setMaxSpace( 5 );
   
-  goto_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ), 1 ), 0, 0, cfix );
+  goto_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 475 ) ), 0, 0, cfix );
   StringGadget *gotosg = (StringGadget*)goto_win_ac1->add( new StringGadget( aguix,
 									     0,
 									     0,
@@ -1006,7 +994,7 @@ int ScriptOp::configure()
 									     ( label != NULL ) ? label : "",
 									     0 ), 1, 0, cincw );
   
-  command_win = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  command_win = new AWindow( aguix, 0, 0, 10, 10, "" );
   ac1->add( command_win, 0, 2, cmin );
   command_win->create();
   command_win->setBorderWidth( 0 );
@@ -1014,14 +1002,14 @@ int ScriptOp::configure()
   AContainer *command_win_ac1 = command_win->setContainer( new AContainer( command_win, 1, 2 ), true );
   command_win_ac1->setMinSpace( 5 );
   command_win_ac1->setMaxSpace( 5 );
-  command_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 989 ), 1 ), 0, 0, cincwnr );
+  command_win_ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 989 ) ), 0, 0, cincwnr );
 
   AContainer *command_win_ac1_2 = command_win_ac1->add( new AContainer( command_win, 5, 1 ), 0, 1 );
   command_win_ac1_2->setMinSpace( 0 );
   command_win_ac1_2->setMaxSpace( 0 );
   command_win_ac1_2->setBorderWidth( 0 );
 
-  command_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 990 ), 1 ), 0, 0, cfix );
+  command_win_ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 990 ) ), 0, 0, cfix );
   command_win_ac1_2->setMaxWidth( 5, 1, 0 );
   StringGadget *cmdsg = (StringGadget*)command_win_ac1_2->add( new StringGadget( aguix,
                                                                                  0,
@@ -1033,15 +1021,11 @@ int ScriptOp::configure()
                                                                     0,
                                                                     0,
                                                                     "C",
-                                                                    1,
-                                                                    0,
                                                                     0 ), 3, 0, cfix );
   Button *cmd_flag_b = (Button*)command_win_ac1_2->add( new Button( aguix,
                                                                  0,
                                                                  0,
                                                                  "F",
-                                                                 1,
-                                                                 0,
                                                                  0 ), 4, 0, cfix );
 
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
@@ -1052,15 +1036,11 @@ int ScriptOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
 
   win->setDoTabCycling( true );
@@ -1395,7 +1375,7 @@ char *ScriptOp::getIfFlag()
   char *returnstr;
   int i, trow, nr, nr2;
   
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -1445,15 +1425,11 @@ char *ScriptOp::getIfFlag()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, AContainer::CO_FIX );
   Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, AContainer::CO_FIX );
 
   win->setDoTabCycling( true );
@@ -1480,7 +1456,7 @@ char *ScriptOp::getIfFlag()
     // ok
     trow = lv->getActiveRow();
     if ( lv->isValidRow( trow ) == true ) {
-      i = lv->getData( trow );
+      i = lv->getData( trow, 0 );
       if ( i >= nr ) {
         returnstr = dupstring( ownop_flags[i - nr].flag );
       } else {
@@ -1503,7 +1479,7 @@ char *ScriptOp::getRegisteredCommand()
   int endmode=-1;
   char *returnstr;
   
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocale( 338 ), AWindow::AWINDOW_DIALOG );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
@@ -1552,15 +1528,11 @@ char *ScriptOp::getRegisteredCommand()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, AContainer::CO_FIX );
   Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, AContainer::CO_FIX );
 
   win->setDoTabCycling( true );
