@@ -1,6 +1,6 @@
 /* searchentryop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2009,2011-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -163,7 +163,7 @@ int SearchEntryOp::configure()
 
   tstr = (char*)_allocsafe( strlen( catalog.getLocale( 293 ) ) + strlen( getDescription() ) + 1 );
   sprintf( tstr, catalog.getLocale( 293 ), getDescription() );
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe( tstr );
   
@@ -172,17 +172,17 @@ int SearchEntryOp::configure()
   ac1->setMaxSpace( 5 );
 
   cb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( ignore_case == true ) ? 1 : 0,
-						  catalog.getLocale( 501 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+						  catalog.getLocale( 501 ), LABEL_RIGHT, 0 ), 0, 0, cincwnr );
 
   rscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( reverse_search == true ) ? 1 : 0,
-						    catalog.getLocale( 648 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						    catalog.getLocale( 648 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
   
   ChooseButton *iscb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, m_infix_search == true,
-                                                                  catalog.getLocale( 862 ), LABEL_RIGHT, 1, 0 ),
+                                                                  catalog.getLocale( 862 ), LABEL_RIGHT, 0 ),
                                                 0, 2, AContainer::CO_INCWNR );
   
   ChooseButton *fmcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, m_flexible_match == true,
-                                                                  catalog.getLocale( 955 ), LABEL_RIGHT, 1, 0 ),
+                                                                  catalog.getLocale( 955 ), LABEL_RIGHT, 0 ),
                                                 0, 3, AContainer::CO_INCWNR );
   
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 4 );
@@ -193,15 +193,11 @@ int SearchEntryOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, cfix );
 
   win->setDoTabCycling( true );
