@@ -862,7 +862,7 @@ void SearchOpBG::createWindow()
     int w, h, sw, sh;
     initColorDefs();
 
-    m_win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 50 ) );
+    m_win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocaleCom( 50 ) );
     m_win->create();
 
     AContainer *ac1 = m_win->setContainer( new AContainer( m_win, 1, 5 ), true );
@@ -874,11 +874,11 @@ void SearchOpBG::createWindow()
     ac1_1->setMaxSpace( 5 );
     ac1_1->setBorderWidth( 5 );
 
-    m_options_k1 = new Kartei( aguix, 10, 10, 10, 10, 0, "" );
+    m_options_k1 = new Kartei( aguix, 10, 10, 10, 10, "" );
     ac1_1->add( m_options_k1, 0, 0, AContainer::CO_INCW );
     m_options_k1->create();
 
-    AWindow *subwin1 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+    AWindow *subwin1 = new AWindow( aguix, 0, 0, 10, 10, "" );
     m_options_k1->add( subwin1 );
     subwin1->create();
 
@@ -892,8 +892,8 @@ void SearchOpBG::createWindow()
     _start_ac->setMaxSpace( 5 );
     _start_ac->setBorderWidth( 0 );
 
-    _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 722 ), 1 ), 0, 0, AContainer::CO_FIX );
-    _startdir_text = (Text*)_start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 723 ), 1 ), 1, 0, AContainer::CO_INCW );
+    _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 722 ) ), 0, 0, AContainer::CO_FIX );
+    _startdir_text = (Text*)_start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 723 ) ), 1, 0, AContainer::CO_INCW );
     _startdir_text->hide();
     _startdir_sg = (StringGadget*)_start_ac->add( new StringGadget( aguix, 0, 0, 100,
                                                                     m_initial_start_vdir.get() != NULL ?
@@ -907,14 +907,14 @@ void SearchOpBG::createWindow()
     ac1_2->setMaxSpace( 0 );
     ac1_2->setBorderWidth( 0 );
 
-    _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 724 ), 1 ), 0, 1, AContainer::CO_FIX );
+    _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 724 ) ), 0, 1, AContainer::CO_FIX );
     _matchname_sg = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, "*", 0 ), 0, 0, AContainer::CO_INCW );
     _matchname_regexp_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                        catalog.getLocale( 502 ), LABEL_RIGHT, 1, 0 ), 1, 0, AContainer::CO_FIXNR );
+                                                                        catalog.getLocale( 502 ), LABEL_RIGHT, 0 ), 1, 0, AContainer::CO_FIXNR );
     _matchname_fullpath_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                          catalog.getLocale( 570 ), LABEL_RIGHT, 1, 0 ), 2, 0, AContainer::CO_FIXNR );
+                                                                          catalog.getLocale( 570 ), LABEL_RIGHT, 0 ), 2, 0, AContainer::CO_FIXNR );
     _matchname_case_cb = (ChooseButton*)ac1_2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                      catalog.getLocale( 725 ), LABEL_RIGHT, 1, 0 ), 3, 0, AContainer::CO_FIXNR );
+                                                                      catalog.getLocale( 725 ), LABEL_RIGHT, 0 ), 3, 0, AContainer::CO_FIXNR );
     _matchname_regexp_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
     _matchname_fullpath_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
     _matchname_case_cb->resize( _matchname_sg->getHeight(), _matchname_sg->getHeight() );
@@ -925,10 +925,10 @@ void SearchOpBG::createWindow()
     ac1_3->setMaxSpace( 0 );
     ac1_3->setBorderWidth( 0 );
 
-    _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 726 ), 1 ), 0, 2, AContainer::CO_FIX );
+    _start_ac->add( new Text( aguix, 0, 0, catalog.getLocale( 726 ) ), 0, 2, AContainer::CO_FIX );
     _matchcontent_sg = (StringGadget*)ac1_3->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 0, 0, AContainer::CO_INCW );
     _matchcontent_case_cb = (ChooseButton*)ac1_3->add( new ChooseButton( aguix, 0, 0, false,
-                                                                         catalog.getLocale( 725 ), LABEL_RIGHT, 1, 0 ), 1, 0, AContainer::CO_FIXNR );
+                                                                         catalog.getLocale( 725 ), LABEL_RIGHT, 0 ), 1, 0, AContainer::CO_FIXNR );
     _matchcontent_case_cb->resize( _matchcontent_sg->getHeight(), _matchcontent_sg->getHeight() );
     ac1_3->readLimits();
 
@@ -938,17 +938,15 @@ void SearchOpBG::createWindow()
     ac1_globsets->setBorderWidth( 0 );
 
     _follow_symlinks_cb = (ChooseButton*)ac1_globsets->add( new ChooseButton( aguix, 0, 0, false,
-                                                                              catalog.getLocale( 298 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CO_FIXNR );
+                                                                              catalog.getLocale( 298 ), LABEL_RIGHT, 0 ), 0, 0, AContainer::CO_FIXNR );
     _search_vfs_cb = (ChooseButton*)ac1_globsets->add( new ChooseButton( aguix, 0, 0, false,
-                                                                         catalog.getLocale( 727 ), LABEL_RIGHT, 1, 0 ), 1, 0, AContainer::CO_FIXNR );
+                                                                         catalog.getLocale( 727 ), LABEL_RIGHT, 0 ), 1, 0, AContainer::CO_FIXNR );
     _search_same_fs_cb = (ChooseButton*)ac1_globsets->add( new ChooseButton( aguix, 0, 0, false,
-                                                                             catalog.getLocale( 792 ), LABEL_RIGHT, 1, 0 ), 2, 0, AContainer::CO_FIXNR );
+                                                                             catalog.getLocale( 792 ), LABEL_RIGHT, 0 ), 2, 0, AContainer::CO_FIXNR );
     m_newsearchb = (Button*)ac1_globsets->add( new Button( aguix,
                                                            0,
                                                            0,
                                                            catalog.getLocale( 728 ),
-                                                           1,
-                                                           0,
                                                            0 ), 4, 0, AContainer::CO_FIX );
 
     AContainer *ac1_set2 = acsw1_1->add( new AContainer( subwin1, 2, 1 ), 0, 2 );
@@ -957,10 +955,10 @@ void SearchOpBG::createWindow()
     ac1_set2->setBorderWidth( 0 );
 
     m_also_dirs_cb = (ChooseButton*)ac1_set2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                     catalog.getLocale( 1003 ), LABEL_RIGHT, 1, 0 ),
+                                                                     catalog.getLocale( 1003 ), LABEL_RIGHT, 0 ),
                                                    0, 0, AContainer::CO_FIXNR );
 
-    AWindow *subwin2 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+    AWindow *subwin2 = new AWindow( aguix, 0, 0, 10, 10, "" );
     m_options_k1->add( subwin2 );
     subwin2->create();
 
@@ -975,13 +973,13 @@ void SearchOpBG::createWindow()
     acsub1->setBorderWidth( 0 );
 
     m_younger_cb = (ChooseButton*)acsub1->add( new ChooseButton( aguix, 0, 0, false,
-                                                                 catalog.getLocale( 813 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CO_FIXNR );
+                                                                 catalog.getLocale( 813 ), LABEL_RIGHT, 0 ), 0, 0, AContainer::CO_FIXNR );
     m_younger_sg = (StringGadget*)acsub1->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 1, 0, AContainer::CO_INCW );
-    m_younger_cal_b = (Button*)acsub1->add( new Button( aguix, 0, 0, catalog.getLocale( 819 ), 1, 0, 0 ), 2, 0, AContainer::CO_FIX );
+    m_younger_cal_b = (Button*)acsub1->add( new Button( aguix, 0, 0, catalog.getLocale( 819 ), 0 ), 2, 0, AContainer::CO_FIX );
     m_older_cb = (ChooseButton*)acsub1->add( new ChooseButton( aguix, 0, 0, false,
-                                                               catalog.getLocale( 814 ), LABEL_RIGHT, 1, 0 ), 3, 0, AContainer::CO_FIXNR );
+                                                               catalog.getLocale( 814 ), LABEL_RIGHT, 0 ), 3, 0, AContainer::CO_FIXNR );
     m_older_sg = (StringGadget*)acsub1->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 4, 0, AContainer::CO_INCW );
-    m_older_cal_b = (Button*)acsub1->add( new Button( aguix, 0, 0, catalog.getLocale( 819 ), 1, 0, 0 ), 5, 0, AContainer::CO_FIX );
+    m_older_cal_b = (Button*)acsub1->add( new Button( aguix, 0, 0, catalog.getLocale( 819 ), 0 ), 5, 0, AContainer::CO_FIX );
 
     AContainer *acsub2 = acsw2_1->add( new AContainer( subwin2, 5, 1 ), 0, 1 );
     acsub2->setMinSpace( 5 );
@@ -989,19 +987,19 @@ void SearchOpBG::createWindow()
     acsub2->setBorderWidth( 0 );
 
     m_size_geq_cb = (ChooseButton*)acsub2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                  catalog.getLocale( 817 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CO_FIXNR );
+                                                                  catalog.getLocale( 817 ), LABEL_RIGHT, 0 ), 0, 0, AContainer::CO_FIXNR );
     m_size_geq_sg = (StringGadget*)acsub2->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 1, 0, AContainer::CO_INCW );
     m_size_leq_cb = (ChooseButton*)acsub2->add( new ChooseButton( aguix, 0, 0, false,
-                                                                  catalog.getLocale( 818 ), LABEL_RIGHT, 1, 0 ), 2, 0, AContainer::CO_FIXNR );
+                                                                  catalog.getLocale( 818 ), LABEL_RIGHT, 0 ), 2, 0, AContainer::CO_FIXNR );
     m_size_leq_sg = (StringGadget*)acsub2->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 3, 0, AContainer::CO_INCW );
-    m_size_help_b = (Button*)acsub2->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 1, 0, 0 ), 4, 0, AContainer::CO_FIX );
+    m_size_help_b = (Button*)acsub2->add( new Button( aguix, 0, 0, catalog.getLocale( 483 ), 0 ), 4, 0, AContainer::CO_FIX );
 
     AContainer *acsub3 = acsw2_1->add( new AContainer( subwin2, 3, 1 ), 0, 2 );
     acsub3->setMinSpace( 5 );
     acsub3->setMaxSpace( 5 );
     acsub3->setBorderWidth( 0 );
 
-    acsub3->add( new Text( aguix, 0, 0, catalog.getLocale( 940 ), 1 ), 0, 0, AContainer::CO_FIX );
+    acsub3->add( new Text( aguix, 0, 0, catalog.getLocale( 940 ) ), 0, 0, AContainer::CO_FIX );
     m_max_vfs_depth_sg = (StringGadget*)acsub3->add( new StringGadget( aguix, 0, 0, aguix->getTextWidth( "MMMMMMMMM" ), "3", 0 ),
                                                      1, 0, AContainer::CO_FIX );
 
@@ -1038,20 +1036,20 @@ void SearchOpBG::createWindow()
 
     m_enterb =(Button*)ac1_4->add( new Button( aguix, 0, 0,
                                                catalog.getLocale( 730 ), catalog.getLocale( 967 ),
-                                               1, 1, 0, 0, 0 ), 0, 0, AContainer::CO_INCW );
+                                               0 ), 0, 0, AContainer::CO_INCW );
     m_panelize_b =(Button*)ac1_4->add( new Button( aguix, 0, 0,
                                                    catalog.getLocale( 995 ),
                                                    catalog.getLocale( 996 ),
-                                                   1, 1, 0, 0, 0 ), 1, 0, AContainer::CO_INCW );
+                                                   0 ), 1, 0, AContainer::CO_INCW );
 
     AContainer *ac1_4_1 = ac1_res->add( new AContainer( m_win, 3, 1 ), 0, 2 );
     ac1_4_1->setMinSpace( 0 );
     ac1_4_1->setMaxSpace( 0 );
     ac1_4_1->setBorderWidth( 0 );
 
-    m_viewb = (Button*)ac1_4_1->add( new Button( aguix, 0, 0, catalog.getLocale( 731 ), 1, 0, 0 ), 0, 0, AContainer::CO_INCW );
-    m_editb = (Button*)ac1_4_1->add( new Button( aguix, 0, 0, catalog.getLocale( 732 ), 1, 0, 0 ), 1, 0, AContainer::CO_INCW );
-    m_removeb = (Button*)ac1_4_1->add( new Button( aguix, 0, 0, catalog.getLocale( 733 ), 1, 0, 0 ),
+    m_viewb = (Button*)ac1_4_1->add( new Button( aguix, 0, 0, catalog.getLocale( 731 ), 0 ), 0, 0, AContainer::CO_INCW );
+    m_editb = (Button*)ac1_4_1->add( new Button( aguix, 0, 0, catalog.getLocale( 732 ), 0 ), 1, 0, AContainer::CO_INCW );
+    m_removeb = (Button*)ac1_4_1->add( new Button( aguix, 0, 0, catalog.getLocale( 733 ), 0 ),
                                      2, 0, AContainer::CO_INCW );
   
     AContainerBB *ac1_res_store = dynamic_cast<AContainerBB*>( ac1->add( new AContainerBB( m_win, 1, 3 ), 0, 2 ) );
@@ -1059,7 +1057,7 @@ void SearchOpBG::createWindow()
     ac1_res_store->setMaxSpace( 5 );
     ac1_res_store->setBorderWidth( 5 );
 
-    ac1_res_store->add( new Text( aguix, 0, 0, catalog.getLocale( 734 ), 1 ), 0, 0, AContainer::CO_INCW );
+    ac1_res_store->add( new Text( aguix, 0, 0, catalog.getLocale( 734 ) ), 0, 0, AContainer::CO_INCW );
     _storelv = (FieldListView*)ac1_res_store->add( new FieldListView( aguix, 0, 0, 100, 5 * aguix->getCharHeight(), 0 ), 0, 1, AContainer::CO_MIN );
     _storelv->setHBarState( 0 );
     _storelv->setVBarState( 2 );
@@ -1076,15 +1074,15 @@ void SearchOpBG::createWindow()
     _storelv->setMBG( wconfig->getListerBG() );
     _storelv->setGlobalFieldSpace( 5 );
 
-    m_clearstoreb =(Button*)ac1_res_store->add( new Button( aguix, 0, 0, catalog.getLocale( 738 ), 1, 0, 0 ), 0, 2, AContainer::CO_INCW );
+    m_clearstoreb =(Button*)ac1_res_store->add( new Button( aguix, 0, 0, catalog.getLocale( 738 ), 0 ), 0, 2, AContainer::CO_INCW );
 
     AContainer *ac1_6 = ac1->add( new AContainer( m_win, 2, 1 ), 0, 3 );
     ac1_6->setMinSpace( 5 );
     ac1_6->setMaxSpace( 5 );
     ac1_6->setBorderWidth( 0 );
 
-    ac1_6->add( new Text( aguix, 0, 0, catalog.getLocale( 739 ), 1 ), 0, 0, AContainer::CO_FIX );
-    m_state_text = (Text*)ac1_6->add( new Text( aguix, 0, 0, catalog.getLocale( 740 ), 1 ), 1, 0, AContainer::CO_INCW );
+    ac1_6->add( new Text( aguix, 0, 0, catalog.getLocale( 739 ) ), 0, 0, AContainer::CO_FIX );
+    m_state_text = (Text*)ac1_6->add( new Text( aguix, 0, 0, catalog.getLocale( 740 ) ), 1, 0, AContainer::CO_INCW );
     m_state_text->setTextShrinker( RefCount<TextShrinker>( new FileNameShrinker() ) );
 
     AContainer *ac1_5 = ac1->add( new AContainer( m_win, 4, 1 ), 0, 4 );
@@ -1095,22 +1093,16 @@ void SearchOpBG::createWindow()
                                                0,
                                                0,
                                                catalog.getLocale( 741 ),
-                                               1,
-                                               0,
                                                0 ), 0, 0, AContainer::CO_FIX );
     m_stopb = (Button*)ac1_5->add( new Button( aguix,
                                                0,
                                                0,
                                                catalog.getLocale( 742 ),
-                                               1,
-                                               0,
                                                0 ), 1, 0, AContainer::CO_FIX );
     m_closeb = (Button*)ac1_5->add( new Button( aguix,
                                                 0,
                                                 0,
                                                 catalog.getLocale( 633 ),
-                                                1,
-                                                0,
                                                 0 ), 3, 0, AContainer::CO_FIX );
   
     int startb_maxwidth = aguix->getTextWidth( catalog.getLocale( 741 ) ), temp_width;
