@@ -1,6 +1,6 @@
 /* searchthread.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2006-2008,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -30,8 +30,8 @@
 
 #include <iostream>
 
-SearchThread::SearchThread( std::auto_ptr<NWC::Dir> searchdir ) : _current_mode( SEARCHING ),
-                                                                  _mode_order( SEARCH )
+SearchThread::SearchThread( std::unique_ptr<NWC::Dir> searchdir ) : _current_mode( SEARCHING ),
+                                                                    _mode_order( SEARCH )
 {
   _searchdir = searchdir.release();
 }
@@ -159,22 +159,24 @@ int SearchThread::visitEnterDir( NWC::Dir &dir, NWC::Dir::WalkControlObj &cobj )
     _current_action = catalog.getLocale( 747 );
     _current_action += dir.getFullname();
     _current_action_lock.unlock();
-    
-    if ( m_sets.getCheckYounger() == true && dir.stat_lastmod() < m_sets.getYoungerThanDate() ) {
-        candidate = false;
-    } else if ( m_sets.getCheckOlder() == true && dir.stat_lastmod() > m_sets.getOlderThanDate() ) {
-        candidate = false;
-    } else if ( m_sets.getCheckSizeGEQ() == true ||
-                m_sets.getCheckSizeLEQ() == true ) {
-        candidate = false;
-    }
 
-    if ( candidate == true ) {
-        if ( checkName( m_sets.getMatchNameFullPath() == true ? dir.getFullname() : dir.getBasename() ) == true ) {
-            if ( m_sets.getMatchContent().length() < 1 ) {
-                _result_lock.lock();
-                _results.push_back( SearchResult( dir.getFullname(), -1, true ) );
-                _result_lock.unlock();
+    if ( m_sets.getMatchAlsoDirectories() ) {
+        if ( m_sets.getCheckYounger() == true && dir.stat_lastmod() < m_sets.getYoungerThanDate() ) {
+            candidate = false;
+        } else if ( m_sets.getCheckOlder() == true && dir.stat_lastmod() > m_sets.getOlderThanDate() ) {
+            candidate = false;
+        } else if ( m_sets.getCheckSizeGEQ() == true ||
+                    m_sets.getCheckSizeLEQ() == true ) {
+            candidate = false;
+        }
+
+        if ( candidate == true ) {
+            if ( checkName( m_sets.getMatchNameFullPath() == true ? dir.getFullname() : dir.getBasename() ) == true ) {
+                if ( m_sets.getMatchContent().length() < 1 ) {
+                    _result_lock.lock();
+                    _results.push_back( SearchResult( dir.getFullname(), -1, true ) );
+                    _result_lock.unlock();
+                }
             }
         }
     }
