@@ -352,7 +352,7 @@ SetFilterOp::doconfigure(int mode)
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getDescription())+1);
   sprintf(tstr,catalog.getLocale(293),getDescription());
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -360,13 +360,13 @@ SetFilterOp::doconfigure(int mode)
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, getDescription(), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, getDescription() ), 0, 0, cincwnr );
 
   AContainer *ac1_0 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
   ac1_0->setMinSpace( 5 );
   ac1_0->setMaxSpace( 5 );
-  ac1_0->add( new Text( aguix, 0, 0, catalog.getLocale( 835 ), 1 ), 0, 0, AContainer::CO_FIX );
-  CycleButton *set_mode_cycb = (CycleButton*)ac1_0->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, AContainer::CO_INCW );
+  ac1_0->add( new Text( aguix, 0, 0, catalog.getLocale( 835 ) ), 0, 0, AContainer::CO_FIX );
+  CycleButton *set_mode_cycb = (CycleButton*)ac1_0->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, AContainer::CO_INCW );
   set_mode_cycb->addOption( catalog.getLocale( 836 ) );
   set_mode_cycb->addOption( catalog.getLocale( 837 ) );
 
@@ -384,15 +384,15 @@ SetFilterOp::doconfigure(int mode)
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 5 );
   ChooseButton *pattern_cb = (ChooseButton*)ac1_1->add( new ChooseButton( aguix, 0, 0, m_change_filters,
-                                                                          catalog.getLocale( 838 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CO_INCWNR );
+                                                                          catalog.getLocale( 838 ), LABEL_RIGHT, 0 ), 0, 0, AContainer::CO_INCWNR );
 
   AContainer *ac1_1_1 = ac1_1->add( new AContainer( win, 2, 1 ), 0, 1 );
   ac1_1_1->setMinSpace( 5 );
   ac1_1_1->setMaxSpace( 5 );
   ac1_1_1->setBorderWidth( 0 );
 
-  ac1_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 133 ), 1 ), 0, 0, cfix );
-  fmcyb = (CycleButton*)ac1_1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 133 ) ), 0, 0, cfix );
+  fmcyb = (CycleButton*)ac1_1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   fmcyb->addOption(catalog.getLocale(191));
   fmcyb->addOption(catalog.getLocale(192));
   fmcyb->addOption(catalog.getLocale(193));
@@ -418,7 +418,7 @@ SetFilterOp::doconfigure(int mode)
   ac1_2->setMaxSpace( 0 );
   ac1_2->setBorderWidth( 0 );
 
-  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 93 ), 1 ), 0, 1, cfix );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 93 ) ), 0, 1, cfix );
 
   if ( mode != 0 ) {
     lv = (FieldListView*)ac1_2->add( new FieldListView( aguix, 0, 0, 100,
@@ -451,14 +451,14 @@ SetFilterOp::doconfigure(int mode)
   ac1_bs->setMaxSpace( 5 );
   ac1_bs->setBorderWidth( 5 );
   ChooseButton *bookmark_cb = (ChooseButton*)ac1_bs->add( new ChooseButton( aguix, 0, 0, m_change_bookmarks,
-                                                                            catalog.getLocale( 839 ), LABEL_RIGHT, 1, 0 ), 0, 0, AContainer::CO_INCWNR );
+                                                                            catalog.getLocale( 839 ), LABEL_RIGHT, 0 ), 0, 0, AContainer::CO_INCWNR );
 
   AContainer *ac1_bs_1 = ac1_bs->add( new AContainer( win, 2, 1 ), 0, 1 );
   ac1_bs_1->setMinSpace( 5 );
   ac1_bs_1->setMaxSpace( 5 );
   ac1_bs_1->setBorderWidth( 0 );
-  ac1_bs_1->add( new Text( aguix, 0, 0, catalog.getLocale( 840 ), 1 ), 0, 0, AContainer::CO_FIX );
-  CycleButton *bookmark_filter_cycb = (CycleButton*)ac1_bs_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, AContainer::CO_INCW );
+  ac1_bs_1->add( new Text( aguix, 0, 0, catalog.getLocale( 840 ) ), 0, 0, AContainer::CO_FIX );
+  CycleButton *bookmark_filter_cycb = (CycleButton*)ac1_bs_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, AContainer::CO_INCW );
   bookmark_filter_cycb->addOption( catalog.getLocale( 841 ) );
   bookmark_filter_cycb->addOption( catalog.getLocale( 842 ) );
   bookmark_filter_cycb->addOption( catalog.getLocale( 843 ) );
@@ -486,7 +486,7 @@ SetFilterOp::doconfigure(int mode)
   ac1_bs_2->setMinWidth( 5, 1, 0 );
   ac1_bs_2->setMaxWidth( 5, 1, 0 );
 
-  ac1_bs_2->add( new Text( aguix, 0, 0, catalog.getLocale( 844 ), 1 ), 0, 1, AContainer::CO_FIX );
+  ac1_bs_2->add( new Text( aguix, 0, 0, catalog.getLocale( 844 ) ), 0, 1, AContainer::CO_FIX );
   
   FieldListView *label_lv = (FieldListView*)ac1_bs_2->add( new FieldListView( aguix,
                                                                               0, 0,
@@ -523,11 +523,11 @@ SetFilterOp::doconfigure(int mode)
                                                                                     m_bookmark_label.c_str(), 0 ), 2, 1, AContainer::CO_INCW );
 
   ChooseButton *query_label_cb = (ChooseButton*)ac1_bs->add( new ChooseButton( aguix, 0, 0, m_query_label,
-                                                                               catalog.getLocale( 850 ), LABEL_RIGHT, 1, 0 ), 0, 3, AContainer::CO_INCWNR );
+                                                                               catalog.getLocale( 850 ), LABEL_RIGHT, 0 ), 0, 3, AContainer::CO_INCWNR );
 
   if(mode==0) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20,( request_flags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 1, 0 ), 0, 4, cincwnr );
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ), 0, 4, cincwnr );
   }
 
   AContainer *ac1_3 = ac1->add( new AContainer( win, 2, 1 ), 0, 5 );
@@ -538,15 +538,11 @@ SetFilterOp::doconfigure(int mode)
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_3->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   fmcyb->takeFocus();
