@@ -1,6 +1,6 @@
 /* setfilterop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2010-2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2004,2008,2010-2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -99,7 +99,7 @@ protected:
   int normalmodesf( ActionMessage* );
 
   void addHistoryItem( const std::string &str );
-  static std::auto_ptr< PersistentStringList > m_history;
+  static std::unique_ptr< PersistentStringList > m_history;
 private:
   static int instance_counter;
   static size_t history_size;
