@@ -1,6 +1,6 @@
 /* setsortmodeop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2010-2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -148,7 +148,7 @@ int SetSortmodeOp::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(getName())+1);
   sprintf(tstr,catalog.getLocale(293),getName());
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -161,8 +161,8 @@ int SetSortmodeOp::configure()
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 158 ), 1 ), 0, 0, cfix );
-  cyb[0] = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 158 ) ), 0, 0, cfix );
+  cyb[0] = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   cyb[0]->addOption(catalog.getLocale(160));
   cyb[0]->addOption(catalog.getLocale(161));
   cyb[0]->addOption(catalog.getLocale(162));
@@ -188,15 +188,15 @@ int SetSortmodeOp::configure()
 
   chb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20,
 						   ( ( mode & SORT_REVERSE ) == SORT_REVERSE ) ? 1 : 0,
-						   catalog.getLocale( 165 ), LABEL_RIGHT, 1, 0 ), 0, 1, cincwnr );
+						   catalog.getLocale( 165 ), LABEL_RIGHT, 0 ), 0, 1, cincwnr );
 
   AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 2 );
   ac1_2->setMinSpace( 5 );
   ac1_2->setMaxSpace( 5 );
   ac1_2->setBorderWidth( 0 );
 
-  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 353 ), 1 ), 0, 0, cfix );
-  cyb[1] = (CycleButton*)ac1_2->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 353 ) ), 0, 0, cfix );
+  cyb[1] = (CycleButton*)ac1_2->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   cyb[1]->addOption(catalog.getLocale(354));
   cyb[1]->addOption(catalog.getLocale(355));
   cyb[1]->addOption(catalog.getLocale(356));
@@ -214,15 +214,11 @@ int SetSortmodeOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_3->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
