@@ -1,6 +1,6 @@
 /* startprogop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -40,11 +40,14 @@
 #include <aguix/choosebutton.h>
 #include <aguix/stringgadget.h>
 #include <aguix/button.h>
+#include <aguix/textview.h>
 #include "wconfig.h"
 #include "flattypelist.hh"
 #include "argclass.hh"
 #include "nwc_path.hh"
 #include "pers_string_list.hh"
+#include "wpucontext.h"
+#include "ownop.h"
 
 const char *StartProgOp::name="StartProgOp";
 
@@ -60,6 +63,9 @@ StartProgOp::StartProgOp() : FunctionProto()
   hasConfigure = true;
 
   gui_msg = "";
+
+  m_cmd_sg = nullptr;
+  m_cmd_flag_b = nullptr;
 }
 
 StartProgOp::~StartProgOp()
@@ -99,7 +105,7 @@ StartProgOp::run( WPUContext *wpu, ActionMessage *msg )
     if(l1!=NULL) {
       startlister=l1;
       endlister = msg->getWorker()->getOtherLister(startlister);
-      startprog( msg );
+      startprog( wpu, msg );
     }
   }
   return 0;
@@ -139,8 +145,35 @@ StartProgOp::getDescription()
   return catalog.getLocaleCom(32);
 }
 
+/* replace backslash with double backslash and backslash { and } */
+static std::string protectForParsing( const char *str1 )
+{
+    std::string res;
+
+    if ( str1 != NULL ) {
+        for ( ; *str1 != '\0'; str1++ ) {
+            switch ( *str1 ) {
+                case '\\':
+                    res += "\\\\";
+                    break;
+                case '{':
+                    res += "\\{";
+                    break;
+                case '}':
+                    res += "\\}";
+                    break;
+                default:
+                    res += *str1;
+                    break;
+            }
+        }
+    }
+
+    return res;
+}
+
 int
-StartProgOp::startprog( ActionMessage *am )
+StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
 {
   ListerMode *lm1 = NULL;
 
@@ -200,9 +233,18 @@ StartProgOp::startprog( ActionMessage *am )
       
       if ( m1->_start == STARTPROGOP_SHOW_OUTPUT_INT ) {
           tmpoutput_lnk = Datei::createTMPHardlink( tmpoutput );
+
+          wpu->ref();
+
           pea = new ProcessExitAction( true,
                                        tmpoutput_lnk,
-                                       am->getWorker(), NULL );
+                                       am->getWorker(), wpu );
+      } else {
+          wpu->ref();
+
+          pea = new ProcessExitAction( false,
+                                       "",
+                                       am->getWorker(), wpu );
       }
 
       Datei fp;
@@ -218,8 +260,14 @@ StartProgOp::startprog( ActionMessage *am )
             }
         }
         if ( m1->_global == false ) fp.putString( "./" );
-      
-        string1 = Worker_secureCommandForShell( m1->_command.c_str() );
+
+        std::string res_str;
+        if ( wpu->parse( m1->_command.c_str(),
+                         res_str,
+                         EXE_STRING_LEN - strlen( tmpoutput ) - 3 ) == WPUContext::PARSE_SUCCESS ) {
+            string1 = Worker_secureCommandForShell( res_str.c_str() );
+        }
+
         if ( string1.length() > 0 ) {
           if ( m1->_start == STARTPROGOP_SHOW_OUTPUT ||
                m1->_start == STARTPROGOP_SHOW_OUTPUT_INT ) {
@@ -354,15 +402,15 @@ std::unique_ptr< StartProgOp::SettingsWidgets > StartProgOp::buildW( AWindow *wi
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 638 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 638 ) ), 0, 0, cincwnr );
 
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
   ac1_1->setMinSpace( 5 );
   ac1_1->setMaxSpace( 5 );
   ac1_1->setBorderWidth( 0 );
 
-  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 331 ), 1 ), 0, 0, cfix );
-  cyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 1, 0, cincw );
+  ac1_1->add( new Text( aguix, 0, 0, catalog.getLocale( 331 ) ), 0, 0, cfix );
+  cyb = (CycleButton*)ac1_1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 1, 0, cincw );
   cyb->addOption(catalog.getLocale(332));
   cyb->addOption(catalog.getLocale(333));
   cyb->addOption(catalog.getLocale(334));
@@ -393,18 +441,17 @@ std::unique_ptr< StartProgOp::SettingsWidgets > StartProgOp::buildW( AWindow *wi
   ac1_2->setMaxSpace( 5 );
   ac1_2->setBorderWidth( 0 );
 
-  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ), 1 ), 0, 0, cfix );
+  ac1_2->add( new Text( aguix, 0, 0, catalog.getLocale( 337 ) ), 0, 0, cfix );
   sg = (StringGadget*)ac1_2->add( new StringGadget( aguix, 0, 0, 100, view_str.c_str(), 0 ), 1, 0, cincw );
 
   gcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, ( global == true ) ? 1 : 0,
-						   catalog.getLocale( 343 ), LABEL_RIGHT, 1, 0 ), 0, 3, cincwnr );
+						   catalog.getLocale( 343 ), LABEL_RIGHT, 0 ), 0, 3, cincwnr );
   ibcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
                                                     0,
                                                     0,
                                                     ( inbackground == true ) ? 1 : 0,
                                                     catalog.getLocale( 435 ),
                                                     LABEL_RIGHT,
-                                                    1,
                                                     0 ), 0, 4, cincwnr );
 
   dcdcb = (ChooseButton*)ac1->add( new ChooseButton( aguix,
@@ -413,7 +460,6 @@ std::unique_ptr< StartProgOp::SettingsWidgets > StartProgOp::buildW( AWindow *wi
 						     ( dontcd == true ) ? 1 : 0,
 						     catalog.getLocale( 617 ),
 						     LABEL_RIGHT,
-						     1,
 						     0 ), 0, 5, cincwnr );
 
   win->contMaximize( true );
@@ -442,7 +488,7 @@ int StartProgOp::doconfigure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(32))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(32));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -450,7 +496,7 @@ int StartProgOp::doconfigure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  AWindow *subwin1 = new AWindow( aguix, 10, 10, 10, 10, 0, "" );
+  AWindow *subwin1 = new AWindow( aguix, 10, 10, 10, 10, "" );
   ac1->add( subwin1, 0, 0, cmin );
 
   std::unique_ptr< SettingsWidgets > m1 = buildW( subwin1 );
@@ -464,15 +510,11 @@ int StartProgOp::doconfigure()
 					0,
 					0,
 					catalog.getLocale( 11 ),
-					1,
-					0,
 					0 ), 0, 0, cfix );
   cb = (Button*)ac1_3->add( new Button( aguix,
 					0,
 					0,
 					catalog.getLocale( 8 ),
-					1,
-					0,
 					0 ), 1, 0, cfix );
 
   okb->takeFocus();
@@ -587,14 +629,14 @@ void StartProgOp::setViewStr( std::string nv )
 }
 
 StartProgOp::SettingsWidgets::SettingsWidgets( StringGadget *sg,
-					       CycleButton *cyb,
-					       ChooseButton *gcb,
-					       ChooseButton *ibcb,
-					       ChooseButton *dcdcb ) : _sg( sg ),
-								      _cyb( cyb ),
-								      _gcb( gcb ),
-								      _ibcb( ibcb ),
-								      _dcdcb( dcdcb )
+                                               CycleButton *cyb,
+                                               ChooseButton *gcb,
+                                               ChooseButton *ibcb,
+                                               ChooseButton *dcdcb ) : _sg( sg ),
+                                                                       _cyb( cyb ),
+                                                                       _gcb( gcb ),
+                                                                       _ibcb( ibcb ),
+    _dcdcb( dcdcb )
 {
 }
 
@@ -650,28 +692,25 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   const int cmin = AContainer::ACONT_MINH +
                    AContainer::ACONT_MINW;
   int i;
-  char *tstr;
-  int lines;
-  char **liness;
   std::string str1;
 
   if ( gui_msg.length() < 1 )
     gui_msg = catalog.getLocale( 645 );
 
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, catalog.getLocaleCom( 32 ) );
+  win = new AWindow( aguix, 10, 10, 10, 10, catalog.getLocaleCom( 32 ) );
   win->create();
 
   AContainer *ac1 = win->setContainer( new AContainer( win, 1, 3 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
   
-  ac1->add( new Text( aguix, 0, 0, gui_msg.c_str(), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, gui_msg.c_str() ), 0, 0, cincwnr );
 
-  Kartei *k1 = new Kartei( aguix, 10, 10, 10, 10, 0, "" );
+  Kartei *k1 = new Kartei( aguix, 10, 10, 10, 10, "" );
   ac1->add( k1, 0, 1, cmin );
   k1->create();
 
-  AWindow *subwin11 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  AWindow *subwin11 = new AWindow( aguix, 0, 0, 10, 10, "" );
   k1->add( subwin11 );
   subwin11->create();
   
@@ -680,34 +719,54 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   acsw11->setMaxSpace( 5 );
   acsw11->setBorderWidth( 5 );
 
-  lines = createLines( catalog.getLocale( 522 ), &liness );
+  RefCount<AFontWidth> lencalc( new AFontWidth( aguix, NULL ) );
+  TextStorageString help_ts( catalog.getLocale( 1076 ), lencalc );
+  TextView *help_tv = (TextView*)acsw11->add( new TextView( aguix,
+                                                            0, 0, 50, 80, "", help_ts ),
+                                              0, 0, AContainer::CO_INCW );
+  help_tv->setLineWrap( true );
+  help_tv->maximizeX( 500 );
+  help_tv->maximizeYLines( 10 );
+  help_tv->showFrame( false );
+  acsw11->readLimits();
+  help_tv->show();
+  help_tv->setAcceptFocus( false );
 
-  AContainer *acsw11_t = acsw11->add( new AContainer( subwin11, 1, lines ), 0, 0 );
-  acsw11_t->setMinSpace( 5 );
-  acsw11_t->setMaxSpace( 5 );
-  acsw11_t->setBorderWidth( 0 );
-
-  for ( i = 0; i < lines; i++ ) {
-    acsw11_t->add( new Text( aguix, 0, 0, liness[i], 1 ),
-		   0, i, cincwnr );
-  }
-  
-  for ( i = 0; i < lines; i++ ) _freesafe( liness[i] );
-  _freesafe( liness );
+  TextView::ColorDef tv_cd = help_tv->getColors();
+  tv_cd.setBackground( 0 );
+  tv_cd.setTextColor( 1 );
+  help_tv->setColors( tv_cd );
 
   AContainer *acsw11_1 = acsw11->add( new AContainer( subwin11, 2, 2 ), 0, 1 );
   acsw11_1->setMinSpace( 5 );
   acsw11_1->setMaxSpace( 5 );
   acsw11_1->setBorderWidth( 0 );
 
-  tstr = AGUIX_catQuotedAndUnQuoted( "", default_file.c_str() );
+  std::string cmd_string;
+  {
+      char *tstr = AGUIX_catQuotedAndUnQuoted( "", default_file.c_str() );
+      cmd_string = protectForParsing( tstr );
+      _freesafe( tstr );
+  }
 
-  acsw11_1->add( new Text( aguix, 0, 0, catalog.getLocale( 639 ), 1 ), 0, 0, cfix );
-  m_cmd_sg = (StringGadget*)acsw11_1->add( new StringGadget( aguix, 0,
-                                                             0, 100, tstr, 0 ), 1, 0, cincw );
-  _freesafe( tstr );
+  acsw11_1->add( new Text( aguix, 0, 0, catalog.getLocale( 639 ) ), 0, 0, cfix );
 
-  acsw11_1->add( new Text( aguix, 0, 0, catalog.getLocale( 1035 ), 1 ), 0, 1,
+  AContainer *acsw11_1_1 = acsw11_1->add( new AContainer( subwin11, 2, 1 ), 1, 0 );
+  acsw11_1_1->setMinSpace( 0 );
+  acsw11_1_1->setMaxSpace( 0 );
+  acsw11_1_1->setBorderWidth( 0 );
+
+  m_cmd_sg = acsw11_1_1->addWidget( new StringGadget( aguix, 0,
+                                                      0, 100, cmd_string.c_str(), 0 ), 0, 0, cincw );
+
+  m_cmd_flag_b = acsw11_1_1->addWidget( new Button( aguix,
+                                                    0,
+                                                    0,
+                                                    "F",
+                                                    0 ), 1, 0, cfix );
+  m_cmd_flag_b->setBubbleHelpText( catalog.getLocale( 1131 ) );
+
+  acsw11_1->add( new Text( aguix, 0, 0, catalog.getLocale( 1035 ) ), 0, 1,
                  AContainer::ACONT_MINH +
                  AContainer::ACONT_MINW +
                  AContainer::ACONT_MAXW +
@@ -718,19 +777,19 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   m_completion_lv->setHBarState( 2 );
   m_completion_lv->setVBarState( 2 );
 
-  AWindow *subwin11_2 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  AWindow *subwin11_2 = new AWindow( aguix, 0, 0, 10, 10, "" );
   acsw11->add( subwin11_2, 0, 2, cmin );
   subwin11_2->create();
   std::unique_ptr< SettingsWidgets > m1 = buildW( subwin11_2 );
   acsw11->readLimits();
 
-  AWindow *subwin12 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  AWindow *subwin12 = new AWindow( aguix, 0, 0, 10, 10, "" );
   k1->add( subwin12 );
   subwin12->create();
 
   std::unique_ptr< FiletypeWindow > ftw = buildFTWindow( subwin12 );
 
-  AWindow *subwin13 = new AWindow( aguix, 0, 0, 10, 10, 0, "" );
+  AWindow *subwin13 = new AWindow( aguix, 0, 0, 10, 10, "" );
   k1->add( subwin13 );
   subwin13->create();
 
@@ -757,15 +816,11 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cancelb = (Button*)ac1_5->add( new Button( aguix,
                                                      0,
                                                      0,
                                                      catalog.getLocale( 8 ),
-                                                     1,
-                                                     0,
                                                      0 ), 1, 0, cfix );
   win->setDoTabCycling( true );
   win->contMaximize( true );
@@ -810,13 +865,20 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
     msg=aguix->WaitMessage(win);
     if(msg!=NULL) {
       switch ( msg->type ) {
-	case AG_CLOSEWINDOW:
-	  if ( msg->closewindow.window == win->getWindow() ) ende = -1;
-        case AG_BUTTONCLICKED:
-          if ( msg->button.button == okb ) {
-	    if ( m1->validate() == 1 ) ende = 1;
-          } else if ( msg->button.button== cancelb ) ende = -1;
-          break;
+          case AG_CLOSEWINDOW:
+              if ( msg->closewindow.window == win->getWindow() ) ende = -1;
+          case AG_BUTTONCLICKED:
+              if ( msg->button.button == okb ) {
+                  if ( m1->validate() == 1 ) ende = 1;
+              } else if ( msg->button.button== cancelb ) ende = -1;
+              else if ( msg->button.button == m_cmd_flag_b ) {
+                  char *tstr = OwnOp::getFlag();
+                  if ( tstr != NULL ) {
+                      m_cmd_sg->insertAtCursor( tstr );
+                      _freesafe( tstr );
+                  }
+              }
+              break;
 	case AG_STRINGGADGET_DEACTIVATE:
           if ( msg->stringgadget.sg == m1->_sg ) {
 	    m1->validate();
@@ -868,23 +930,23 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
                 m1->_dcdcb->setState( ( m1->_dcdcb->getState() == true ) ? false : true );
                 break;
               case XK_Return:
-                if ( cancelb->getHasFocus() == false ) {
-		  if ( m1->validate() == 1 ) ende = 1;
-                }
-                break;
-              case XK_Escape:
-                ende = -1;
-                break;
-	      case XK_F1:
-		//TODO Was passiert mit Focus, wenn ich per Key die Kartei wechsle?
-		k1->optionChange( 0 );
-		break;
-	      case XK_F2:
-		k1->optionChange( 1 );
-		break;
-	      case XK_F3:
-		k1->optionChange( 2 );
-		break;
+                  if ( cancelb->getHasFocus() == false ) {
+                      if ( m1->validate() == 1 ) ende = 1;
+                  }
+                  break;
+                case XK_Escape:
+                    ende = -1;
+                    break;
+                case XK_F1:
+                    //TODO Was passiert mit Focus, wenn ich per Key die Kartei wechsle?
+                    k1->optionChange( 0 );
+                    break;
+                case XK_F2:
+                    k1->optionChange( 1 );
+                    break;
+                case XK_F3:
+                    k1->optionChange( 2 );
+                    break;
                 case XK_Down:
                     if ( m_completion_lv->getElements() > 0 ) {
                         int trow = m_completion_lv->getActiveRow();
@@ -942,6 +1004,18 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
                       history.pushFrontEntry( base );
                   }
               }
+          } else {
+              std::string base = sets->_command;
+              if ( AGUIXUtils::ends_with( base, "}" ) ) {
+                  AGUIXUtils::rstrip( base );
+
+                  if ( ! base.empty() ) {
+                      if ( base[0] != ' ' ) {
+                          history.removeEntry( base );
+                          history.pushFrontEntry( base );
+                      }
+                  }
+              }
           }
 
           sets->_view_str = m1->_sg->getText();
@@ -983,15 +1057,18 @@ std::unique_ptr< StartProgOp::StartSettings > StartProgOp::showGUI()
   }
   delete win;
 
+  m_cmd_sg = nullptr;
+  m_cmd_flag_b = nullptr;
+
   return std::unique_ptr< StartSettings >( sets );
 }
 
 StartProgOp::StartSettings::StartSettings() : _startmode( CANCEL ),
-					      _type( NULL ),
-					      _start( STARTPROGOP_START_NORMAL ),
-					      _global( true ),
-					      _inbackground( false ),
-					      _dontcd( false )
+                                              _type( NULL ),
+                                              _start( STARTPROGOP_START_NORMAL ),
+                                              _global( true ),
+                                              _inbackground( false ),
+                                              _dontcd( false )
 {
 }
 
@@ -1013,14 +1090,14 @@ std::unique_ptr< StartProgOp::FiletypeWindow > StartProgOp::buildFTWindow( AWind
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 644 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 644 ) ), 0, 0, cincwnr );
 
   AContainer *ac1_sub1 = ac1->add( new AContainer( win, 2, 1 ),
                                    0, 1 );
   ac1_sub1->setMinSpace( 5 );
   ac1_sub1->setMaxSpace( 5 );
 
-  ac1_sub1->add( new Text( aguix, 0, 0, catalog.getLocale( 793 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac1_sub1->add( new Text( aguix, 0, 0, catalog.getLocale( 793 ) ), 0, 0, AContainer::CO_FIX );
   auto sg = ac1_sub1->addWidget( new StringGadget( aguix, 0, 0, 50, "", 0 ),
                                  1, 0, cincw );
 
@@ -1085,7 +1162,7 @@ std::unique_ptr< StartProgOp::ArchiveWindow > StartProgOp::buildArcWindow( AWind
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 640 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 640 ) ), 0, 0, cincwnr );
 
   StringGadget *sg = (StringGadget*)ac1->add( new StringGadget( aguix, 0, 0, 100, "", 0 ), 0, 1, cincw );
 
@@ -1159,8 +1236,10 @@ void StartProgOp::updateSGFromComplete( StringGadget *sg,
     for ( auto &s : m_current_completions ) {
         std::string s2( s );
 
-        s2 += " ";
-        s2 += m_current_original_file;
+        if ( ! AGUIXUtils::ends_with( s2, "}" ) ) {
+            s2 += " ";
+            s2 += m_current_original_file;
+        }
 
         lv->setText( row, 0, s2 );
         lv->setPreColors( row, FieldListView::PRECOLOR_ONLYACTIVE );
@@ -1180,8 +1259,10 @@ void StartProgOp::updateSGFromComplete( StringGadget *sg,
     if ( m_current_completions.empty() ) {
         std::string new_text( prefix );
 
-        new_text += " ";
-        new_text += m_current_original_file;
+        if ( ! AGUIXUtils::ends_with( new_text, "}" ) ) {
+            new_text += " ";
+            new_text += m_current_original_file;
+        }
 
         sg->setText( new_text.c_str() );
 
@@ -1203,8 +1284,10 @@ void StartProgOp::updateSGFromComplete( StringGadget *sg,
             m_previous_sg_content.resize( sg->getCursor() );
         }
 
-        new_text += " ";
-        new_text += m_current_original_file;
+        if ( ! AGUIXUtils::ends_with( new_text, "}" ) ) {
+            new_text += " ";
+            new_text += m_current_original_file;
+        }
 
         sg->setText( new_text.c_str() );
 
