@@ -99,13 +99,13 @@ void TextViewMode::on()
     m_ac1->setMinSpace( 5 );
     m_ac1->setMaxSpace( 5 );
 
-    m_info_text = m_ac1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 404 ), 1 ), 0, 0, AContainer::CO_FIX );
-    m_file_name_text = (Text*)m_ac1->add( new Text( aguix, 0, 0, "", 1 ),
+    m_info_text = m_ac1->addWidget( new Text( aguix, 0, 0, catalog.getLocale( 404 ) ), 0, 0, AContainer::CO_FIX );
+    m_file_name_text = (Text*)m_ac1->add( new Text( aguix, 0, 0, "" ),
                                           1, 0, AContainer::ACONT_MINH + AContainer::ACONT_MAXH );
-    m_file_percentage_text = (Text*)m_ac1->add( new Text( aguix, 0, 0, "", 1 ),
+    m_file_percentage_text = (Text*)m_ac1->add( new Text( aguix, 0, 0, "" ),
                                                 2, 0, AContainer::CO_FIX );
 
-    m_tv = new TextView( aguix, 0, 0, 50, 50, 0, "", *m_ts );
+    m_tv = new TextView( aguix, 0, 0, 50, 50, "", *m_ts );
     m_tv->setFont( wconfig->getFont( 4 ).c_str() );
     m_tv->redraw();
     m_tv->setAcceptFocus( false );
