@@ -1,6 +1,6 @@
 /* virtualdirmode_copy.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2014 Ralf Hoffmann.
+ * Copyright (C) 2013-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,6 +31,7 @@
 #include "nmcopyopdir.hh"
 #include "nwc_path.hh"
 #include "copystate.hh"
+#include <iostream>
 
 const static int BGCOPY_UPDATE_TIMEOUT ( 1000 / 25 );
 
@@ -183,27 +184,37 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
     // now database ready, can start copy-process
 
     int cs_id = cs->m_id;
+    bool move = co->move;
 
     cc->setPreCopyCallback( [this,
                              cs_id]( loff_t size, int id, bool is_dir )
                             {
-                                m_bg_copy_status.bg_copy_messages.message_mutex.lock();
-                                m_bg_copy_status.bg_copy_messages.messages.push_back( CopyBGMessage( cs_id, size, id, is_dir ) );
-                                m_bg_copy_status.bg_copy_messages.message_mutex.unlock();
+                                m_bg_copy_status.post_copy_cb_replies.mutex.lock();
+                                m_bg_copy_status.post_copy_cb_replies.messages.push_back( CopyBGMessage( cs_id, size, id, is_dir ) );
+                                m_bg_copy_status.post_copy_cb_replies.mutex.unlock();
                             } );
 
     cc->setPostCopyCallback( [this,
-                              cs_id]( const std::string &source_fullname, int id,
-                                                       CopyCore::nm_copy_t res,
-                                                       bool is_dir, unsigned long dir_error_counter,
-                                                       const std::string &target_fullname )
+                              cs_id,
+                              move]( const std::string &source_fullname, int id,
+                                     CopyCore::nm_copy_t res,
+                                     bool is_dir, unsigned long dir_error_counter,
+                                     const std::string &target_fullname )
                              {
-                                 m_bg_copy_status.bg_copy_messages.message_mutex.lock();
-                                 m_bg_copy_status.bg_copy_messages.messages.push_back( CopyBGMessage( cs_id, source_fullname,
-                                                                                                      id, res, is_dir,
-                                                                                                      dir_error_counter,
-                                                                                                      target_fullname ) );
-                                 m_bg_copy_status.bg_copy_messages.message_mutex.unlock();
+                                 m_bg_copy_status.post_copy_cb_replies.mutex.lock();
+                                 m_bg_copy_status.post_copy_cb_replies.messages.push_back( CopyBGMessage( cs_id, source_fullname,
+                                                                                                          id, res, is_dir,
+                                                                                                          dir_error_counter,
+                                                                                                          target_fullname ) );
+
+                                 if ( res == CopyCore::NM_COPY_OK ||
+                                      res == CopyCore::NM_COPY_NEED_DELETE ) {
+                                     m_bg_copy_status.post_copy_cb_replies.pers_path_store_relocates.push_back( std::make_tuple( target_fullname,
+                                                                                                                                 source_fullname,
+                                                                                                                                 move ) );
+                                 }
+                                 
+                                 m_bg_copy_status.post_copy_cb_replies.mutex.unlock();
                              } );
 
     if ( ! cc->getCancel() ) {
@@ -443,17 +454,28 @@ void VirtualDirMode::finalizeCopy( std::shared_ptr< CopyState > cs )
 void VirtualDirMode::process_bg_messages()
 {
     for (;;) {
-        m_bg_copy_status.bg_copy_messages.message_mutex.lock();
+        m_bg_copy_status.post_copy_cb_replies.mutex.lock();
 
-        if ( m_bg_copy_status.bg_copy_messages.messages.empty() ) {
-            m_bg_copy_status.bg_copy_messages.message_mutex.unlock();
+        if ( m_bg_copy_status.post_copy_cb_replies.messages.empty() ) {
+            m_bg_copy_status.post_copy_cb_replies.mutex.unlock();
             break;
         }
 
-        CopyBGMessage msg = m_bg_copy_status.bg_copy_messages.messages.front();
-        m_bg_copy_status.bg_copy_messages.messages.pop_front();
+        CopyBGMessage msg = m_bg_copy_status.post_copy_cb_replies.messages.front();
+        m_bg_copy_status.post_copy_cb_replies.messages.pop_front();
 
-        m_bg_copy_status.bg_copy_messages.message_mutex.unlock();
+        time_t now = time( NULL );
+
+        for ( auto &e : m_bg_copy_status.post_copy_cb_replies.pers_path_store_relocates ) {
+            parentlister->getWorker()->relocateEntriesPers( std::get<0>( e ),
+                                                            std::get<1>( e ),
+                                                            now,
+                                                            std::get<2>( e ) );
+        }
+
+        m_bg_copy_status.post_copy_cb_replies.pers_path_store_relocates.clear();
+        
+        m_bg_copy_status.post_copy_cb_replies.mutex.unlock();
 
         std::shared_ptr< CopyState > cs;
 
