@@ -32,7 +32,7 @@
 
 void VirtualDirMode::deletef( struct deleteorder *delorder )
 {
-    int tnrfiles, tnrdirs;
+    long int tnrfiles, tnrdirs;
     int erg;
     bool cancel = false;
     DeleteOpWin *dowin;
@@ -48,6 +48,8 @@ void VirtualDirMode::deletef( struct deleteorder *delorder )
     tnrfiles = ce->getNrOfFiles( 1 );
     tnrdirs = ce->getNrOfDirs( 1 );
 
+    long int invisible_entries = getNrOfInvisibleEntries();
+
     if ( ( delorder->source == delorder->NM_ALLENTRIES ) &&
          ( ( tnrfiles + tnrdirs ) < 1 ) ) {
         auto es = ce->getEntry( ce->getActiveEntryPos() );
@@ -60,6 +62,10 @@ void VirtualDirMode::deletef( struct deleteorder *delorder )
                 if ( fse->getBasename() != ".." ) {
                     if ( fse->isDir( false ) ) tnrdirs++;
                     else tnrfiles++;
+
+                    if ( isPosVisible( ce->getActiveEntryPos() ) == false ) {
+                        invisible_entries++;
+                    }
                 }
             }
         }
@@ -76,9 +82,17 @@ void VirtualDirMode::deletef( struct deleteorder *delorder )
                                    strlen( catalog.getLocale( 8 ) ) + 1 );
     sprintf( buttonstr, "%s|%s", catalog.getLocale( 11 ),
              catalog.getLocale( 8 ) );
-    textstr = (char*)_allocsafe( strlen( catalog.getLocale( 145 ) ) + A_BYTESFORNUMBER( tnrfiles ) +
-                                 A_BYTESFORNUMBER( tnrdirs ) + 1 );
-    sprintf( textstr, catalog.getLocale( 145 ), tnrfiles, tnrdirs );
+
+    if ( invisible_entries > 0 ) {
+        std::string s = AGUIXUtils::formatStringToString( catalog.getLocale( 1119 ),
+                                                          tnrfiles, tnrdirs, invisible_entries );
+        textstr = dupstring( s.c_str() );
+    } else {
+        textstr = (char*)_allocsafe( strlen( catalog.getLocale( 145 ) ) + A_BYTESFORNUMBER( tnrfiles ) +
+                                     A_BYTESFORNUMBER( tnrdirs ) + 1 );
+        sprintf( textstr, catalog.getLocale( 145 ), tnrfiles, tnrdirs );
+    }
+
     erg = dowin->request( catalog.getLocale( 123 ), textstr, buttonstr );
     _freesafe( buttonstr );
     _freesafe( textstr );
@@ -116,7 +130,9 @@ void VirtualDirMode::deletef( struct deleteorder *delorder )
                 break;
         }
         for ( auto &it : dellist ) {
-            dc->registerFEToDelete( *it.entry(), it.getID() );
+            if ( it.entry() ) {
+                dc->registerFEToDelete( *it.entry(), it.getID() );
+            }
         }
     }
 
