@@ -1,6 +1,6 @@
 /* volumemanagerop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009,2011 Ralf Hoffmann.
+ * Copyright (C) 2009,2011,2013 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -21,13 +21,14 @@
 
 #include "volumemanagerop.hh"
 #include "listermode.h"
-#include "normalmode.h"
 #include "volumemanagerui.hh"
 #include "nwc_fsentry.hh"
 #include "nmspecialsourceext.hh"
 #include "worker_locale.h"
 #include "worker.h"
 #include "fileentry.hh"
+#include "argclass.hh"
+#include "nwc_path.hh"
 
 const char *VolumeManagerOp::name = "VolumeManagerOp";
 
@@ -62,7 +63,6 @@ int VolumeManagerOp::run( WPUContext *wpu, ActionMessage *msg )
 {
     Lister *l1;
     ListerMode *lm1;
-    NormalMode *nm1;
     
     l1 = msg->getWorker()->getActiveLister();
     if ( l1 == NULL )
@@ -73,23 +73,20 @@ int VolumeManagerOp::run( WPUContext *wpu, ActionMessage *msg )
     VolumeManagerUI ui( *Worker::getAGUIX(), msg->getWorker()->getVolumeManager() );
 
     lm1 = l1->getActiveMode();
-    if ( lm1 != NULL && lm1->isType( "NormalMode" ) == true ) {
-        nm1 = (NormalMode*)lm1;
-            
-        std::list<NM_specialsourceExt*> sellist;
-        nm1->getSelFiles( &sellist, NormalMode::NM_GETFILES_ONLYACTIVE );
+    if ( lm1 ) {
+        std::list< NM_specialsourceExt > sellist;
+        lm1->getSelFiles( sellist, ListerMode::LM_GETFILES_ONLYACTIVE );
             
         std::string dirname, basename;
 
-        if ( nm1->getCurrentDir() != NULL )
-            dirname = nm1->getCurrentDir();
+        dirname = lm1->getCurrentDirectory();
 
         if ( sellist.empty() == false ) {
-            if ( (*sellist.begin())->entry() != NULL ) {
-                basename = (*sellist.begin())->entry()->name;
+            if ( sellist.begin()->entry() != NULL ) {
+                basename = sellist.begin()->entry()->name;
+                dirname = NWC::Path::dirname( sellist.begin()->entry()->fullname );
             }
         }
-        nm1->freeSelFiles( &sellist );
             
         ui.setCurrentDirname( dirname );
         ui.setCurrentBasename( basename );
@@ -99,14 +96,12 @@ int VolumeManagerOp::run( WPUContext *wpu, ActionMessage *msg )
         std::string dir = ui.getDirectoryToEnter();
         if ( ! dir.empty() ) {
             NWC::FSEntry fse( dir );
-            if ( fse.isDir( true ) ) {
-                l1->switch2Mode( 0 );
-                lm1 = l1->getActiveMode();
-                if ( lm1 != NULL && lm1->isType( "NormalMode" ) == true ) {
-                    nm1 = (NormalMode*)lm1;
-                    
-                    nm1->enterPath( dir );
-                }
+            if ( fse.isDir( true ) && lm1 ) {
+
+                std::list< RefCount< ArgClass > > args;
+
+                args.push_back( new StringArg( dir ) );
+                lm1->runCommand( "enter_dir", args );
             }
         }
         //TODO maybe issue reload if we did not called enterPath?
