@@ -29,6 +29,7 @@
 #include <map>
 #include "layoutsettings.hh"
 #include <aguix/aguix.h>
+#include "stringcomparator.hh"
 
 class Worker;
 class WCPath;
@@ -286,8 +287,8 @@ public:
   void setSaveWorkerStateOnExit( bool nv );
   bool getSaveWorkerStateOnExit() const;
 
-  void setUseVersionStringCompare( bool nv );
-  bool getUseVersionStringCompare() const;
+  void setUseStringCompareMode( StringComparator::string_comparator_modes nv );
+  StringComparator::string_comparator_modes getUseStringCompareMode() const;
 
   void setPathJumpStoreFilesAlways( bool nv );
   bool getPathJumpStoreFilesAlways() const;
@@ -521,7 +522,7 @@ protected:
         int preferred_udisks_version;
     } m_vm_settings;
 
-    bool m_use_version_string_compare;
+    StringComparator::string_comparator_modes m_use_string_compare_mode;
     bool m_apply_window_dialog_type;
     bool m_use_extended_regex;
     std::list< std::string > m_pathjump_allow_dirs;
