@@ -63,10 +63,10 @@ int FiletypePanel::create()
   ac1_0->setMinSpace( 5 );
   ac1_0->setMaxSpace( 5 );
 
-  ac1_0->add( new Text( _aguix, 0, 0, catalog.getLocale( 793 ), 1 ), 0, 0, AContainer::CO_FIX );
+  ac1_0->add( new Text( _aguix, 0, 0, catalog.getLocale( 793 ) ), 0, 0, AContainer::CO_FIX );
   m_filter_sg = (StringGadget*)ac1_0->add( new StringGadget( _aguix, 0, 0, 100, "", 1 ), 1, 0, AContainer::CO_INCW );
   m_filter_sg->connect( this );
-  m_clear_filter_b = (Button*)ac1_0->add( new Button( _aguix, 0, 0, catalog.getLocale( 794 ), 1, 0, 0 ), 2, 0, AContainer::CO_FIX );
+  m_clear_filter_b = (Button*)ac1_0->add( new Button( _aguix, 0, 0, catalog.getLocale( 794 ), 0 ), 2, 0, AContainer::CO_FIX );
   m_clear_filter_b->connect( this );
 
   lv = (FieldListView*)ac1->add( new FieldListView( _aguix, 0, 0, 100, 150, 0 ), 0, 2, AContainer::CO_MIN );
@@ -86,11 +86,11 @@ int FiletypePanel::create()
   ac1_1_1->setMinSpace( 0 );
   ac1_1_1->setMaxSpace( 0 );
 
-  newb = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 85 ), 1, 0, 0 ), 0, 0, AContainer::CO_INCW );
+  newb = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 85 ), 0 ), 0, 0, AContainer::CO_INCW );
   newb->connect( this );
-  newchildb = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 596 ), 1, 0, 0 ), 1, 0, AContainer::CO_INCW );
+  newchildb = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 596 ), 0 ), 1, 0, AContainer::CO_INCW );
   newchildb->connect( this );
-  dupb = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 86 ), 1, 0, 0 ), 2, 0, AContainer::CO_INCW );
+  dupb = (Button*)ac1_1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 86 ), 0 ), 2, 0, AContainer::CO_INCW );
   dupb->connect( this );
 
   AContainer *ac1_1_2 = ac1_1->add( new AContainer( this, 2, 1 ), 0, 1 );
@@ -98,9 +98,9 @@ int FiletypePanel::create()
   ac1_1_2->setMinSpace( 5 );
   ac1_1_2->setMaxSpace( 5 );
 
-  editb = (Button*)ac1_1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 88 ), 1, 0, 0 ), 0, 0, AContainer::CO_INCW );
+  editb = (Button*)ac1_1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 88 ), 0 ), 0, 0, AContainer::CO_INCW );
   editb->connect( this );
-  delb = (Button*)ac1_1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 87 ), 1, 0, 0 ), 1, 0, AContainer::CO_INCW );
+  delb = (Button*)ac1_1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 87 ), 0 ), 1, 0, AContainer::CO_INCW );
   delb->connect( this );
 
   AContainer *ac1_1_3 = ac1_1->add( new AContainer( this, 3, 1 ), 0, 2 );
@@ -108,11 +108,11 @@ int FiletypePanel::create()
   ac1_1_3->setMinSpace( 0 );
   ac1_1_3->setMaxSpace( 0 );
 
-  cutb = (Button*)ac1_1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 598 ), 1, 0, 0 ), 0, 0, AContainer::CO_INCW );
+  cutb = (Button*)ac1_1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 598 ), 0 ), 0, 0, AContainer::CO_INCW );
   cutb->connect( this );
-  pasteb = (Button*)ac1_1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 599 ), 1, 0, 0 ), 1, 0, AContainer::CO_INCW );
+  pasteb = (Button*)ac1_1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 599 ), 0 ), 1, 0, AContainer::CO_INCW );
   pasteb->connect( this );
-  pastechildb = (Button*)ac1_1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 600 ), 1, 0, 0 ), 2, 0, AContainer::CO_INCW );
+  pastechildb = (Button*)ac1_1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 600 ), 0 ), 2, 0, AContainer::CO_INCW );
   pastechildb->connect( this );
 
   tempconfig->getFiletypes()->sort( WCFiletype::sortfunction, 0 );
