@@ -62,11 +62,11 @@ int PathJumpAllowPanel::create()
     ac1_1->setMaxSpace( 0 );
     ac1_1->setBorderWidth( 0 );
 
-    m_newb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 181 ), 1, 0, 0 ),
+    m_newb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 181 ), 0 ),
                                   0, 0, AContainer::CO_INCW );
     m_newb->connect( this );
 
-    m_delb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 183 ), 1, 0, 0 ),
+    m_delb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 183 ), 0 ),
                                   1, 0, AContainer::CO_INCW );
     m_delb->connect( this );
 
@@ -74,7 +74,6 @@ int PathJumpAllowPanel::create()
                                                          _baseconfig.getPathJumpStoreFilesAlways(),
                                                          catalog.getLocale( 1043 ),
                                                          LABEL_RIGHT,
-                                                         1,
                                                          0 ), 0, 3, AContainer::CO_INCWNR );
 
     contMaximize( true );
