@@ -1,6 +1,6 @@
 /* wdefines.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2011 Ralf Hoffmann.
+ * Copyright (C) 2001-2012 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -116,12 +116,15 @@ extern "C" {
 #endif
 
 //#define EXE_STRING_LEN ARG_MAX
-#if MAX_CMD_LEN < 0
+#if ! defined( MAX_CMD_LEN ) || MAX_CMD_LEN < 0
 #  define EXE_STRING_LEN ( 1024 * 1024 )
 #elif ( MAX_CMD_LEN < 4096 ) && ( MAX_CMD_LEN < ARG_MAX )
 #  define EXE_STRING_LEN ARG_MAX
-#else
+#elif MAX_CMD_LEN < ( 10 * 1024 * 1024 )
 #  define EXE_STRING_LEN MAX_CMD_LEN
+#else
+// use this upper limit right now since sometimes the autoconf test gives very large values (like 4GB)
+#  define EXE_STRING_LEN ( 10 * 1024 * 1024 )
 #endif
 
 #ifdef DEVELOPER
