@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -210,6 +210,10 @@ public:
     void storePathPers( const std::string &path, time_t ts );
     void removePathPers( const std::string &path );
     std::list< std::pair< std::string, time_t > > getPathsPers();
+    void relocateEntriesPers( const std::string &dest,
+                              const std::string &source,
+                              time_t ts,
+                              bool move );
 
     void storePathPersIfInProgress( const std::string &path );
     void setPathJumpInProgress( bool nv = true );
@@ -418,6 +422,8 @@ protected:
 
     void setKeyChainCandidateActive( bool nv );
 
+    void showButtonCommandHelp( int i, int j, int state );
+
     DeepPathStore m_path_store;
     std::unique_ptr< PersDeepPathStore > m_pers_path_store;
 
@@ -446,6 +452,8 @@ protected:
     std::unique_ptr< PrefixDB > m_pdb;
 
     bool m_key_chain_cand_active;
+
+    TimedText m_button_help_text;
 };
 
 #endif
