@@ -1,6 +1,6 @@
 /* worker_commands.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -214,6 +214,12 @@ FunctionProto *Worker::getCommand4ID(int id)
     case 62:
       fpr = new CommandMenuOp();
       break;
+    case 63:
+      fpr = new ChTimeOp();
+      break;
+    case 64:
+      fpr = new ChangeColumnsOp();
+      break;
     default:
       fpr=new DNDAction();
   }
@@ -286,6 +292,8 @@ int Worker::getID4Command(FunctionProto *fpr)
   else if ( fpr->isName( PathJumpOp::name ) == true ) type = 60;
   else if ( fpr->isName( ClipboardOp::name ) == true ) type = 61;
   else if ( fpr->isName( CommandMenuOp::name ) == true ) type = 62;
+  else if ( fpr->isName( ChTimeOp::name ) == true ) type = 63;
+  else if ( fpr->isName( ChangeColumnsOp::name ) == true ) type = 64;
   return type;
 }
 
