@@ -1,6 +1,6 @@
 /* worker_commands.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -73,6 +73,10 @@
 #include "textviewmode.hh"
 #include "virtualdirmode.hh"
 
+#include "chtimeop.hh"
+
+#include "changecolumnsop.hh"
+
 #endif
 
 /* Local Variables: */
