@@ -27,7 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1136
+#define CATENTRY 1159
 #define CATCOMENTRY 65
 #define CATFLAGENTRY 59
 
@@ -1241,6 +1241,29 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1133]=dupstring( "Comma separates multiple patterns" );
   catalog[1134]=dupstring( "Executed command: %s" );
   catalog[1135]=dupstring( "Show Worker version, license, and compile time parameter" );
+  catalog[1136]=dupstring( "Next match" );
+  catalog[1137]=dupstring( "Previous match" );
+  catalog[1138]=dupstring( "Restart search from top" );
+  catalog[1139]=dupstring( "Matched position:" );
+  catalog[1140]=dupstring( "String not found" );
+  catalog[1141]=dupstring( "String found at line %d" );
+  catalog[1142]=dupstring( "Jump to line number\nKey: Ctrl-l" );
+  catalog[1143]=dupstring( "Close window\nKey: q, F3, F10" );
+  catalog[1144]=dupstring( "Jump to next match\nKey: Enter or n" );
+  catalog[1145]=dupstring( "Jump to previous match\nKey: p" );
+  catalog[1146]=dupstring( "Read more lines from file\nKey: r" );
+  catalog[1147]=dupstring( "Wrap lines at window width\nKey: w" );
+  catalog[1148]=dupstring( "Show line numbers\nKey: l" );
+  catalog[1149]=dupstring( "Enter search string\nKey to activate: /, Ctrl-s, Ctrl-f" );
+  catalog[1150]=dupstring( "String compare mode:" );
+  catalog[1151]=dupstring( "regular string comparison" );
+  catalog[1152]=dupstring( "number optimized comparison" );
+  catalog[1153]=dupstring( "compare ignoring case" );
+  catalog[1154]=dupstring( "Accessed earlier than:" );
+  catalog[1155]=dupstring( "+1 hour (Ctrl+h)" );
+  catalog[1156]=dupstring( "+1 day (Ctrl+d)" );
+  catalog[1157]=dupstring( "+1 week (Ctrl+w)" );
+  catalog[1158]=dupstring( "Reset" );
 
 //  catalog[]=dupstring( "" );
   
