@@ -1,6 +1,6 @@
 /* wpucontext.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2005,2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2002-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -366,20 +366,20 @@ int WPUContext::openWin()
   
   if ( userwin == NULL ) {
     aguix = worker->getAGUIX();
-    userwin = new AWindow( aguix, 10, 10, 100, 50, 0, catalog.getLocale( 499 ), AWindow::AWINDOW_DIALOG );
+    userwin = new AWindow( aguix, 10, 10, 100, 50, catalog.getLocale( 499 ), AWindow::AWINDOW_DIALOG );
     userwin->create();
     tx = ty = 5;
     nr_of_text = 1;
     texts = new Text*[nr_of_text];
-    texts[0] = (Text*)userwin->add( new Text( aguix, tx, ty, "", 1 ) );
+    texts[0] = (Text*)userwin->add( new Text( aguix, tx, ty, "" ) );
     ty += texts[0]->getHeight() + 5;
     bb1 = (BevelBox*)userwin->add( new BevelBox( aguix, tx, ty, 10, 10, 1 ) );
-    prosb = (SolidButton*)userwin->add( new SolidButton( aguix, tx + 1, ty + 1, 10, "", 2, 3, 0 ) );
+    prosb = (SolidButton*)userwin->add( new SolidButton( aguix, tx + 1, ty + 1, 10, "", "button-special1-fg", "button-special1-bg", 0 ) );
     bb1->resize( bb1->getWidth(), prosb->getHeight() + 2 );
     ty += bb1->getHeight() + 5;
     bb2 = (BevelBox*)userwin->add( new BevelBox( aguix, tx, ty, 10, 2, 0 ) );
     ty += bb2->getHeight() + 5;
-    cancelb = (Button*)userwin->add( new Button( aguix, tx, ty, catalog.getLocale( 8 ), 1, 0, 0 ) );
+    cancelb = (Button*)userwin->add( new Button( aguix, tx, ty, catalog.getLocale( 8 ), 0 ) );
     ty += cancelb->getHeight() + 5;
     userwin->maximizeX();
     userwin->maximizeY();
@@ -1220,7 +1220,7 @@ void WPUContext::setWinText( const char *str )
         ty += ntexts[i]->getHeight() + 5;
       }
       for ( i = nr_of_text; i < lines; i++ ) {
-        ntexts[i] = (Text*)userwin->add( new Text( aguix, 5, ty, liness[i], 1 ) );
+        ntexts[i] = (Text*)userwin->add( new Text( aguix, 5, ty, liness[i] ) );
         ty += ntexts[i]->getHeight() + 5;
       }
     } else {
